Class: Google::Cloud::CapacityPlanner::V1beta::Allocation
- Inherits:
-
Object
- Object
- Google::Cloud::CapacityPlanner::V1beta::Allocation
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/capacityplanner/v1beta/allocation.rb
Overview
Repesents Allocation which is part of aggregated reservations data response of "QueryReservations".
Defined Under Namespace
Modules: Status Classes: ShareSettings, SpecificSKUAllocation
Instance Attribute Summary collapse
-
#allocation ⇒ ::String
The reservation resource name.
-
#auto_delete_time ⇒ ::Google::Protobuf::Timestamp
Absolute time in future when the reservation will be auto-deleted by Compute Engine.
-
#create_time ⇒ ::Google::Protobuf::Timestamp
The creation timestamp for this allocation.
-
#description ⇒ ::String
A description while creating reservation.
-
#id ⇒ ::Integer
The unique identifier for the resource.
- #owner_project_id ⇒ ::String
-
#share_settings ⇒ ::Google::Cloud::CapacityPlanner::V1beta::Allocation::ShareSettings
Specify share-settings to create a shared reservation.
-
#specific_allocation ⇒ ::Google::Cloud::CapacityPlanner::V1beta::Allocation::SpecificSKUAllocation
Reservation for instances with specific machine shapes.
-
#status ⇒ ::Google::Cloud::CapacityPlanner::V1beta::Allocation::Status
The status of the reservation.
-
#zone ⇒ ::String
Zone in which the reservation resides.
Instance Attribute Details
#allocation ⇒ ::String
Returns The reservation resource name.
57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 |
# File 'proto_docs/google/cloud/capacityplanner/v1beta/allocation.rb', line 57 class Allocation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # This reservation type allows to pre allocate specific instance # configuration. # @!attribute [rw] instance_properties # @return [::Google::Cloud::CapacityPlanner::V1beta::Allocation::SpecificSKUAllocation::AllocatedInstanceProperties] # The instance properties for the reservation. # @!attribute [rw] count # @return [::Integer] # Specifies the number of resources that are allocated. # @!attribute [rw] used_count # @return [::Integer] # Indicates how many instances are in use. # @!attribute [rw] assured_count # @return [::Integer] # Indicates how many instances are actually usable currently. class SpecificSKUAllocation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Properties of the SKU instances being reserved. # @!attribute [rw] machine_type # @return [::String] # Specifies type of machine (name only) which has fixed number of vCPUs # and fixed amount of memory. This also includes specifying custom # machine type following custom-NUMBER_OF_CPUS-AMOUNT_OF_MEMORY pattern. # @!attribute [rw] guest_accelerator # @return [::Array<::Google::Cloud::CapacityPlanner::V1beta::Allocation::SpecificSKUAllocation::AllocatedInstanceProperties::AcceleratorConfig>] # Specifies accelerator type and count. # @!attribute [rw] min_cpu_platform # @return [::String] # Minimum cpu platform the reservation. # @!attribute [rw] local_ssd # @return [::Array<::Google::Cloud::CapacityPlanner::V1beta::Allocation::SpecificSKUAllocation::AllocatedInstanceProperties::AllocatedDisk>] # Specifies amount of local ssd to reserve with each instance. The type # of disk is local-ssd. class AllocatedInstanceProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # A specification of the type and number of accelerator cards attached to # the instance. # @!attribute [rw] type # @return [::String] # Accelerator name. # See https://cloud.google.com/compute/docs/gpus/#introduction for a # full list of accelerator types. # @!attribute [rw] count # @return [::Integer] # The number of the guest accelerator cards exposed to this instance. class AcceleratorConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # A specification of the interface and size of disk attached to # the instance. # @!attribute [rw] disk_size_gb # @return [::Integer] # Specifies the size of the disk in base-2 GB. # @!attribute [rw] disk_interface # @return [::Google::Cloud::CapacityPlanner::V1beta::Allocation::SpecificSKUAllocation::AllocatedInstanceProperties::AllocatedDisk::DiskInterface] # Specifies the disk interface to use for attaching this disk, which is # either SCSI or NVME. The default is SCSI. class AllocatedDisk include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # guest device interface options to use for the disk. module DiskInterface # Default value. This value is unused. DISK_INTERFACE_UNSPECIFIED = 0 # SCSI disk interface. SCSI = 1 # NVME disk interface. NVME = 2 # NVDIMM disk interface. NVDIMM = 3 # ISCSI disk interface. ISCSI = 4 end end end end # The share setting for reservation. # @!attribute [rw] share_type # @return [::Google::Cloud::CapacityPlanner::V1beta::Allocation::ShareSettings::ShareType] # Type of sharing for this shared-reservation # @!attribute [rw] projects # @return [::Array<::String>] # A List of Project names to specify consumer projects for this # shared-reservation. This is only valid when share_type's value is # SPECIFIC_PROJECTS. class ShareSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Possible scope in which the reservation can be shared. More granularity # can be added in future. module ShareType # Default value. This value is unused. SHARE_TYPE_UNSPECIFIED = 0 # Shared-reservation is open to entire Organization ORGANIZATION = 1 # Shared-reservation is open to specific projects SPECIFIC_PROJECTS = 2 # Default value. LOCAL = 3 # Shared-reservation is open to direct child projects of specific # folders. DIRECT_PROJECTS_UNDER_SPECIFIC_FOLDERS = 4 end end # The status of the reservation. module Status # Default value. This value is unused. STATUS_UNSPECIFIED = 0 # Invalid Reservation INVALID = 1 # Resources are being allocated for the reservation. CREATING = 2 # Reservation has allocated all its resources. READY = 3 # Reservation is currently being deleted. DELETING = 4 # Reservation is currently being resized. UPDATING = 5 end end |
#auto_delete_time ⇒ ::Google::Protobuf::Timestamp
Returns Absolute time in future when the reservation will be auto-deleted by Compute Engine.
57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 |
# File 'proto_docs/google/cloud/capacityplanner/v1beta/allocation.rb', line 57 class Allocation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # This reservation type allows to pre allocate specific instance # configuration. # @!attribute [rw] instance_properties # @return [::Google::Cloud::CapacityPlanner::V1beta::Allocation::SpecificSKUAllocation::AllocatedInstanceProperties] # The instance properties for the reservation. # @!attribute [rw] count # @return [::Integer] # Specifies the number of resources that are allocated. # @!attribute [rw] used_count # @return [::Integer] # Indicates how many instances are in use. # @!attribute [rw] assured_count # @return [::Integer] # Indicates how many instances are actually usable currently. class SpecificSKUAllocation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Properties of the SKU instances being reserved. # @!attribute [rw] machine_type # @return [::String] # Specifies type of machine (name only) which has fixed number of vCPUs # and fixed amount of memory. This also includes specifying custom # machine type following custom-NUMBER_OF_CPUS-AMOUNT_OF_MEMORY pattern. # @!attribute [rw] guest_accelerator # @return [::Array<::Google::Cloud::CapacityPlanner::V1beta::Allocation::SpecificSKUAllocation::AllocatedInstanceProperties::AcceleratorConfig>] # Specifies accelerator type and count. # @!attribute [rw] min_cpu_platform # @return [::String] # Minimum cpu platform the reservation. # @!attribute [rw] local_ssd # @return [::Array<::Google::Cloud::CapacityPlanner::V1beta::Allocation::SpecificSKUAllocation::AllocatedInstanceProperties::AllocatedDisk>] # Specifies amount of local ssd to reserve with each instance. The type # of disk is local-ssd. class AllocatedInstanceProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # A specification of the type and number of accelerator cards attached to # the instance. # @!attribute [rw] type # @return [::String] # Accelerator name. # See https://cloud.google.com/compute/docs/gpus/#introduction for a # full list of accelerator types. # @!attribute [rw] count # @return [::Integer] # The number of the guest accelerator cards exposed to this instance. class AcceleratorConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # A specification of the interface and size of disk attached to # the instance. # @!attribute [rw] disk_size_gb # @return [::Integer] # Specifies the size of the disk in base-2 GB. # @!attribute [rw] disk_interface # @return [::Google::Cloud::CapacityPlanner::V1beta::Allocation::SpecificSKUAllocation::AllocatedInstanceProperties::AllocatedDisk::DiskInterface] # Specifies the disk interface to use for attaching this disk, which is # either SCSI or NVME. The default is SCSI. class AllocatedDisk include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # guest device interface options to use for the disk. module DiskInterface # Default value. This value is unused. DISK_INTERFACE_UNSPECIFIED = 0 # SCSI disk interface. SCSI = 1 # NVME disk interface. NVME = 2 # NVDIMM disk interface. NVDIMM = 3 # ISCSI disk interface. ISCSI = 4 end end end end # The share setting for reservation. # @!attribute [rw] share_type # @return [::Google::Cloud::CapacityPlanner::V1beta::Allocation::ShareSettings::ShareType] # Type of sharing for this shared-reservation # @!attribute [rw] projects # @return [::Array<::String>] # A List of Project names to specify consumer projects for this # shared-reservation. This is only valid when share_type's value is # SPECIFIC_PROJECTS. class ShareSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Possible scope in which the reservation can be shared. More granularity # can be added in future. module ShareType # Default value. This value is unused. SHARE_TYPE_UNSPECIFIED = 0 # Shared-reservation is open to entire Organization ORGANIZATION = 1 # Shared-reservation is open to specific projects SPECIFIC_PROJECTS = 2 # Default value. LOCAL = 3 # Shared-reservation is open to direct child projects of specific # folders. DIRECT_PROJECTS_UNDER_SPECIFIC_FOLDERS = 4 end end # The status of the reservation. module Status # Default value. This value is unused. STATUS_UNSPECIFIED = 0 # Invalid Reservation INVALID = 1 # Resources are being allocated for the reservation. CREATING = 2 # Reservation has allocated all its resources. READY = 3 # Reservation is currently being deleted. DELETING = 4 # Reservation is currently being resized. UPDATING = 5 end end |
#create_time ⇒ ::Google::Protobuf::Timestamp
Returns The creation timestamp for this allocation.
57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 |
# File 'proto_docs/google/cloud/capacityplanner/v1beta/allocation.rb', line 57 class Allocation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # This reservation type allows to pre allocate specific instance # configuration. # @!attribute [rw] instance_properties # @return [::Google::Cloud::CapacityPlanner::V1beta::Allocation::SpecificSKUAllocation::AllocatedInstanceProperties] # The instance properties for the reservation. # @!attribute [rw] count # @return [::Integer] # Specifies the number of resources that are allocated. # @!attribute [rw] used_count # @return [::Integer] # Indicates how many instances are in use. # @!attribute [rw] assured_count # @return [::Integer] # Indicates how many instances are actually usable currently. class SpecificSKUAllocation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Properties of the SKU instances being reserved. # @!attribute [rw] machine_type # @return [::String] # Specifies type of machine (name only) which has fixed number of vCPUs # and fixed amount of memory. This also includes specifying custom # machine type following custom-NUMBER_OF_CPUS-AMOUNT_OF_MEMORY pattern. # @!attribute [rw] guest_accelerator # @return [::Array<::Google::Cloud::CapacityPlanner::V1beta::Allocation::SpecificSKUAllocation::AllocatedInstanceProperties::AcceleratorConfig>] # Specifies accelerator type and count. # @!attribute [rw] min_cpu_platform # @return [::String] # Minimum cpu platform the reservation. # @!attribute [rw] local_ssd # @return [::Array<::Google::Cloud::CapacityPlanner::V1beta::Allocation::SpecificSKUAllocation::AllocatedInstanceProperties::AllocatedDisk>] # Specifies amount of local ssd to reserve with each instance. The type # of disk is local-ssd. class AllocatedInstanceProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # A specification of the type and number of accelerator cards attached to # the instance. # @!attribute [rw] type # @return [::String] # Accelerator name. # See https://cloud.google.com/compute/docs/gpus/#introduction for a # full list of accelerator types. # @!attribute [rw] count # @return [::Integer] # The number of the guest accelerator cards exposed to this instance. class AcceleratorConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # A specification of the interface and size of disk attached to # the instance. # @!attribute [rw] disk_size_gb # @return [::Integer] # Specifies the size of the disk in base-2 GB. # @!attribute [rw] disk_interface # @return [::Google::Cloud::CapacityPlanner::V1beta::Allocation::SpecificSKUAllocation::AllocatedInstanceProperties::AllocatedDisk::DiskInterface] # Specifies the disk interface to use for attaching this disk, which is # either SCSI or NVME. The default is SCSI. class AllocatedDisk include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # guest device interface options to use for the disk. module DiskInterface # Default value. This value is unused. DISK_INTERFACE_UNSPECIFIED = 0 # SCSI disk interface. SCSI = 1 # NVME disk interface. NVME = 2 # NVDIMM disk interface. NVDIMM = 3 # ISCSI disk interface. ISCSI = 4 end end end end # The share setting for reservation. # @!attribute [rw] share_type # @return [::Google::Cloud::CapacityPlanner::V1beta::Allocation::ShareSettings::ShareType] # Type of sharing for this shared-reservation # @!attribute [rw] projects # @return [::Array<::String>] # A List of Project names to specify consumer projects for this # shared-reservation. This is only valid when share_type's value is # SPECIFIC_PROJECTS. class ShareSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Possible scope in which the reservation can be shared. More granularity # can be added in future. module ShareType # Default value. This value is unused. SHARE_TYPE_UNSPECIFIED = 0 # Shared-reservation is open to entire Organization ORGANIZATION = 1 # Shared-reservation is open to specific projects SPECIFIC_PROJECTS = 2 # Default value. LOCAL = 3 # Shared-reservation is open to direct child projects of specific # folders. DIRECT_PROJECTS_UNDER_SPECIFIC_FOLDERS = 4 end end # The status of the reservation. module Status # Default value. This value is unused. STATUS_UNSPECIFIED = 0 # Invalid Reservation INVALID = 1 # Resources are being allocated for the reservation. CREATING = 2 # Reservation has allocated all its resources. READY = 3 # Reservation is currently being deleted. DELETING = 4 # Reservation is currently being resized. UPDATING = 5 end end |
#description ⇒ ::String
Returns A description while creating reservation.
57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 |
# File 'proto_docs/google/cloud/capacityplanner/v1beta/allocation.rb', line 57 class Allocation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # This reservation type allows to pre allocate specific instance # configuration. # @!attribute [rw] instance_properties # @return [::Google::Cloud::CapacityPlanner::V1beta::Allocation::SpecificSKUAllocation::AllocatedInstanceProperties] # The instance properties for the reservation. # @!attribute [rw] count # @return [::Integer] # Specifies the number of resources that are allocated. # @!attribute [rw] used_count # @return [::Integer] # Indicates how many instances are in use. # @!attribute [rw] assured_count # @return [::Integer] # Indicates how many instances are actually usable currently. class SpecificSKUAllocation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Properties of the SKU instances being reserved. # @!attribute [rw] machine_type # @return [::String] # Specifies type of machine (name only) which has fixed number of vCPUs # and fixed amount of memory. This also includes specifying custom # machine type following custom-NUMBER_OF_CPUS-AMOUNT_OF_MEMORY pattern. # @!attribute [rw] guest_accelerator # @return [::Array<::Google::Cloud::CapacityPlanner::V1beta::Allocation::SpecificSKUAllocation::AllocatedInstanceProperties::AcceleratorConfig>] # Specifies accelerator type and count. # @!attribute [rw] min_cpu_platform # @return [::String] # Minimum cpu platform the reservation. # @!attribute [rw] local_ssd # @return [::Array<::Google::Cloud::CapacityPlanner::V1beta::Allocation::SpecificSKUAllocation::AllocatedInstanceProperties::AllocatedDisk>] # Specifies amount of local ssd to reserve with each instance. The type # of disk is local-ssd. class AllocatedInstanceProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # A specification of the type and number of accelerator cards attached to # the instance. # @!attribute [rw] type # @return [::String] # Accelerator name. # See https://cloud.google.com/compute/docs/gpus/#introduction for a # full list of accelerator types. # @!attribute [rw] count # @return [::Integer] # The number of the guest accelerator cards exposed to this instance. class AcceleratorConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # A specification of the interface and size of disk attached to # the instance. # @!attribute [rw] disk_size_gb # @return [::Integer] # Specifies the size of the disk in base-2 GB. # @!attribute [rw] disk_interface # @return [::Google::Cloud::CapacityPlanner::V1beta::Allocation::SpecificSKUAllocation::AllocatedInstanceProperties::AllocatedDisk::DiskInterface] # Specifies the disk interface to use for attaching this disk, which is # either SCSI or NVME. The default is SCSI. class AllocatedDisk include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # guest device interface options to use for the disk. module DiskInterface # Default value. This value is unused. DISK_INTERFACE_UNSPECIFIED = 0 # SCSI disk interface. SCSI = 1 # NVME disk interface. NVME = 2 # NVDIMM disk interface. NVDIMM = 3 # ISCSI disk interface. ISCSI = 4 end end end end # The share setting for reservation. # @!attribute [rw] share_type # @return [::Google::Cloud::CapacityPlanner::V1beta::Allocation::ShareSettings::ShareType] # Type of sharing for this shared-reservation # @!attribute [rw] projects # @return [::Array<::String>] # A List of Project names to specify consumer projects for this # shared-reservation. This is only valid when share_type's value is # SPECIFIC_PROJECTS. class ShareSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Possible scope in which the reservation can be shared. More granularity # can be added in future. module ShareType # Default value. This value is unused. SHARE_TYPE_UNSPECIFIED = 0 # Shared-reservation is open to entire Organization ORGANIZATION = 1 # Shared-reservation is open to specific projects SPECIFIC_PROJECTS = 2 # Default value. LOCAL = 3 # Shared-reservation is open to direct child projects of specific # folders. DIRECT_PROJECTS_UNDER_SPECIFIC_FOLDERS = 4 end end # The status of the reservation. module Status # Default value. This value is unused. STATUS_UNSPECIFIED = 0 # Invalid Reservation INVALID = 1 # Resources are being allocated for the reservation. CREATING = 2 # Reservation has allocated all its resources. READY = 3 # Reservation is currently being deleted. DELETING = 4 # Reservation is currently being resized. UPDATING = 5 end end |
#id ⇒ ::Integer
Returns The unique identifier for the resource. This identifier is defined by the server.
57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 |
# File 'proto_docs/google/cloud/capacityplanner/v1beta/allocation.rb', line 57 class Allocation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # This reservation type allows to pre allocate specific instance # configuration. # @!attribute [rw] instance_properties # @return [::Google::Cloud::CapacityPlanner::V1beta::Allocation::SpecificSKUAllocation::AllocatedInstanceProperties] # The instance properties for the reservation. # @!attribute [rw] count # @return [::Integer] # Specifies the number of resources that are allocated. # @!attribute [rw] used_count # @return [::Integer] # Indicates how many instances are in use. # @!attribute [rw] assured_count # @return [::Integer] # Indicates how many instances are actually usable currently. class SpecificSKUAllocation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Properties of the SKU instances being reserved. # @!attribute [rw] machine_type # @return [::String] # Specifies type of machine (name only) which has fixed number of vCPUs # and fixed amount of memory. This also includes specifying custom # machine type following custom-NUMBER_OF_CPUS-AMOUNT_OF_MEMORY pattern. # @!attribute [rw] guest_accelerator # @return [::Array<::Google::Cloud::CapacityPlanner::V1beta::Allocation::SpecificSKUAllocation::AllocatedInstanceProperties::AcceleratorConfig>] # Specifies accelerator type and count. # @!attribute [rw] min_cpu_platform # @return [::String] # Minimum cpu platform the reservation. # @!attribute [rw] local_ssd # @return [::Array<::Google::Cloud::CapacityPlanner::V1beta::Allocation::SpecificSKUAllocation::AllocatedInstanceProperties::AllocatedDisk>] # Specifies amount of local ssd to reserve with each instance. The type # of disk is local-ssd. class AllocatedInstanceProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # A specification of the type and number of accelerator cards attached to # the instance. # @!attribute [rw] type # @return [::String] # Accelerator name. # See https://cloud.google.com/compute/docs/gpus/#introduction for a # full list of accelerator types. # @!attribute [rw] count # @return [::Integer] # The number of the guest accelerator cards exposed to this instance. class AcceleratorConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # A specification of the interface and size of disk attached to # the instance. # @!attribute [rw] disk_size_gb # @return [::Integer] # Specifies the size of the disk in base-2 GB. # @!attribute [rw] disk_interface # @return [::Google::Cloud::CapacityPlanner::V1beta::Allocation::SpecificSKUAllocation::AllocatedInstanceProperties::AllocatedDisk::DiskInterface] # Specifies the disk interface to use for attaching this disk, which is # either SCSI or NVME. The default is SCSI. class AllocatedDisk include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # guest device interface options to use for the disk. module DiskInterface # Default value. This value is unused. DISK_INTERFACE_UNSPECIFIED = 0 # SCSI disk interface. SCSI = 1 # NVME disk interface. NVME = 2 # NVDIMM disk interface. NVDIMM = 3 # ISCSI disk interface. ISCSI = 4 end end end end # The share setting for reservation. # @!attribute [rw] share_type # @return [::Google::Cloud::CapacityPlanner::V1beta::Allocation::ShareSettings::ShareType] # Type of sharing for this shared-reservation # @!attribute [rw] projects # @return [::Array<::String>] # A List of Project names to specify consumer projects for this # shared-reservation. This is only valid when share_type's value is # SPECIFIC_PROJECTS. class ShareSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Possible scope in which the reservation can be shared. More granularity # can be added in future. module ShareType # Default value. This value is unused. SHARE_TYPE_UNSPECIFIED = 0 # Shared-reservation is open to entire Organization ORGANIZATION = 1 # Shared-reservation is open to specific projects SPECIFIC_PROJECTS = 2 # Default value. LOCAL = 3 # Shared-reservation is open to direct child projects of specific # folders. DIRECT_PROJECTS_UNDER_SPECIFIC_FOLDERS = 4 end end # The status of the reservation. module Status # Default value. This value is unused. STATUS_UNSPECIFIED = 0 # Invalid Reservation INVALID = 1 # Resources are being allocated for the reservation. CREATING = 2 # Reservation has allocated all its resources. READY = 3 # Reservation is currently being deleted. DELETING = 4 # Reservation is currently being resized. UPDATING = 5 end end |
#owner_project_id ⇒ ::String
57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 |
# File 'proto_docs/google/cloud/capacityplanner/v1beta/allocation.rb', line 57 class Allocation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # This reservation type allows to pre allocate specific instance # configuration. # @!attribute [rw] instance_properties # @return [::Google::Cloud::CapacityPlanner::V1beta::Allocation::SpecificSKUAllocation::AllocatedInstanceProperties] # The instance properties for the reservation. # @!attribute [rw] count # @return [::Integer] # Specifies the number of resources that are allocated. # @!attribute [rw] used_count # @return [::Integer] # Indicates how many instances are in use. # @!attribute [rw] assured_count # @return [::Integer] # Indicates how many instances are actually usable currently. class SpecificSKUAllocation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Properties of the SKU instances being reserved. # @!attribute [rw] machine_type # @return [::String] # Specifies type of machine (name only) which has fixed number of vCPUs # and fixed amount of memory. This also includes specifying custom # machine type following custom-NUMBER_OF_CPUS-AMOUNT_OF_MEMORY pattern. # @!attribute [rw] guest_accelerator # @return [::Array<::Google::Cloud::CapacityPlanner::V1beta::Allocation::SpecificSKUAllocation::AllocatedInstanceProperties::AcceleratorConfig>] # Specifies accelerator type and count. # @!attribute [rw] min_cpu_platform # @return [::String] # Minimum cpu platform the reservation. # @!attribute [rw] local_ssd # @return [::Array<::Google::Cloud::CapacityPlanner::V1beta::Allocation::SpecificSKUAllocation::AllocatedInstanceProperties::AllocatedDisk>] # Specifies amount of local ssd to reserve with each instance. The type # of disk is local-ssd. class AllocatedInstanceProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # A specification of the type and number of accelerator cards attached to # the instance. # @!attribute [rw] type # @return [::String] # Accelerator name. # See https://cloud.google.com/compute/docs/gpus/#introduction for a # full list of accelerator types. # @!attribute [rw] count # @return [::Integer] # The number of the guest accelerator cards exposed to this instance. class AcceleratorConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # A specification of the interface and size of disk attached to # the instance. # @!attribute [rw] disk_size_gb # @return [::Integer] # Specifies the size of the disk in base-2 GB. # @!attribute [rw] disk_interface # @return [::Google::Cloud::CapacityPlanner::V1beta::Allocation::SpecificSKUAllocation::AllocatedInstanceProperties::AllocatedDisk::DiskInterface] # Specifies the disk interface to use for attaching this disk, which is # either SCSI or NVME. The default is SCSI. class AllocatedDisk include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # guest device interface options to use for the disk. module DiskInterface # Default value. This value is unused. DISK_INTERFACE_UNSPECIFIED = 0 # SCSI disk interface. SCSI = 1 # NVME disk interface. NVME = 2 # NVDIMM disk interface. NVDIMM = 3 # ISCSI disk interface. ISCSI = 4 end end end end # The share setting for reservation. # @!attribute [rw] share_type # @return [::Google::Cloud::CapacityPlanner::V1beta::Allocation::ShareSettings::ShareType] # Type of sharing for this shared-reservation # @!attribute [rw] projects # @return [::Array<::String>] # A List of Project names to specify consumer projects for this # shared-reservation. This is only valid when share_type's value is # SPECIFIC_PROJECTS. class ShareSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Possible scope in which the reservation can be shared. More granularity # can be added in future. module ShareType # Default value. This value is unused. SHARE_TYPE_UNSPECIFIED = 0 # Shared-reservation is open to entire Organization ORGANIZATION = 1 # Shared-reservation is open to specific projects SPECIFIC_PROJECTS = 2 # Default value. LOCAL = 3 # Shared-reservation is open to direct child projects of specific # folders. DIRECT_PROJECTS_UNDER_SPECIFIC_FOLDERS = 4 end end # The status of the reservation. module Status # Default value. This value is unused. STATUS_UNSPECIFIED = 0 # Invalid Reservation INVALID = 1 # Resources are being allocated for the reservation. CREATING = 2 # Reservation has allocated all its resources. READY = 3 # Reservation is currently being deleted. DELETING = 4 # Reservation is currently being resized. UPDATING = 5 end end |
#share_settings ⇒ ::Google::Cloud::CapacityPlanner::V1beta::Allocation::ShareSettings
Returns Specify share-settings to create a shared reservation.
57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 |
# File 'proto_docs/google/cloud/capacityplanner/v1beta/allocation.rb', line 57 class Allocation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # This reservation type allows to pre allocate specific instance # configuration. # @!attribute [rw] instance_properties # @return [::Google::Cloud::CapacityPlanner::V1beta::Allocation::SpecificSKUAllocation::AllocatedInstanceProperties] # The instance properties for the reservation. # @!attribute [rw] count # @return [::Integer] # Specifies the number of resources that are allocated. # @!attribute [rw] used_count # @return [::Integer] # Indicates how many instances are in use. # @!attribute [rw] assured_count # @return [::Integer] # Indicates how many instances are actually usable currently. class SpecificSKUAllocation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Properties of the SKU instances being reserved. # @!attribute [rw] machine_type # @return [::String] # Specifies type of machine (name only) which has fixed number of vCPUs # and fixed amount of memory. This also includes specifying custom # machine type following custom-NUMBER_OF_CPUS-AMOUNT_OF_MEMORY pattern. # @!attribute [rw] guest_accelerator # @return [::Array<::Google::Cloud::CapacityPlanner::V1beta::Allocation::SpecificSKUAllocation::AllocatedInstanceProperties::AcceleratorConfig>] # Specifies accelerator type and count. # @!attribute [rw] min_cpu_platform # @return [::String] # Minimum cpu platform the reservation. # @!attribute [rw] local_ssd # @return [::Array<::Google::Cloud::CapacityPlanner::V1beta::Allocation::SpecificSKUAllocation::AllocatedInstanceProperties::AllocatedDisk>] # Specifies amount of local ssd to reserve with each instance. The type # of disk is local-ssd. class AllocatedInstanceProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # A specification of the type and number of accelerator cards attached to # the instance. # @!attribute [rw] type # @return [::String] # Accelerator name. # See https://cloud.google.com/compute/docs/gpus/#introduction for a # full list of accelerator types. # @!attribute [rw] count # @return [::Integer] # The number of the guest accelerator cards exposed to this instance. class AcceleratorConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # A specification of the interface and size of disk attached to # the instance. # @!attribute [rw] disk_size_gb # @return [::Integer] # Specifies the size of the disk in base-2 GB. # @!attribute [rw] disk_interface # @return [::Google::Cloud::CapacityPlanner::V1beta::Allocation::SpecificSKUAllocation::AllocatedInstanceProperties::AllocatedDisk::DiskInterface] # Specifies the disk interface to use for attaching this disk, which is # either SCSI or NVME. The default is SCSI. class AllocatedDisk include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # guest device interface options to use for the disk. module DiskInterface # Default value. This value is unused. DISK_INTERFACE_UNSPECIFIED = 0 # SCSI disk interface. SCSI = 1 # NVME disk interface. NVME = 2 # NVDIMM disk interface. NVDIMM = 3 # ISCSI disk interface. ISCSI = 4 end end end end # The share setting for reservation. # @!attribute [rw] share_type # @return [::Google::Cloud::CapacityPlanner::V1beta::Allocation::ShareSettings::ShareType] # Type of sharing for this shared-reservation # @!attribute [rw] projects # @return [::Array<::String>] # A List of Project names to specify consumer projects for this # shared-reservation. This is only valid when share_type's value is # SPECIFIC_PROJECTS. class ShareSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Possible scope in which the reservation can be shared. More granularity # can be added in future. module ShareType # Default value. This value is unused. SHARE_TYPE_UNSPECIFIED = 0 # Shared-reservation is open to entire Organization ORGANIZATION = 1 # Shared-reservation is open to specific projects SPECIFIC_PROJECTS = 2 # Default value. LOCAL = 3 # Shared-reservation is open to direct child projects of specific # folders. DIRECT_PROJECTS_UNDER_SPECIFIC_FOLDERS = 4 end end # The status of the reservation. module Status # Default value. This value is unused. STATUS_UNSPECIFIED = 0 # Invalid Reservation INVALID = 1 # Resources are being allocated for the reservation. CREATING = 2 # Reservation has allocated all its resources. READY = 3 # Reservation is currently being deleted. DELETING = 4 # Reservation is currently being resized. UPDATING = 5 end end |
#specific_allocation ⇒ ::Google::Cloud::CapacityPlanner::V1beta::Allocation::SpecificSKUAllocation
Returns Reservation for instances with specific machine shapes.
57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 |
# File 'proto_docs/google/cloud/capacityplanner/v1beta/allocation.rb', line 57 class Allocation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # This reservation type allows to pre allocate specific instance # configuration. # @!attribute [rw] instance_properties # @return [::Google::Cloud::CapacityPlanner::V1beta::Allocation::SpecificSKUAllocation::AllocatedInstanceProperties] # The instance properties for the reservation. # @!attribute [rw] count # @return [::Integer] # Specifies the number of resources that are allocated. # @!attribute [rw] used_count # @return [::Integer] # Indicates how many instances are in use. # @!attribute [rw] assured_count # @return [::Integer] # Indicates how many instances are actually usable currently. class SpecificSKUAllocation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Properties of the SKU instances being reserved. # @!attribute [rw] machine_type # @return [::String] # Specifies type of machine (name only) which has fixed number of vCPUs # and fixed amount of memory. This also includes specifying custom # machine type following custom-NUMBER_OF_CPUS-AMOUNT_OF_MEMORY pattern. # @!attribute [rw] guest_accelerator # @return [::Array<::Google::Cloud::CapacityPlanner::V1beta::Allocation::SpecificSKUAllocation::AllocatedInstanceProperties::AcceleratorConfig>] # Specifies accelerator type and count. # @!attribute [rw] min_cpu_platform # @return [::String] # Minimum cpu platform the reservation. # @!attribute [rw] local_ssd # @return [::Array<::Google::Cloud::CapacityPlanner::V1beta::Allocation::SpecificSKUAllocation::AllocatedInstanceProperties::AllocatedDisk>] # Specifies amount of local ssd to reserve with each instance. The type # of disk is local-ssd. class AllocatedInstanceProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # A specification of the type and number of accelerator cards attached to # the instance. # @!attribute [rw] type # @return [::String] # Accelerator name. # See https://cloud.google.com/compute/docs/gpus/#introduction for a # full list of accelerator types. # @!attribute [rw] count # @return [::Integer] # The number of the guest accelerator cards exposed to this instance. class AcceleratorConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # A specification of the interface and size of disk attached to # the instance. # @!attribute [rw] disk_size_gb # @return [::Integer] # Specifies the size of the disk in base-2 GB. # @!attribute [rw] disk_interface # @return [::Google::Cloud::CapacityPlanner::V1beta::Allocation::SpecificSKUAllocation::AllocatedInstanceProperties::AllocatedDisk::DiskInterface] # Specifies the disk interface to use for attaching this disk, which is # either SCSI or NVME. The default is SCSI. class AllocatedDisk include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # guest device interface options to use for the disk. module DiskInterface # Default value. This value is unused. DISK_INTERFACE_UNSPECIFIED = 0 # SCSI disk interface. SCSI = 1 # NVME disk interface. NVME = 2 # NVDIMM disk interface. NVDIMM = 3 # ISCSI disk interface. ISCSI = 4 end end end end # The share setting for reservation. # @!attribute [rw] share_type # @return [::Google::Cloud::CapacityPlanner::V1beta::Allocation::ShareSettings::ShareType] # Type of sharing for this shared-reservation # @!attribute [rw] projects # @return [::Array<::String>] # A List of Project names to specify consumer projects for this # shared-reservation. This is only valid when share_type's value is # SPECIFIC_PROJECTS. class ShareSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Possible scope in which the reservation can be shared. More granularity # can be added in future. module ShareType # Default value. This value is unused. SHARE_TYPE_UNSPECIFIED = 0 # Shared-reservation is open to entire Organization ORGANIZATION = 1 # Shared-reservation is open to specific projects SPECIFIC_PROJECTS = 2 # Default value. LOCAL = 3 # Shared-reservation is open to direct child projects of specific # folders. DIRECT_PROJECTS_UNDER_SPECIFIC_FOLDERS = 4 end end # The status of the reservation. module Status # Default value. This value is unused. STATUS_UNSPECIFIED = 0 # Invalid Reservation INVALID = 1 # Resources are being allocated for the reservation. CREATING = 2 # Reservation has allocated all its resources. READY = 3 # Reservation is currently being deleted. DELETING = 4 # Reservation is currently being resized. UPDATING = 5 end end |
#status ⇒ ::Google::Cloud::CapacityPlanner::V1beta::Allocation::Status
Returns The status of the reservation.
57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 |
# File 'proto_docs/google/cloud/capacityplanner/v1beta/allocation.rb', line 57 class Allocation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # This reservation type allows to pre allocate specific instance # configuration. # @!attribute [rw] instance_properties # @return [::Google::Cloud::CapacityPlanner::V1beta::Allocation::SpecificSKUAllocation::AllocatedInstanceProperties] # The instance properties for the reservation. # @!attribute [rw] count # @return [::Integer] # Specifies the number of resources that are allocated. # @!attribute [rw] used_count # @return [::Integer] # Indicates how many instances are in use. # @!attribute [rw] assured_count # @return [::Integer] # Indicates how many instances are actually usable currently. class SpecificSKUAllocation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Properties of the SKU instances being reserved. # @!attribute [rw] machine_type # @return [::String] # Specifies type of machine (name only) which has fixed number of vCPUs # and fixed amount of memory. This also includes specifying custom # machine type following custom-NUMBER_OF_CPUS-AMOUNT_OF_MEMORY pattern. # @!attribute [rw] guest_accelerator # @return [::Array<::Google::Cloud::CapacityPlanner::V1beta::Allocation::SpecificSKUAllocation::AllocatedInstanceProperties::AcceleratorConfig>] # Specifies accelerator type and count. # @!attribute [rw] min_cpu_platform # @return [::String] # Minimum cpu platform the reservation. # @!attribute [rw] local_ssd # @return [::Array<::Google::Cloud::CapacityPlanner::V1beta::Allocation::SpecificSKUAllocation::AllocatedInstanceProperties::AllocatedDisk>] # Specifies amount of local ssd to reserve with each instance. The type # of disk is local-ssd. class AllocatedInstanceProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # A specification of the type and number of accelerator cards attached to # the instance. # @!attribute [rw] type # @return [::String] # Accelerator name. # See https://cloud.google.com/compute/docs/gpus/#introduction for a # full list of accelerator types. # @!attribute [rw] count # @return [::Integer] # The number of the guest accelerator cards exposed to this instance. class AcceleratorConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # A specification of the interface and size of disk attached to # the instance. # @!attribute [rw] disk_size_gb # @return [::Integer] # Specifies the size of the disk in base-2 GB. # @!attribute [rw] disk_interface # @return [::Google::Cloud::CapacityPlanner::V1beta::Allocation::SpecificSKUAllocation::AllocatedInstanceProperties::AllocatedDisk::DiskInterface] # Specifies the disk interface to use for attaching this disk, which is # either SCSI or NVME. The default is SCSI. class AllocatedDisk include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # guest device interface options to use for the disk. module DiskInterface # Default value. This value is unused. DISK_INTERFACE_UNSPECIFIED = 0 # SCSI disk interface. SCSI = 1 # NVME disk interface. NVME = 2 # NVDIMM disk interface. NVDIMM = 3 # ISCSI disk interface. ISCSI = 4 end end end end # The share setting for reservation. # @!attribute [rw] share_type # @return [::Google::Cloud::CapacityPlanner::V1beta::Allocation::ShareSettings::ShareType] # Type of sharing for this shared-reservation # @!attribute [rw] projects # @return [::Array<::String>] # A List of Project names to specify consumer projects for this # shared-reservation. This is only valid when share_type's value is # SPECIFIC_PROJECTS. class ShareSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Possible scope in which the reservation can be shared. More granularity # can be added in future. module ShareType # Default value. This value is unused. SHARE_TYPE_UNSPECIFIED = 0 # Shared-reservation is open to entire Organization ORGANIZATION = 1 # Shared-reservation is open to specific projects SPECIFIC_PROJECTS = 2 # Default value. LOCAL = 3 # Shared-reservation is open to direct child projects of specific # folders. DIRECT_PROJECTS_UNDER_SPECIFIC_FOLDERS = 4 end end # The status of the reservation. module Status # Default value. This value is unused. STATUS_UNSPECIFIED = 0 # Invalid Reservation INVALID = 1 # Resources are being allocated for the reservation. CREATING = 2 # Reservation has allocated all its resources. READY = 3 # Reservation is currently being deleted. DELETING = 4 # Reservation is currently being resized. UPDATING = 5 end end |
#zone ⇒ ::String
Returns Zone in which the reservation resides.
57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 |
# File 'proto_docs/google/cloud/capacityplanner/v1beta/allocation.rb', line 57 class Allocation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # This reservation type allows to pre allocate specific instance # configuration. # @!attribute [rw] instance_properties # @return [::Google::Cloud::CapacityPlanner::V1beta::Allocation::SpecificSKUAllocation::AllocatedInstanceProperties] # The instance properties for the reservation. # @!attribute [rw] count # @return [::Integer] # Specifies the number of resources that are allocated. # @!attribute [rw] used_count # @return [::Integer] # Indicates how many instances are in use. # @!attribute [rw] assured_count # @return [::Integer] # Indicates how many instances are actually usable currently. class SpecificSKUAllocation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Properties of the SKU instances being reserved. # @!attribute [rw] machine_type # @return [::String] # Specifies type of machine (name only) which has fixed number of vCPUs # and fixed amount of memory. This also includes specifying custom # machine type following custom-NUMBER_OF_CPUS-AMOUNT_OF_MEMORY pattern. # @!attribute [rw] guest_accelerator # @return [::Array<::Google::Cloud::CapacityPlanner::V1beta::Allocation::SpecificSKUAllocation::AllocatedInstanceProperties::AcceleratorConfig>] # Specifies accelerator type and count. # @!attribute [rw] min_cpu_platform # @return [::String] # Minimum cpu platform the reservation. # @!attribute [rw] local_ssd # @return [::Array<::Google::Cloud::CapacityPlanner::V1beta::Allocation::SpecificSKUAllocation::AllocatedInstanceProperties::AllocatedDisk>] # Specifies amount of local ssd to reserve with each instance. The type # of disk is local-ssd. class AllocatedInstanceProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # A specification of the type and number of accelerator cards attached to # the instance. # @!attribute [rw] type # @return [::String] # Accelerator name. # See https://cloud.google.com/compute/docs/gpus/#introduction for a # full list of accelerator types. # @!attribute [rw] count # @return [::Integer] # The number of the guest accelerator cards exposed to this instance. class AcceleratorConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # A specification of the interface and size of disk attached to # the instance. # @!attribute [rw] disk_size_gb # @return [::Integer] # Specifies the size of the disk in base-2 GB. # @!attribute [rw] disk_interface # @return [::Google::Cloud::CapacityPlanner::V1beta::Allocation::SpecificSKUAllocation::AllocatedInstanceProperties::AllocatedDisk::DiskInterface] # Specifies the disk interface to use for attaching this disk, which is # either SCSI or NVME. The default is SCSI. class AllocatedDisk include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # guest device interface options to use for the disk. module DiskInterface # Default value. This value is unused. DISK_INTERFACE_UNSPECIFIED = 0 # SCSI disk interface. SCSI = 1 # NVME disk interface. NVME = 2 # NVDIMM disk interface. NVDIMM = 3 # ISCSI disk interface. ISCSI = 4 end end end end # The share setting for reservation. # @!attribute [rw] share_type # @return [::Google::Cloud::CapacityPlanner::V1beta::Allocation::ShareSettings::ShareType] # Type of sharing for this shared-reservation # @!attribute [rw] projects # @return [::Array<::String>] # A List of Project names to specify consumer projects for this # shared-reservation. This is only valid when share_type's value is # SPECIFIC_PROJECTS. class ShareSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Possible scope in which the reservation can be shared. More granularity # can be added in future. module ShareType # Default value. This value is unused. SHARE_TYPE_UNSPECIFIED = 0 # Shared-reservation is open to entire Organization ORGANIZATION = 1 # Shared-reservation is open to specific projects SPECIFIC_PROJECTS = 2 # Default value. LOCAL = 3 # Shared-reservation is open to direct child projects of specific # folders. DIRECT_PROJECTS_UNDER_SPECIFIC_FOLDERS = 4 end end # The status of the reservation. module Status # Default value. This value is unused. STATUS_UNSPECIFIED = 0 # Invalid Reservation INVALID = 1 # Resources are being allocated for the reservation. CREATING = 2 # Reservation has allocated all its resources. READY = 3 # Reservation is currently being deleted. DELETING = 4 # Reservation is currently being resized. UPDATING = 5 end end |