Class: Google::Cloud::CapacityPlanner::V1beta::Allocation::SpecificSKUAllocation::AllocatedInstanceProperties

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/capacityplanner/v1beta/allocation.rb

Overview

Properties of the SKU instances being reserved.

Defined Under Namespace

Classes: AcceleratorConfig, AllocatedDisk

Instance Attribute Summary collapse

Instance Attribute Details

#guest_accelerator::Array<::Google::Cloud::CapacityPlanner::V1beta::Allocation::SpecificSKUAllocation::AllocatedInstanceProperties::AcceleratorConfig>

Returns Specifies accelerator type and count.



95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
# File 'proto_docs/google/cloud/capacityplanner/v1beta/allocation.rb', line 95

class AllocatedInstanceProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # A specification of the type and number of accelerator cards attached to
  # the instance.
  # @!attribute [rw] type
  #   @return [::String]
  #     Accelerator name.
  #     See https://cloud.google.com/compute/docs/gpus/#introduction for a
  #     full list of accelerator types.
  # @!attribute [rw] count
  #   @return [::Integer]
  #     The number of the guest accelerator cards exposed to this instance.
  class AcceleratorConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # A specification of the interface and size of disk attached to
  # the instance.
  # @!attribute [rw] disk_size_gb
  #   @return [::Integer]
  #     Specifies the size of the disk in base-2 GB.
  # @!attribute [rw] disk_interface
  #   @return [::Google::Cloud::CapacityPlanner::V1beta::Allocation::SpecificSKUAllocation::AllocatedInstanceProperties::AllocatedDisk::DiskInterface]
  #     Specifies the disk interface to use for attaching this disk, which is
  #     either SCSI or NVME. The default is SCSI.
  class AllocatedDisk
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # guest device interface options to use for the disk.
    module DiskInterface
      # Default value. This value is unused.
      DISK_INTERFACE_UNSPECIFIED = 0

      # SCSI disk interface.
      SCSI = 1

      # NVME disk interface.
      NVME = 2

      # NVDIMM disk interface.
      NVDIMM = 3

      # ISCSI disk interface.
      ISCSI = 4
    end
  end
end

#local_ssd::Array<::Google::Cloud::CapacityPlanner::V1beta::Allocation::SpecificSKUAllocation::AllocatedInstanceProperties::AllocatedDisk>

Returns Specifies amount of local ssd to reserve with each instance. The type of disk is local-ssd.

Returns:



95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
# File 'proto_docs/google/cloud/capacityplanner/v1beta/allocation.rb', line 95

class AllocatedInstanceProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # A specification of the type and number of accelerator cards attached to
  # the instance.
  # @!attribute [rw] type
  #   @return [::String]
  #     Accelerator name.
  #     See https://cloud.google.com/compute/docs/gpus/#introduction for a
  #     full list of accelerator types.
  # @!attribute [rw] count
  #   @return [::Integer]
  #     The number of the guest accelerator cards exposed to this instance.
  class AcceleratorConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # A specification of the interface and size of disk attached to
  # the instance.
  # @!attribute [rw] disk_size_gb
  #   @return [::Integer]
  #     Specifies the size of the disk in base-2 GB.
  # @!attribute [rw] disk_interface
  #   @return [::Google::Cloud::CapacityPlanner::V1beta::Allocation::SpecificSKUAllocation::AllocatedInstanceProperties::AllocatedDisk::DiskInterface]
  #     Specifies the disk interface to use for attaching this disk, which is
  #     either SCSI or NVME. The default is SCSI.
  class AllocatedDisk
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # guest device interface options to use for the disk.
    module DiskInterface
      # Default value. This value is unused.
      DISK_INTERFACE_UNSPECIFIED = 0

      # SCSI disk interface.
      SCSI = 1

      # NVME disk interface.
      NVME = 2

      # NVDIMM disk interface.
      NVDIMM = 3

      # ISCSI disk interface.
      ISCSI = 4
    end
  end
end

#machine_type::String

Returns Specifies type of machine (name only) which has fixed number of vCPUs and fixed amount of memory. This also includes specifying custom machine type following custom-NUMBER_OF_CPUS-AMOUNT_OF_MEMORY pattern.

Returns:

  • (::String)

    Specifies type of machine (name only) which has fixed number of vCPUs and fixed amount of memory. This also includes specifying custom machine type following custom-NUMBER_OF_CPUS-AMOUNT_OF_MEMORY pattern.



95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
# File 'proto_docs/google/cloud/capacityplanner/v1beta/allocation.rb', line 95

class AllocatedInstanceProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # A specification of the type and number of accelerator cards attached to
  # the instance.
  # @!attribute [rw] type
  #   @return [::String]
  #     Accelerator name.
  #     See https://cloud.google.com/compute/docs/gpus/#introduction for a
  #     full list of accelerator types.
  # @!attribute [rw] count
  #   @return [::Integer]
  #     The number of the guest accelerator cards exposed to this instance.
  class AcceleratorConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # A specification of the interface and size of disk attached to
  # the instance.
  # @!attribute [rw] disk_size_gb
  #   @return [::Integer]
  #     Specifies the size of the disk in base-2 GB.
  # @!attribute [rw] disk_interface
  #   @return [::Google::Cloud::CapacityPlanner::V1beta::Allocation::SpecificSKUAllocation::AllocatedInstanceProperties::AllocatedDisk::DiskInterface]
  #     Specifies the disk interface to use for attaching this disk, which is
  #     either SCSI or NVME. The default is SCSI.
  class AllocatedDisk
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # guest device interface options to use for the disk.
    module DiskInterface
      # Default value. This value is unused.
      DISK_INTERFACE_UNSPECIFIED = 0

      # SCSI disk interface.
      SCSI = 1

      # NVME disk interface.
      NVME = 2

      # NVDIMM disk interface.
      NVDIMM = 3

      # ISCSI disk interface.
      ISCSI = 4
    end
  end
end

#min_cpu_platform::String

Returns Minimum cpu platform the reservation.

Returns:

  • (::String)

    Minimum cpu platform the reservation.



95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
# File 'proto_docs/google/cloud/capacityplanner/v1beta/allocation.rb', line 95

class AllocatedInstanceProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # A specification of the type and number of accelerator cards attached to
  # the instance.
  # @!attribute [rw] type
  #   @return [::String]
  #     Accelerator name.
  #     See https://cloud.google.com/compute/docs/gpus/#introduction for a
  #     full list of accelerator types.
  # @!attribute [rw] count
  #   @return [::Integer]
  #     The number of the guest accelerator cards exposed to this instance.
  class AcceleratorConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # A specification of the interface and size of disk attached to
  # the instance.
  # @!attribute [rw] disk_size_gb
  #   @return [::Integer]
  #     Specifies the size of the disk in base-2 GB.
  # @!attribute [rw] disk_interface
  #   @return [::Google::Cloud::CapacityPlanner::V1beta::Allocation::SpecificSKUAllocation::AllocatedInstanceProperties::AllocatedDisk::DiskInterface]
  #     Specifies the disk interface to use for attaching this disk, which is
  #     either SCSI or NVME. The default is SCSI.
  class AllocatedDisk
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # guest device interface options to use for the disk.
    module DiskInterface
      # Default value. This value is unused.
      DISK_INTERFACE_UNSPECIFIED = 0

      # SCSI disk interface.
      SCSI = 1

      # NVME disk interface.
      NVME = 2

      # NVDIMM disk interface.
      NVDIMM = 3

      # ISCSI disk interface.
      ISCSI = 4
    end
  end
end