Module: Google::Cloud::CapacityPlanner::V1beta::BigQueryDestination::WriteDisposition

Defined in:
proto_docs/google/cloud/capacityplanner/v1beta/usage_service.rb

Overview

Specifies the action that occurs if the destination table or partition already exists. By default, the data will be appended to the existing table.

Constant Summary collapse

WRITE_DISPOSITION_UNSPECIFIED =

Unspecified write disposition.

0
WRITE_APPEND =

If the table or partition already exists, BigQuery appends the data to the table or the latest partition.

1
WRITE_TRUNCATE =

If the table or partition already exists, BigQuery overwrites the entire table or all the partitions data.

2
WRITE_EMPTY =

If the table already exists and contains data, an error is returned.

3