Class: Google::Cloud::CapacityPlanner::V1beta::ExportReservationsUsageRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/capacityplanner/v1beta/usage_service.rb

Overview

The ExportReservationsUsage request

Defined Under Namespace

Modules: ShareType

Instance Attribute Summary collapse

Instance Attribute Details

#cloud_resource_type::String

Returns Required. The resource for the ReservationsUsage values to return. Possible values include "gce-vcpus", "gce-ram", "gce-local-ssd", and "gce-gpu".

Returns:

  • (::String)

    Required. The resource for the ReservationsUsage values to return. Possible values include "gce-vcpus", "gce-ram", "gce-local-ssd", and "gce-gpu".



733
734
735
736
737
738
739
740
741
742
743
744
745
746
747
748
# File 'proto_docs/google/cloud/capacityplanner/v1beta/usage_service.rb', line 733

class ExportReservationsUsageRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Possible scope in which the reservation can be shared.
  module ShareType
    # No share type specified.
    SHARE_TYPE_UNSPECIFIED = 0

    # Default value, for which reservation is open to only owner project.
    SHARE_TYPE_LOCAL = 1

    # Shared-reservation is open to specific projects.
    SHARE_TYPE_SPECIFIC_PROJECTS = 2
  end
end

#end_date::Google::Type::Date

Returns Optional. The end date of reservations usage.

Returns:



733
734
735
736
737
738
739
740
741
742
743
744
745
746
747
748
# File 'proto_docs/google/cloud/capacityplanner/v1beta/usage_service.rb', line 733

class ExportReservationsUsageRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Possible scope in which the reservation can be shared.
  module ShareType
    # No share type specified.
    SHARE_TYPE_UNSPECIFIED = 0

    # Default value, for which reservation is open to only owner project.
    SHARE_TYPE_LOCAL = 1

    # Shared-reservation is open to specific projects.
    SHARE_TYPE_SPECIFIC_PROJECTS = 2
  end
end

#gpu_type::String

Returns Optional. The GPU type to query reservations and usage by. For example: NVIDIA T4.

Note: The following fields are mutually exclusive: gpu_type, machine_family, machine_shape. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::String)

    Optional. The GPU type to query reservations and usage by. For example: NVIDIA T4.

    Note: The following fields are mutually exclusive: gpu_type, machine_family, machine_shape. If a field in that set is populated, all other fields in the set will automatically be cleared.



733
734
735
736
737
738
739
740
741
742
743
744
745
746
747
748
# File 'proto_docs/google/cloud/capacityplanner/v1beta/usage_service.rb', line 733

class ExportReservationsUsageRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Possible scope in which the reservation can be shared.
  module ShareType
    # No share type specified.
    SHARE_TYPE_UNSPECIFIED = 0

    # Default value, for which reservation is open to only owner project.
    SHARE_TYPE_LOCAL = 1

    # Shared-reservation is open to specific projects.
    SHARE_TYPE_SPECIFIC_PROJECTS = 2
  end
end

#location_level::Google::Cloud::CapacityPlanner::V1beta::TimeSeries::LocationType

Returns Optional. The location level of the reservations usage timeseries.

Returns:



733
734
735
736
737
738
739
740
741
742
743
744
745
746
747
748
# File 'proto_docs/google/cloud/capacityplanner/v1beta/usage_service.rb', line 733

class ExportReservationsUsageRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Possible scope in which the reservation can be shared.
  module ShareType
    # No share type specified.
    SHARE_TYPE_UNSPECIFIED = 0

    # Default value, for which reservation is open to only owner project.
    SHARE_TYPE_LOCAL = 1

    # Shared-reservation is open to specific projects.
    SHARE_TYPE_SPECIFIC_PROJECTS = 2
  end
end

#machine_family::String

Returns Optional. The machine family to query reservations and usage by. For example: n1, n2d.

Note: The following fields are mutually exclusive: machine_family, machine_shape, gpu_type. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::String)

    Optional. The machine family to query reservations and usage by. For example: n1, n2d.

    Note: The following fields are mutually exclusive: machine_family, machine_shape, gpu_type. If a field in that set is populated, all other fields in the set will automatically be cleared.



733
734
735
736
737
738
739
740
741
742
743
744
745
746
747
748
# File 'proto_docs/google/cloud/capacityplanner/v1beta/usage_service.rb', line 733

class ExportReservationsUsageRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Possible scope in which the reservation can be shared.
  module ShareType
    # No share type specified.
    SHARE_TYPE_UNSPECIFIED = 0

    # Default value, for which reservation is open to only owner project.
    SHARE_TYPE_LOCAL = 1

    # Shared-reservation is open to specific projects.
    SHARE_TYPE_SPECIFIC_PROJECTS = 2
  end
end

#machine_shape::Google::Cloud::CapacityPlanner::V1beta::MachineShape

Returns Optional. The machine_shape as a filter to select matching reservations and its usage.

Note: The following fields are mutually exclusive: machine_shape, machine_family, gpu_type. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::CapacityPlanner::V1beta::MachineShape)

    Optional. The machine_shape as a filter to select matching reservations and its usage.

    Note: The following fields are mutually exclusive: machine_shape, machine_family, gpu_type. If a field in that set is populated, all other fields in the set will automatically be cleared.



733
734
735
736
737
738
739
740
741
742
743
744
745
746
747
748
# File 'proto_docs/google/cloud/capacityplanner/v1beta/usage_service.rb', line 733

class ExportReservationsUsageRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Possible scope in which the reservation can be shared.
  module ShareType
    # No share type specified.
    SHARE_TYPE_UNSPECIFIED = 0

    # Default value, for which reservation is open to only owner project.
    SHARE_TYPE_LOCAL = 1

    # Shared-reservation is open to specific projects.
    SHARE_TYPE_SPECIFIC_PROJECTS = 2
  end
end

#output_config::Google::Cloud::CapacityPlanner::V1beta::OutputConfig

Returns Required. Output configuration indicating where the results will be output to.

Returns:



733
734
735
736
737
738
739
740
741
742
743
744
745
746
747
748
# File 'proto_docs/google/cloud/capacityplanner/v1beta/usage_service.rb', line 733

class ExportReservationsUsageRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Possible scope in which the reservation can be shared.
  module ShareType
    # No share type specified.
    SHARE_TYPE_UNSPECIFIED = 0

    # Default value, for which reservation is open to only owner project.
    SHARE_TYPE_LOCAL = 1

    # Shared-reservation is open to specific projects.
    SHARE_TYPE_SPECIFIC_PROJECTS = 2
  end
end

#parent::String

Returns Required. The compute engine resource and location of the reservationsusage. The format is: projects/{project}/locations/{location} or organizations/{organization}/locations/{location} or folders/{folder}/locations/{location}.

Returns:

  • (::String)

    Required. The compute engine resource and location of the reservationsusage. The format is: projects/{project}/locations/{location} or organizations/{organization}/locations/{location} or folders/{folder}/locations/{location}



733
734
735
736
737
738
739
740
741
742
743
744
745
746
747
748
# File 'proto_docs/google/cloud/capacityplanner/v1beta/usage_service.rb', line 733

class ExportReservationsUsageRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Possible scope in which the reservation can be shared.
  module ShareType
    # No share type specified.
    SHARE_TYPE_UNSPECIFIED = 0

    # Default value, for which reservation is open to only owner project.
    SHARE_TYPE_LOCAL = 1

    # Shared-reservation is open to specific projects.
    SHARE_TYPE_SPECIFIC_PROJECTS = 2
  end
end

#share_type::Google::Cloud::CapacityPlanner::V1beta::ExportReservationsUsageRequest::ShareType

Returns Optional. Type of share settings to filter reservations in response. If unspecified, all types are included.

Returns:



733
734
735
736
737
738
739
740
741
742
743
744
745
746
747
748
# File 'proto_docs/google/cloud/capacityplanner/v1beta/usage_service.rb', line 733

class ExportReservationsUsageRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Possible scope in which the reservation can be shared.
  module ShareType
    # No share type specified.
    SHARE_TYPE_UNSPECIFIED = 0

    # Default value, for which reservation is open to only owner project.
    SHARE_TYPE_LOCAL = 1

    # Shared-reservation is open to specific projects.
    SHARE_TYPE_SPECIFIC_PROJECTS = 2
  end
end

#start_date::Google::Type::Date

Returns Optional. The start date of reservations usage.

Returns:



733
734
735
736
737
738
739
740
741
742
743
744
745
746
747
748
# File 'proto_docs/google/cloud/capacityplanner/v1beta/usage_service.rb', line 733

class ExportReservationsUsageRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Possible scope in which the reservation can be shared.
  module ShareType
    # No share type specified.
    SHARE_TYPE_UNSPECIFIED = 0

    # Default value, for which reservation is open to only owner project.
    SHARE_TYPE_LOCAL = 1

    # Shared-reservation is open to specific projects.
    SHARE_TYPE_SPECIFIC_PROJECTS = 2
  end
end

#usage_aggregation_method::Google::Cloud::CapacityPlanner::V1beta::UsageHistory::AggregationMethod

Returns Required. The method that should be used to convert sampled reservations data to daily usage values.

Returns:



733
734
735
736
737
738
739
740
741
742
743
744
745
746
747
748
# File 'proto_docs/google/cloud/capacityplanner/v1beta/usage_service.rb', line 733

class ExportReservationsUsageRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Possible scope in which the reservation can be shared.
  module ShareType
    # No share type specified.
    SHARE_TYPE_UNSPECIFIED = 0

    # Default value, for which reservation is open to only owner project.
    SHARE_TYPE_LOCAL = 1

    # Shared-reservation is open to specific projects.
    SHARE_TYPE_SPECIFIC_PROJECTS = 2
  end
end