Class: Google::Cloud::CapacityPlanner::V1beta::ExportUsageHistoriesResponse
- Inherits:
-
Object
- Object
- Google::Cloud::CapacityPlanner::V1beta::ExportUsageHistoriesResponse
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/capacityplanner/v1beta/usage_service.rb
Overview
A response message for [UsageService.ExportUsageHistories].
Instance Attribute Summary collapse
-
#response ⇒ ::String
The response message for the usage history export.
Instance Attribute Details
#response ⇒ ::String
Returns The response message for the usage history export. In case of bigquery, it will also contain job id.
885 886 887 888 |
# File 'proto_docs/google/cloud/capacityplanner/v1beta/usage_service.rb', line 885 class ExportUsageHistoriesResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |