Module: Google::Cloud::CapacityPlanner::V1beta::Forecast::PredictionInterval

Defined in:
proto_docs/google/cloud/capacityplanner/v1beta/usage_service.rb

Overview

The prediction interval represented by a forecast.

Constant Summary collapse

PREDICTION_INTERVAL_UNSPECIFIED =

No prediction interval is specified.

0
PREDICTION_INTERVAL_90 =

This represents a prediction interval that has 90% confidence. For example, for a symmetric prediction interval, a PredictionInterval of PREDICTION_INTERVAL_90 means that the UPPER_BOUND will represent the 95th precentile.

1
PREDICTION_INTERVAL_50 =

This represents a prediction interval that has 50% confidence. For example, for a symmetric prediction interval, a PredictionInterval of PREDICTION_INTERVAL_50 means that the UPPER_BOUND will represent the 75th precentile.

2