Class: Google::Cloud::CapacityPlanner::V1beta::FutureReservation
- Inherits:
-
Object
- Object
- Google::Cloud::CapacityPlanner::V1beta::FutureReservation
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/capacityplanner/v1beta/future_reservation.rb
Overview
Repesents Future Reservation request which is part of aggregated reservations data response of "QueryReservations".
Defined Under Namespace
Classes: SpecificSKUProperties, Status, TimeWindow
Instance Attribute Summary collapse
-
#auto_created_reservations_delete_time ⇒ ::Google::Protobuf::Timestamp
Future timestamp when the FR auto-created reservations will be deleted by Compute Engine.
-
#auto_delete_auto_created_reservations ⇒ ::Boolean
Setting for enabling or disabling automatic deletion for auto-created reservation.
-
#create_time ⇒ ::Google::Protobuf::Timestamp
The creation timestamp for this future reservation.
-
#description ⇒ ::String
Description of the future reservation provided by user.
-
#future_reservation ⇒ ::String
The future reservation resource name.
-
#id ⇒ ::Integer
A unique identifier for this future reservation.
-
#name_prefix ⇒ ::String
Name prefix for the reservations to be created at the time of delivery.
- #owner_project_id ⇒ ::String
-
#share_settings ⇒ ::Google::Cloud::CapacityPlanner::V1beta::Allocation::ShareSettings
List of Projects/Folders to share with.
-
#specific_sku_properties ⇒ ::Google::Cloud::CapacityPlanner::V1beta::FutureReservation::SpecificSKUProperties
Future Reservation configuration to indicate instance properties and total count.
-
#status ⇒ ::Google::Cloud::CapacityPlanner::V1beta::FutureReservation::Status
Status of the Future Reservation.
-
#time_window ⇒ ::Google::Cloud::CapacityPlanner::V1beta::FutureReservation::TimeWindow
Time window for this Future Reservation.
-
#zone ⇒ ::String
URL of the Zone where this future reservation resides.
Instance Attribute Details
#auto_created_reservations_delete_time ⇒ ::Google::Protobuf::Timestamp
Returns Future timestamp when the FR auto-created reservations will be deleted by Compute Engine. Format of this field must be a valid RFC3339 value.
77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 |
# File 'proto_docs/google/cloud/capacityplanner/v1beta/future_reservation.rb', line 77 class FutureReservation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents specific SKU properties for the Future Reservation. # @!attribute [rw] instance_properties # @return [::Google::Cloud::CapacityPlanner::V1beta::Allocation::SpecificSKUAllocation::AllocatedInstanceProperties] # Properties of the SKU instances being reserved. # @!attribute [rw] total_count # @return [::Integer] # Total number of instances for which capacity assurance is requested at a # future time period. class SpecificSKUProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Represents time window for the Future Reservation. # @!attribute [rw] start_time # @return [::Google::Protobuf::Timestamp] # Start time of the Future Reservation. # @!attribute [rw] end_time # @return [::Google::Protobuf::Timestamp] # End time of the Future Reservation. class TimeWindow include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Represents status related to the future reservation. # @!attribute [rw] procurement_status # @return [::Google::Cloud::CapacityPlanner::V1beta::FutureReservation::Status::ProcurementStatus] # Current state of this Future Reservation # @!attribute [rw] lock_time # @return [::Google::Protobuf::Timestamp] # Time when Future Reservation would become LOCKED, after which no # modifications to Future Reservation will be allowed. Applicable only # after the Future Reservation is in the APPROVED state. The lock_time is # an RFC3339 string. The procurement_status will transition to PROCURING # state at this time. # @!attribute [rw] auto_created_reservations # @return [::Array<::String>] # Fully qualified urls of the automatically created reservations at # start_time. # @!attribute [rw] fulfilled_count # @return [::Integer] # This count indicates the fulfilled capacity so far. This is set during # "PROVISIONING" state. This count also includes capacity delivered as part # of existing matching reservations. class Status include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents procurement status of the Future Reservation. module ProcurementStatus # This is unused status value. PROCUREMENT_STATUS_UNSPECIFIED = 0 # Future reservation is pending approval by Google Cloud Platform. PENDING_APPROVAL = 1 # Future reservation is approved by Google Cloud Platform. APPROVED = 2 # Future reservation is committed by the customer. COMMITTED = 3 # Future reservation is rejected by Google Cloud Platform. DECLINED = 4 # Future reservation is cancelled by the customer. CANCELLED = 5 # Future reservation is being procured by Google Cloud Platform. Beyond # this point, Future reservation is locked and no further modifications # are allowed. PROCURING = 6 # Future reservation capacity is being provisioned. This state will be # entered after start_time, while reservations are being created to # provide total_count reserved instance slots. This state will not # persist past start_time + 24h. PROVISIONING = 7 # Future reservation is fulfilled completely. FULFILLED = 8 # Future reservation failed. No additional reservations were provided. FAILED = 9 # Future reservation is partially fulfilled. Additional reservations were # provided but did not reach total_count reserved instance slots. FAILED_PARTIALLY_FULFILLED = 10 # Related status for PlanningStatus.Draft. Transitions to # PENDING_APPROVAL upon user submitting FR. DRAFTING = 11 # An Amendment to the Future Reservation has been requested. If the # Amendment is declined, the Future Reservation will be restored to the # last known good state. PENDING_AMENDMENT_APPROVAL = 12 end end end |
#auto_delete_auto_created_reservations ⇒ ::Boolean
Returns Setting for enabling or disabling automatic deletion for auto-created reservation. If set to true, auto-created reservations will be deleted at Future Reservation's end time (default) or at user's defined timestamp if any of the [auto_created_reservations_delete_time, auto_created_reservations_duration] values is specified. For keeping auto-created reservation indefinitely, this value should be set to false.
77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 |
# File 'proto_docs/google/cloud/capacityplanner/v1beta/future_reservation.rb', line 77 class FutureReservation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents specific SKU properties for the Future Reservation. # @!attribute [rw] instance_properties # @return [::Google::Cloud::CapacityPlanner::V1beta::Allocation::SpecificSKUAllocation::AllocatedInstanceProperties] # Properties of the SKU instances being reserved. # @!attribute [rw] total_count # @return [::Integer] # Total number of instances for which capacity assurance is requested at a # future time period. class SpecificSKUProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Represents time window for the Future Reservation. # @!attribute [rw] start_time # @return [::Google::Protobuf::Timestamp] # Start time of the Future Reservation. # @!attribute [rw] end_time # @return [::Google::Protobuf::Timestamp] # End time of the Future Reservation. class TimeWindow include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Represents status related to the future reservation. # @!attribute [rw] procurement_status # @return [::Google::Cloud::CapacityPlanner::V1beta::FutureReservation::Status::ProcurementStatus] # Current state of this Future Reservation # @!attribute [rw] lock_time # @return [::Google::Protobuf::Timestamp] # Time when Future Reservation would become LOCKED, after which no # modifications to Future Reservation will be allowed. Applicable only # after the Future Reservation is in the APPROVED state. The lock_time is # an RFC3339 string. The procurement_status will transition to PROCURING # state at this time. # @!attribute [rw] auto_created_reservations # @return [::Array<::String>] # Fully qualified urls of the automatically created reservations at # start_time. # @!attribute [rw] fulfilled_count # @return [::Integer] # This count indicates the fulfilled capacity so far. This is set during # "PROVISIONING" state. This count also includes capacity delivered as part # of existing matching reservations. class Status include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents procurement status of the Future Reservation. module ProcurementStatus # This is unused status value. PROCUREMENT_STATUS_UNSPECIFIED = 0 # Future reservation is pending approval by Google Cloud Platform. PENDING_APPROVAL = 1 # Future reservation is approved by Google Cloud Platform. APPROVED = 2 # Future reservation is committed by the customer. COMMITTED = 3 # Future reservation is rejected by Google Cloud Platform. DECLINED = 4 # Future reservation is cancelled by the customer. CANCELLED = 5 # Future reservation is being procured by Google Cloud Platform. Beyond # this point, Future reservation is locked and no further modifications # are allowed. PROCURING = 6 # Future reservation capacity is being provisioned. This state will be # entered after start_time, while reservations are being created to # provide total_count reserved instance slots. This state will not # persist past start_time + 24h. PROVISIONING = 7 # Future reservation is fulfilled completely. FULFILLED = 8 # Future reservation failed. No additional reservations were provided. FAILED = 9 # Future reservation is partially fulfilled. Additional reservations were # provided but did not reach total_count reserved instance slots. FAILED_PARTIALLY_FULFILLED = 10 # Related status for PlanningStatus.Draft. Transitions to # PENDING_APPROVAL upon user submitting FR. DRAFTING = 11 # An Amendment to the Future Reservation has been requested. If the # Amendment is declined, the Future Reservation will be restored to the # last known good state. PENDING_AMENDMENT_APPROVAL = 12 end end end |
#create_time ⇒ ::Google::Protobuf::Timestamp
Returns The creation timestamp for this future reservation.
77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 |
# File 'proto_docs/google/cloud/capacityplanner/v1beta/future_reservation.rb', line 77 class FutureReservation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents specific SKU properties for the Future Reservation. # @!attribute [rw] instance_properties # @return [::Google::Cloud::CapacityPlanner::V1beta::Allocation::SpecificSKUAllocation::AllocatedInstanceProperties] # Properties of the SKU instances being reserved. # @!attribute [rw] total_count # @return [::Integer] # Total number of instances for which capacity assurance is requested at a # future time period. class SpecificSKUProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Represents time window for the Future Reservation. # @!attribute [rw] start_time # @return [::Google::Protobuf::Timestamp] # Start time of the Future Reservation. # @!attribute [rw] end_time # @return [::Google::Protobuf::Timestamp] # End time of the Future Reservation. class TimeWindow include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Represents status related to the future reservation. # @!attribute [rw] procurement_status # @return [::Google::Cloud::CapacityPlanner::V1beta::FutureReservation::Status::ProcurementStatus] # Current state of this Future Reservation # @!attribute [rw] lock_time # @return [::Google::Protobuf::Timestamp] # Time when Future Reservation would become LOCKED, after which no # modifications to Future Reservation will be allowed. Applicable only # after the Future Reservation is in the APPROVED state. The lock_time is # an RFC3339 string. The procurement_status will transition to PROCURING # state at this time. # @!attribute [rw] auto_created_reservations # @return [::Array<::String>] # Fully qualified urls of the automatically created reservations at # start_time. # @!attribute [rw] fulfilled_count # @return [::Integer] # This count indicates the fulfilled capacity so far. This is set during # "PROVISIONING" state. This count also includes capacity delivered as part # of existing matching reservations. class Status include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents procurement status of the Future Reservation. module ProcurementStatus # This is unused status value. PROCUREMENT_STATUS_UNSPECIFIED = 0 # Future reservation is pending approval by Google Cloud Platform. PENDING_APPROVAL = 1 # Future reservation is approved by Google Cloud Platform. APPROVED = 2 # Future reservation is committed by the customer. COMMITTED = 3 # Future reservation is rejected by Google Cloud Platform. DECLINED = 4 # Future reservation is cancelled by the customer. CANCELLED = 5 # Future reservation is being procured by Google Cloud Platform. Beyond # this point, Future reservation is locked and no further modifications # are allowed. PROCURING = 6 # Future reservation capacity is being provisioned. This state will be # entered after start_time, while reservations are being created to # provide total_count reserved instance slots. This state will not # persist past start_time + 24h. PROVISIONING = 7 # Future reservation is fulfilled completely. FULFILLED = 8 # Future reservation failed. No additional reservations were provided. FAILED = 9 # Future reservation is partially fulfilled. Additional reservations were # provided but did not reach total_count reserved instance slots. FAILED_PARTIALLY_FULFILLED = 10 # Related status for PlanningStatus.Draft. Transitions to # PENDING_APPROVAL upon user submitting FR. DRAFTING = 11 # An Amendment to the Future Reservation has been requested. If the # Amendment is declined, the Future Reservation will be restored to the # last known good state. PENDING_AMENDMENT_APPROVAL = 12 end end end |
#description ⇒ ::String
Returns Description of the future reservation provided by user.
77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 |
# File 'proto_docs/google/cloud/capacityplanner/v1beta/future_reservation.rb', line 77 class FutureReservation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents specific SKU properties for the Future Reservation. # @!attribute [rw] instance_properties # @return [::Google::Cloud::CapacityPlanner::V1beta::Allocation::SpecificSKUAllocation::AllocatedInstanceProperties] # Properties of the SKU instances being reserved. # @!attribute [rw] total_count # @return [::Integer] # Total number of instances for which capacity assurance is requested at a # future time period. class SpecificSKUProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Represents time window for the Future Reservation. # @!attribute [rw] start_time # @return [::Google::Protobuf::Timestamp] # Start time of the Future Reservation. # @!attribute [rw] end_time # @return [::Google::Protobuf::Timestamp] # End time of the Future Reservation. class TimeWindow include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Represents status related to the future reservation. # @!attribute [rw] procurement_status # @return [::Google::Cloud::CapacityPlanner::V1beta::FutureReservation::Status::ProcurementStatus] # Current state of this Future Reservation # @!attribute [rw] lock_time # @return [::Google::Protobuf::Timestamp] # Time when Future Reservation would become LOCKED, after which no # modifications to Future Reservation will be allowed. Applicable only # after the Future Reservation is in the APPROVED state. The lock_time is # an RFC3339 string. The procurement_status will transition to PROCURING # state at this time. # @!attribute [rw] auto_created_reservations # @return [::Array<::String>] # Fully qualified urls of the automatically created reservations at # start_time. # @!attribute [rw] fulfilled_count # @return [::Integer] # This count indicates the fulfilled capacity so far. This is set during # "PROVISIONING" state. This count also includes capacity delivered as part # of existing matching reservations. class Status include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents procurement status of the Future Reservation. module ProcurementStatus # This is unused status value. PROCUREMENT_STATUS_UNSPECIFIED = 0 # Future reservation is pending approval by Google Cloud Platform. PENDING_APPROVAL = 1 # Future reservation is approved by Google Cloud Platform. APPROVED = 2 # Future reservation is committed by the customer. COMMITTED = 3 # Future reservation is rejected by Google Cloud Platform. DECLINED = 4 # Future reservation is cancelled by the customer. CANCELLED = 5 # Future reservation is being procured by Google Cloud Platform. Beyond # this point, Future reservation is locked and no further modifications # are allowed. PROCURING = 6 # Future reservation capacity is being provisioned. This state will be # entered after start_time, while reservations are being created to # provide total_count reserved instance slots. This state will not # persist past start_time + 24h. PROVISIONING = 7 # Future reservation is fulfilled completely. FULFILLED = 8 # Future reservation failed. No additional reservations were provided. FAILED = 9 # Future reservation is partially fulfilled. Additional reservations were # provided but did not reach total_count reserved instance slots. FAILED_PARTIALLY_FULFILLED = 10 # Related status for PlanningStatus.Draft. Transitions to # PENDING_APPROVAL upon user submitting FR. DRAFTING = 11 # An Amendment to the Future Reservation has been requested. If the # Amendment is declined, the Future Reservation will be restored to the # last known good state. PENDING_AMENDMENT_APPROVAL = 12 end end end |
#future_reservation ⇒ ::String
Returns The future reservation resource name.
77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 |
# File 'proto_docs/google/cloud/capacityplanner/v1beta/future_reservation.rb', line 77 class FutureReservation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents specific SKU properties for the Future Reservation. # @!attribute [rw] instance_properties # @return [::Google::Cloud::CapacityPlanner::V1beta::Allocation::SpecificSKUAllocation::AllocatedInstanceProperties] # Properties of the SKU instances being reserved. # @!attribute [rw] total_count # @return [::Integer] # Total number of instances for which capacity assurance is requested at a # future time period. class SpecificSKUProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Represents time window for the Future Reservation. # @!attribute [rw] start_time # @return [::Google::Protobuf::Timestamp] # Start time of the Future Reservation. # @!attribute [rw] end_time # @return [::Google::Protobuf::Timestamp] # End time of the Future Reservation. class TimeWindow include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Represents status related to the future reservation. # @!attribute [rw] procurement_status # @return [::Google::Cloud::CapacityPlanner::V1beta::FutureReservation::Status::ProcurementStatus] # Current state of this Future Reservation # @!attribute [rw] lock_time # @return [::Google::Protobuf::Timestamp] # Time when Future Reservation would become LOCKED, after which no # modifications to Future Reservation will be allowed. Applicable only # after the Future Reservation is in the APPROVED state. The lock_time is # an RFC3339 string. The procurement_status will transition to PROCURING # state at this time. # @!attribute [rw] auto_created_reservations # @return [::Array<::String>] # Fully qualified urls of the automatically created reservations at # start_time. # @!attribute [rw] fulfilled_count # @return [::Integer] # This count indicates the fulfilled capacity so far. This is set during # "PROVISIONING" state. This count also includes capacity delivered as part # of existing matching reservations. class Status include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents procurement status of the Future Reservation. module ProcurementStatus # This is unused status value. PROCUREMENT_STATUS_UNSPECIFIED = 0 # Future reservation is pending approval by Google Cloud Platform. PENDING_APPROVAL = 1 # Future reservation is approved by Google Cloud Platform. APPROVED = 2 # Future reservation is committed by the customer. COMMITTED = 3 # Future reservation is rejected by Google Cloud Platform. DECLINED = 4 # Future reservation is cancelled by the customer. CANCELLED = 5 # Future reservation is being procured by Google Cloud Platform. Beyond # this point, Future reservation is locked and no further modifications # are allowed. PROCURING = 6 # Future reservation capacity is being provisioned. This state will be # entered after start_time, while reservations are being created to # provide total_count reserved instance slots. This state will not # persist past start_time + 24h. PROVISIONING = 7 # Future reservation is fulfilled completely. FULFILLED = 8 # Future reservation failed. No additional reservations were provided. FAILED = 9 # Future reservation is partially fulfilled. Additional reservations were # provided but did not reach total_count reserved instance slots. FAILED_PARTIALLY_FULFILLED = 10 # Related status for PlanningStatus.Draft. Transitions to # PENDING_APPROVAL upon user submitting FR. DRAFTING = 11 # An Amendment to the Future Reservation has been requested. If the # Amendment is declined, the Future Reservation will be restored to the # last known good state. PENDING_AMENDMENT_APPROVAL = 12 end end end |
#id ⇒ ::Integer
Returns A unique identifier for this future reservation. The server defines this identifier.
77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 |
# File 'proto_docs/google/cloud/capacityplanner/v1beta/future_reservation.rb', line 77 class FutureReservation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents specific SKU properties for the Future Reservation. # @!attribute [rw] instance_properties # @return [::Google::Cloud::CapacityPlanner::V1beta::Allocation::SpecificSKUAllocation::AllocatedInstanceProperties] # Properties of the SKU instances being reserved. # @!attribute [rw] total_count # @return [::Integer] # Total number of instances for which capacity assurance is requested at a # future time period. class SpecificSKUProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Represents time window for the Future Reservation. # @!attribute [rw] start_time # @return [::Google::Protobuf::Timestamp] # Start time of the Future Reservation. # @!attribute [rw] end_time # @return [::Google::Protobuf::Timestamp] # End time of the Future Reservation. class TimeWindow include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Represents status related to the future reservation. # @!attribute [rw] procurement_status # @return [::Google::Cloud::CapacityPlanner::V1beta::FutureReservation::Status::ProcurementStatus] # Current state of this Future Reservation # @!attribute [rw] lock_time # @return [::Google::Protobuf::Timestamp] # Time when Future Reservation would become LOCKED, after which no # modifications to Future Reservation will be allowed. Applicable only # after the Future Reservation is in the APPROVED state. The lock_time is # an RFC3339 string. The procurement_status will transition to PROCURING # state at this time. # @!attribute [rw] auto_created_reservations # @return [::Array<::String>] # Fully qualified urls of the automatically created reservations at # start_time. # @!attribute [rw] fulfilled_count # @return [::Integer] # This count indicates the fulfilled capacity so far. This is set during # "PROVISIONING" state. This count also includes capacity delivered as part # of existing matching reservations. class Status include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents procurement status of the Future Reservation. module ProcurementStatus # This is unused status value. PROCUREMENT_STATUS_UNSPECIFIED = 0 # Future reservation is pending approval by Google Cloud Platform. PENDING_APPROVAL = 1 # Future reservation is approved by Google Cloud Platform. APPROVED = 2 # Future reservation is committed by the customer. COMMITTED = 3 # Future reservation is rejected by Google Cloud Platform. DECLINED = 4 # Future reservation is cancelled by the customer. CANCELLED = 5 # Future reservation is being procured by Google Cloud Platform. Beyond # this point, Future reservation is locked and no further modifications # are allowed. PROCURING = 6 # Future reservation capacity is being provisioned. This state will be # entered after start_time, while reservations are being created to # provide total_count reserved instance slots. This state will not # persist past start_time + 24h. PROVISIONING = 7 # Future reservation is fulfilled completely. FULFILLED = 8 # Future reservation failed. No additional reservations were provided. FAILED = 9 # Future reservation is partially fulfilled. Additional reservations were # provided but did not reach total_count reserved instance slots. FAILED_PARTIALLY_FULFILLED = 10 # Related status for PlanningStatus.Draft. Transitions to # PENDING_APPROVAL upon user submitting FR. DRAFTING = 11 # An Amendment to the Future Reservation has been requested. If the # Amendment is declined, the Future Reservation will be restored to the # last known good state. PENDING_AMENDMENT_APPROVAL = 12 end end end |
#name_prefix ⇒ ::String
Returns Name prefix for the reservations to be created at the time of
delivery. The name prefix must comply with RFC1035.
Maximum allowed length for name prefix is 20. Automatically created
reservations name format will be
77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 |
# File 'proto_docs/google/cloud/capacityplanner/v1beta/future_reservation.rb', line 77 class FutureReservation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents specific SKU properties for the Future Reservation. # @!attribute [rw] instance_properties # @return [::Google::Cloud::CapacityPlanner::V1beta::Allocation::SpecificSKUAllocation::AllocatedInstanceProperties] # Properties of the SKU instances being reserved. # @!attribute [rw] total_count # @return [::Integer] # Total number of instances for which capacity assurance is requested at a # future time period. class SpecificSKUProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Represents time window for the Future Reservation. # @!attribute [rw] start_time # @return [::Google::Protobuf::Timestamp] # Start time of the Future Reservation. # @!attribute [rw] end_time # @return [::Google::Protobuf::Timestamp] # End time of the Future Reservation. class TimeWindow include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Represents status related to the future reservation. # @!attribute [rw] procurement_status # @return [::Google::Cloud::CapacityPlanner::V1beta::FutureReservation::Status::ProcurementStatus] # Current state of this Future Reservation # @!attribute [rw] lock_time # @return [::Google::Protobuf::Timestamp] # Time when Future Reservation would become LOCKED, after which no # modifications to Future Reservation will be allowed. Applicable only # after the Future Reservation is in the APPROVED state. The lock_time is # an RFC3339 string. The procurement_status will transition to PROCURING # state at this time. # @!attribute [rw] auto_created_reservations # @return [::Array<::String>] # Fully qualified urls of the automatically created reservations at # start_time. # @!attribute [rw] fulfilled_count # @return [::Integer] # This count indicates the fulfilled capacity so far. This is set during # "PROVISIONING" state. This count also includes capacity delivered as part # of existing matching reservations. class Status include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents procurement status of the Future Reservation. module ProcurementStatus # This is unused status value. PROCUREMENT_STATUS_UNSPECIFIED = 0 # Future reservation is pending approval by Google Cloud Platform. PENDING_APPROVAL = 1 # Future reservation is approved by Google Cloud Platform. APPROVED = 2 # Future reservation is committed by the customer. COMMITTED = 3 # Future reservation is rejected by Google Cloud Platform. DECLINED = 4 # Future reservation is cancelled by the customer. CANCELLED = 5 # Future reservation is being procured by Google Cloud Platform. Beyond # this point, Future reservation is locked and no further modifications # are allowed. PROCURING = 6 # Future reservation capacity is being provisioned. This state will be # entered after start_time, while reservations are being created to # provide total_count reserved instance slots. This state will not # persist past start_time + 24h. PROVISIONING = 7 # Future reservation is fulfilled completely. FULFILLED = 8 # Future reservation failed. No additional reservations were provided. FAILED = 9 # Future reservation is partially fulfilled. Additional reservations were # provided but did not reach total_count reserved instance slots. FAILED_PARTIALLY_FULFILLED = 10 # Related status for PlanningStatus.Draft. Transitions to # PENDING_APPROVAL upon user submitting FR. DRAFTING = 11 # An Amendment to the Future Reservation has been requested. If the # Amendment is declined, the Future Reservation will be restored to the # last known good state. PENDING_AMENDMENT_APPROVAL = 12 end end end |
#owner_project_id ⇒ ::String
77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 |
# File 'proto_docs/google/cloud/capacityplanner/v1beta/future_reservation.rb', line 77 class FutureReservation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents specific SKU properties for the Future Reservation. # @!attribute [rw] instance_properties # @return [::Google::Cloud::CapacityPlanner::V1beta::Allocation::SpecificSKUAllocation::AllocatedInstanceProperties] # Properties of the SKU instances being reserved. # @!attribute [rw] total_count # @return [::Integer] # Total number of instances for which capacity assurance is requested at a # future time period. class SpecificSKUProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Represents time window for the Future Reservation. # @!attribute [rw] start_time # @return [::Google::Protobuf::Timestamp] # Start time of the Future Reservation. # @!attribute [rw] end_time # @return [::Google::Protobuf::Timestamp] # End time of the Future Reservation. class TimeWindow include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Represents status related to the future reservation. # @!attribute [rw] procurement_status # @return [::Google::Cloud::CapacityPlanner::V1beta::FutureReservation::Status::ProcurementStatus] # Current state of this Future Reservation # @!attribute [rw] lock_time # @return [::Google::Protobuf::Timestamp] # Time when Future Reservation would become LOCKED, after which no # modifications to Future Reservation will be allowed. Applicable only # after the Future Reservation is in the APPROVED state. The lock_time is # an RFC3339 string. The procurement_status will transition to PROCURING # state at this time. # @!attribute [rw] auto_created_reservations # @return [::Array<::String>] # Fully qualified urls of the automatically created reservations at # start_time. # @!attribute [rw] fulfilled_count # @return [::Integer] # This count indicates the fulfilled capacity so far. This is set during # "PROVISIONING" state. This count also includes capacity delivered as part # of existing matching reservations. class Status include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents procurement status of the Future Reservation. module ProcurementStatus # This is unused status value. PROCUREMENT_STATUS_UNSPECIFIED = 0 # Future reservation is pending approval by Google Cloud Platform. PENDING_APPROVAL = 1 # Future reservation is approved by Google Cloud Platform. APPROVED = 2 # Future reservation is committed by the customer. COMMITTED = 3 # Future reservation is rejected by Google Cloud Platform. DECLINED = 4 # Future reservation is cancelled by the customer. CANCELLED = 5 # Future reservation is being procured by Google Cloud Platform. Beyond # this point, Future reservation is locked and no further modifications # are allowed. PROCURING = 6 # Future reservation capacity is being provisioned. This state will be # entered after start_time, while reservations are being created to # provide total_count reserved instance slots. This state will not # persist past start_time + 24h. PROVISIONING = 7 # Future reservation is fulfilled completely. FULFILLED = 8 # Future reservation failed. No additional reservations were provided. FAILED = 9 # Future reservation is partially fulfilled. Additional reservations were # provided but did not reach total_count reserved instance slots. FAILED_PARTIALLY_FULFILLED = 10 # Related status for PlanningStatus.Draft. Transitions to # PENDING_APPROVAL upon user submitting FR. DRAFTING = 11 # An Amendment to the Future Reservation has been requested. If the # Amendment is declined, the Future Reservation will be restored to the # last known good state. PENDING_AMENDMENT_APPROVAL = 12 end end end |
#share_settings ⇒ ::Google::Cloud::CapacityPlanner::V1beta::Allocation::ShareSettings
Returns List of Projects/Folders to share with.
77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 |
# File 'proto_docs/google/cloud/capacityplanner/v1beta/future_reservation.rb', line 77 class FutureReservation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents specific SKU properties for the Future Reservation. # @!attribute [rw] instance_properties # @return [::Google::Cloud::CapacityPlanner::V1beta::Allocation::SpecificSKUAllocation::AllocatedInstanceProperties] # Properties of the SKU instances being reserved. # @!attribute [rw] total_count # @return [::Integer] # Total number of instances for which capacity assurance is requested at a # future time period. class SpecificSKUProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Represents time window for the Future Reservation. # @!attribute [rw] start_time # @return [::Google::Protobuf::Timestamp] # Start time of the Future Reservation. # @!attribute [rw] end_time # @return [::Google::Protobuf::Timestamp] # End time of the Future Reservation. class TimeWindow include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Represents status related to the future reservation. # @!attribute [rw] procurement_status # @return [::Google::Cloud::CapacityPlanner::V1beta::FutureReservation::Status::ProcurementStatus] # Current state of this Future Reservation # @!attribute [rw] lock_time # @return [::Google::Protobuf::Timestamp] # Time when Future Reservation would become LOCKED, after which no # modifications to Future Reservation will be allowed. Applicable only # after the Future Reservation is in the APPROVED state. The lock_time is # an RFC3339 string. The procurement_status will transition to PROCURING # state at this time. # @!attribute [rw] auto_created_reservations # @return [::Array<::String>] # Fully qualified urls of the automatically created reservations at # start_time. # @!attribute [rw] fulfilled_count # @return [::Integer] # This count indicates the fulfilled capacity so far. This is set during # "PROVISIONING" state. This count also includes capacity delivered as part # of existing matching reservations. class Status include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents procurement status of the Future Reservation. module ProcurementStatus # This is unused status value. PROCUREMENT_STATUS_UNSPECIFIED = 0 # Future reservation is pending approval by Google Cloud Platform. PENDING_APPROVAL = 1 # Future reservation is approved by Google Cloud Platform. APPROVED = 2 # Future reservation is committed by the customer. COMMITTED = 3 # Future reservation is rejected by Google Cloud Platform. DECLINED = 4 # Future reservation is cancelled by the customer. CANCELLED = 5 # Future reservation is being procured by Google Cloud Platform. Beyond # this point, Future reservation is locked and no further modifications # are allowed. PROCURING = 6 # Future reservation capacity is being provisioned. This state will be # entered after start_time, while reservations are being created to # provide total_count reserved instance slots. This state will not # persist past start_time + 24h. PROVISIONING = 7 # Future reservation is fulfilled completely. FULFILLED = 8 # Future reservation failed. No additional reservations were provided. FAILED = 9 # Future reservation is partially fulfilled. Additional reservations were # provided but did not reach total_count reserved instance slots. FAILED_PARTIALLY_FULFILLED = 10 # Related status for PlanningStatus.Draft. Transitions to # PENDING_APPROVAL upon user submitting FR. DRAFTING = 11 # An Amendment to the Future Reservation has been requested. If the # Amendment is declined, the Future Reservation will be restored to the # last known good state. PENDING_AMENDMENT_APPROVAL = 12 end end end |
#specific_sku_properties ⇒ ::Google::Cloud::CapacityPlanner::V1beta::FutureReservation::SpecificSKUProperties
Returns Future Reservation configuration to indicate instance properties and total count.
77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 |
# File 'proto_docs/google/cloud/capacityplanner/v1beta/future_reservation.rb', line 77 class FutureReservation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents specific SKU properties for the Future Reservation. # @!attribute [rw] instance_properties # @return [::Google::Cloud::CapacityPlanner::V1beta::Allocation::SpecificSKUAllocation::AllocatedInstanceProperties] # Properties of the SKU instances being reserved. # @!attribute [rw] total_count # @return [::Integer] # Total number of instances for which capacity assurance is requested at a # future time period. class SpecificSKUProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Represents time window for the Future Reservation. # @!attribute [rw] start_time # @return [::Google::Protobuf::Timestamp] # Start time of the Future Reservation. # @!attribute [rw] end_time # @return [::Google::Protobuf::Timestamp] # End time of the Future Reservation. class TimeWindow include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Represents status related to the future reservation. # @!attribute [rw] procurement_status # @return [::Google::Cloud::CapacityPlanner::V1beta::FutureReservation::Status::ProcurementStatus] # Current state of this Future Reservation # @!attribute [rw] lock_time # @return [::Google::Protobuf::Timestamp] # Time when Future Reservation would become LOCKED, after which no # modifications to Future Reservation will be allowed. Applicable only # after the Future Reservation is in the APPROVED state. The lock_time is # an RFC3339 string. The procurement_status will transition to PROCURING # state at this time. # @!attribute [rw] auto_created_reservations # @return [::Array<::String>] # Fully qualified urls of the automatically created reservations at # start_time. # @!attribute [rw] fulfilled_count # @return [::Integer] # This count indicates the fulfilled capacity so far. This is set during # "PROVISIONING" state. This count also includes capacity delivered as part # of existing matching reservations. class Status include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents procurement status of the Future Reservation. module ProcurementStatus # This is unused status value. PROCUREMENT_STATUS_UNSPECIFIED = 0 # Future reservation is pending approval by Google Cloud Platform. PENDING_APPROVAL = 1 # Future reservation is approved by Google Cloud Platform. APPROVED = 2 # Future reservation is committed by the customer. COMMITTED = 3 # Future reservation is rejected by Google Cloud Platform. DECLINED = 4 # Future reservation is cancelled by the customer. CANCELLED = 5 # Future reservation is being procured by Google Cloud Platform. Beyond # this point, Future reservation is locked and no further modifications # are allowed. PROCURING = 6 # Future reservation capacity is being provisioned. This state will be # entered after start_time, while reservations are being created to # provide total_count reserved instance slots. This state will not # persist past start_time + 24h. PROVISIONING = 7 # Future reservation is fulfilled completely. FULFILLED = 8 # Future reservation failed. No additional reservations were provided. FAILED = 9 # Future reservation is partially fulfilled. Additional reservations were # provided but did not reach total_count reserved instance slots. FAILED_PARTIALLY_FULFILLED = 10 # Related status for PlanningStatus.Draft. Transitions to # PENDING_APPROVAL upon user submitting FR. DRAFTING = 11 # An Amendment to the Future Reservation has been requested. If the # Amendment is declined, the Future Reservation will be restored to the # last known good state. PENDING_AMENDMENT_APPROVAL = 12 end end end |
#status ⇒ ::Google::Cloud::CapacityPlanner::V1beta::FutureReservation::Status
Returns Status of the Future Reservation.
77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 |
# File 'proto_docs/google/cloud/capacityplanner/v1beta/future_reservation.rb', line 77 class FutureReservation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents specific SKU properties for the Future Reservation. # @!attribute [rw] instance_properties # @return [::Google::Cloud::CapacityPlanner::V1beta::Allocation::SpecificSKUAllocation::AllocatedInstanceProperties] # Properties of the SKU instances being reserved. # @!attribute [rw] total_count # @return [::Integer] # Total number of instances for which capacity assurance is requested at a # future time period. class SpecificSKUProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Represents time window for the Future Reservation. # @!attribute [rw] start_time # @return [::Google::Protobuf::Timestamp] # Start time of the Future Reservation. # @!attribute [rw] end_time # @return [::Google::Protobuf::Timestamp] # End time of the Future Reservation. class TimeWindow include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Represents status related to the future reservation. # @!attribute [rw] procurement_status # @return [::Google::Cloud::CapacityPlanner::V1beta::FutureReservation::Status::ProcurementStatus] # Current state of this Future Reservation # @!attribute [rw] lock_time # @return [::Google::Protobuf::Timestamp] # Time when Future Reservation would become LOCKED, after which no # modifications to Future Reservation will be allowed. Applicable only # after the Future Reservation is in the APPROVED state. The lock_time is # an RFC3339 string. The procurement_status will transition to PROCURING # state at this time. # @!attribute [rw] auto_created_reservations # @return [::Array<::String>] # Fully qualified urls of the automatically created reservations at # start_time. # @!attribute [rw] fulfilled_count # @return [::Integer] # This count indicates the fulfilled capacity so far. This is set during # "PROVISIONING" state. This count also includes capacity delivered as part # of existing matching reservations. class Status include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents procurement status of the Future Reservation. module ProcurementStatus # This is unused status value. PROCUREMENT_STATUS_UNSPECIFIED = 0 # Future reservation is pending approval by Google Cloud Platform. PENDING_APPROVAL = 1 # Future reservation is approved by Google Cloud Platform. APPROVED = 2 # Future reservation is committed by the customer. COMMITTED = 3 # Future reservation is rejected by Google Cloud Platform. DECLINED = 4 # Future reservation is cancelled by the customer. CANCELLED = 5 # Future reservation is being procured by Google Cloud Platform. Beyond # this point, Future reservation is locked and no further modifications # are allowed. PROCURING = 6 # Future reservation capacity is being provisioned. This state will be # entered after start_time, while reservations are being created to # provide total_count reserved instance slots. This state will not # persist past start_time + 24h. PROVISIONING = 7 # Future reservation is fulfilled completely. FULFILLED = 8 # Future reservation failed. No additional reservations were provided. FAILED = 9 # Future reservation is partially fulfilled. Additional reservations were # provided but did not reach total_count reserved instance slots. FAILED_PARTIALLY_FULFILLED = 10 # Related status for PlanningStatus.Draft. Transitions to # PENDING_APPROVAL upon user submitting FR. DRAFTING = 11 # An Amendment to the Future Reservation has been requested. If the # Amendment is declined, the Future Reservation will be restored to the # last known good state. PENDING_AMENDMENT_APPROVAL = 12 end end end |
#time_window ⇒ ::Google::Cloud::CapacityPlanner::V1beta::FutureReservation::TimeWindow
Returns Time window for this Future Reservation.
77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 |
# File 'proto_docs/google/cloud/capacityplanner/v1beta/future_reservation.rb', line 77 class FutureReservation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents specific SKU properties for the Future Reservation. # @!attribute [rw] instance_properties # @return [::Google::Cloud::CapacityPlanner::V1beta::Allocation::SpecificSKUAllocation::AllocatedInstanceProperties] # Properties of the SKU instances being reserved. # @!attribute [rw] total_count # @return [::Integer] # Total number of instances for which capacity assurance is requested at a # future time period. class SpecificSKUProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Represents time window for the Future Reservation. # @!attribute [rw] start_time # @return [::Google::Protobuf::Timestamp] # Start time of the Future Reservation. # @!attribute [rw] end_time # @return [::Google::Protobuf::Timestamp] # End time of the Future Reservation. class TimeWindow include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Represents status related to the future reservation. # @!attribute [rw] procurement_status # @return [::Google::Cloud::CapacityPlanner::V1beta::FutureReservation::Status::ProcurementStatus] # Current state of this Future Reservation # @!attribute [rw] lock_time # @return [::Google::Protobuf::Timestamp] # Time when Future Reservation would become LOCKED, after which no # modifications to Future Reservation will be allowed. Applicable only # after the Future Reservation is in the APPROVED state. The lock_time is # an RFC3339 string. The procurement_status will transition to PROCURING # state at this time. # @!attribute [rw] auto_created_reservations # @return [::Array<::String>] # Fully qualified urls of the automatically created reservations at # start_time. # @!attribute [rw] fulfilled_count # @return [::Integer] # This count indicates the fulfilled capacity so far. This is set during # "PROVISIONING" state. This count also includes capacity delivered as part # of existing matching reservations. class Status include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents procurement status of the Future Reservation. module ProcurementStatus # This is unused status value. PROCUREMENT_STATUS_UNSPECIFIED = 0 # Future reservation is pending approval by Google Cloud Platform. PENDING_APPROVAL = 1 # Future reservation is approved by Google Cloud Platform. APPROVED = 2 # Future reservation is committed by the customer. COMMITTED = 3 # Future reservation is rejected by Google Cloud Platform. DECLINED = 4 # Future reservation is cancelled by the customer. CANCELLED = 5 # Future reservation is being procured by Google Cloud Platform. Beyond # this point, Future reservation is locked and no further modifications # are allowed. PROCURING = 6 # Future reservation capacity is being provisioned. This state will be # entered after start_time, while reservations are being created to # provide total_count reserved instance slots. This state will not # persist past start_time + 24h. PROVISIONING = 7 # Future reservation is fulfilled completely. FULFILLED = 8 # Future reservation failed. No additional reservations were provided. FAILED = 9 # Future reservation is partially fulfilled. Additional reservations were # provided but did not reach total_count reserved instance slots. FAILED_PARTIALLY_FULFILLED = 10 # Related status for PlanningStatus.Draft. Transitions to # PENDING_APPROVAL upon user submitting FR. DRAFTING = 11 # An Amendment to the Future Reservation has been requested. If the # Amendment is declined, the Future Reservation will be restored to the # last known good state. PENDING_AMENDMENT_APPROVAL = 12 end end end |
#zone ⇒ ::String
Returns URL of the Zone where this future reservation resides.
77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 |
# File 'proto_docs/google/cloud/capacityplanner/v1beta/future_reservation.rb', line 77 class FutureReservation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents specific SKU properties for the Future Reservation. # @!attribute [rw] instance_properties # @return [::Google::Cloud::CapacityPlanner::V1beta::Allocation::SpecificSKUAllocation::AllocatedInstanceProperties] # Properties of the SKU instances being reserved. # @!attribute [rw] total_count # @return [::Integer] # Total number of instances for which capacity assurance is requested at a # future time period. class SpecificSKUProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Represents time window for the Future Reservation. # @!attribute [rw] start_time # @return [::Google::Protobuf::Timestamp] # Start time of the Future Reservation. # @!attribute [rw] end_time # @return [::Google::Protobuf::Timestamp] # End time of the Future Reservation. class TimeWindow include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Represents status related to the future reservation. # @!attribute [rw] procurement_status # @return [::Google::Cloud::CapacityPlanner::V1beta::FutureReservation::Status::ProcurementStatus] # Current state of this Future Reservation # @!attribute [rw] lock_time # @return [::Google::Protobuf::Timestamp] # Time when Future Reservation would become LOCKED, after which no # modifications to Future Reservation will be allowed. Applicable only # after the Future Reservation is in the APPROVED state. The lock_time is # an RFC3339 string. The procurement_status will transition to PROCURING # state at this time. # @!attribute [rw] auto_created_reservations # @return [::Array<::String>] # Fully qualified urls of the automatically created reservations at # start_time. # @!attribute [rw] fulfilled_count # @return [::Integer] # This count indicates the fulfilled capacity so far. This is set during # "PROVISIONING" state. This count also includes capacity delivered as part # of existing matching reservations. class Status include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents procurement status of the Future Reservation. module ProcurementStatus # This is unused status value. PROCUREMENT_STATUS_UNSPECIFIED = 0 # Future reservation is pending approval by Google Cloud Platform. PENDING_APPROVAL = 1 # Future reservation is approved by Google Cloud Platform. APPROVED = 2 # Future reservation is committed by the customer. COMMITTED = 3 # Future reservation is rejected by Google Cloud Platform. DECLINED = 4 # Future reservation is cancelled by the customer. CANCELLED = 5 # Future reservation is being procured by Google Cloud Platform. Beyond # this point, Future reservation is locked and no further modifications # are allowed. PROCURING = 6 # Future reservation capacity is being provisioned. This state will be # entered after start_time, while reservations are being created to # provide total_count reserved instance slots. This state will not # persist past start_time + 24h. PROVISIONING = 7 # Future reservation is fulfilled completely. FULFILLED = 8 # Future reservation failed. No additional reservations were provided. FAILED = 9 # Future reservation is partially fulfilled. Additional reservations were # provided but did not reach total_count reserved instance slots. FAILED_PARTIALLY_FULFILLED = 10 # Related status for PlanningStatus.Draft. Transitions to # PENDING_APPROVAL upon user submitting FR. DRAFTING = 11 # An Amendment to the Future Reservation has been requested. If the # Amendment is declined, the Future Reservation will be restored to the # last known good state. PENDING_AMENDMENT_APPROVAL = 12 end end end |