Class: Google::Cloud::CapacityPlanner::V1beta::FutureReservation::SpecificSKUProperties

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/capacityplanner/v1beta/future_reservation.rb

Overview

Represents specific SKU properties for the Future Reservation.

Instance Attribute Summary collapse

Instance Attribute Details

#instance_properties::Google::Cloud::CapacityPlanner::V1beta::Allocation::SpecificSKUAllocation::AllocatedInstanceProperties

Returns Properties of the SKU instances being reserved.



89
90
91
92
# File 'proto_docs/google/cloud/capacityplanner/v1beta/future_reservation.rb', line 89

class SpecificSKUProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#total_count::Integer

Returns Total number of instances for which capacity assurance is requested at a future time period.

Returns:

  • (::Integer)

    Total number of instances for which capacity assurance is requested at a future time period.



89
90
91
92
# File 'proto_docs/google/cloud/capacityplanner/v1beta/future_reservation.rb', line 89

class SpecificSKUProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end