Class: Google::Cloud::CapacityPlanner::V1beta::LocationIdentifier

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/capacityplanner/v1beta/location.rb

Overview

Identifier for a Google Cloud Platform location.

Defined Under Namespace

Classes: LinkedLocation

Instance Attribute Summary collapse

Instance Attribute Details

#linked_locations::Array<::Google::Cloud::CapacityPlanner::V1beta::LocationIdentifier::LinkedLocation>

Returns Optional. Other linked locations.

Returns:



35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
# File 'proto_docs/google/cloud/capacityplanner/v1beta/location.rb', line 35

class LocationIdentifier
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] location_level
  #   @return [::Google::Cloud::CapacityPlanner::V1beta::LocationLevel]
  #     The location level such as a region.
  # @!attribute [rw] location
  #   @return [::String]
  #     Required. The linked cloud location.
  # @!attribute [rw] label
  #   @return [::String]
  class LinkedLocation
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#location_level::Google::Cloud::CapacityPlanner::V1beta::LocationLevel

Returns The location level such as a region.

Returns:



35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
# File 'proto_docs/google/cloud/capacityplanner/v1beta/location.rb', line 35

class LocationIdentifier
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] location_level
  #   @return [::Google::Cloud::CapacityPlanner::V1beta::LocationLevel]
  #     The location level such as a region.
  # @!attribute [rw] location
  #   @return [::String]
  #     Required. The linked cloud location.
  # @!attribute [rw] label
  #   @return [::String]
  class LinkedLocation
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#source::String

Returns Required. Location where resource is sourced. For Cloud Storage, the alphabetically first location is the source.

Returns:

  • (::String)

    Required. Location where resource is sourced. For Cloud Storage, the alphabetically first location is the source.



35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
# File 'proto_docs/google/cloud/capacityplanner/v1beta/location.rb', line 35

class LocationIdentifier
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] location_level
  #   @return [::Google::Cloud::CapacityPlanner::V1beta::LocationLevel]
  #     The location level such as a region.
  # @!attribute [rw] location
  #   @return [::String]
  #     Required. The linked cloud location.
  # @!attribute [rw] label
  #   @return [::String]
  class LinkedLocation
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end