Class: Google::Cloud::CapacityPlanner::V1beta::MachineShape

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/capacityplanner/v1beta/usage_service.rb

Overview

Machine shape details Next : 13

Instance Attribute Summary collapse

Instance Attribute Details

#cpu_cores::Float

Returns Optional. Number of CPU cores per VM.

Returns:

  • (::Float)

    Optional. Number of CPU cores per VM.



557
558
559
560
# File 'proto_docs/google/cloud/capacityplanner/v1beta/usage_service.rb', line 557

class MachineShape
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#gpu_compute_type::String

Returns Optional. The GPU name recognized by Compute Engine APIs.

Returns:

  • (::String)

    Optional. The GPU name recognized by Compute Engine APIs.



557
558
559
560
# File 'proto_docs/google/cloud/capacityplanner/v1beta/usage_service.rb', line 557

class MachineShape
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#gpu_cores::Integer

Returns Optional. The number of GPU cores per VM.

Returns:

  • (::Integer)

    Optional. The number of GPU cores per VM.



557
558
559
560
# File 'proto_docs/google/cloud/capacityplanner/v1beta/usage_service.rb', line 557

class MachineShape
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#gpu_type::String

Returns Optional. The type of GPU with the VM.

Returns:

  • (::String)

    Optional. The type of GPU with the VM.



557
558
559
560
# File 'proto_docs/google/cloud/capacityplanner/v1beta/usage_service.rb', line 557

class MachineShape
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#local_ssd_gb::Float

Returns Optional. Total amount of local SSD storage.

Returns:

  • (::Float)

    Optional. Total amount of local SSD storage.



557
558
559
560
# File 'proto_docs/google/cloud/capacityplanner/v1beta/usage_service.rb', line 557

class MachineShape
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#local_ssd_interface::String

Returns Optional. The local SSD interface used such as nvme or scsi.

Returns:

  • (::String)

    Optional. The local SSD interface used such as nvme or scsi



557
558
559
560
# File 'proto_docs/google/cloud/capacityplanner/v1beta/usage_service.rb', line 557

class MachineShape
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#local_ssd_partitions::Integer

Returns Optional. The number of local SSD partitions per VM.

Returns:

  • (::Integer)

    Optional. The number of local SSD partitions per VM.



557
558
559
560
# File 'proto_docs/google/cloud/capacityplanner/v1beta/usage_service.rb', line 557

class MachineShape
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#machine_family::String

Returns Optional. The VM family.

Returns:

  • (::String)

    Optional. The VM family.



557
558
559
560
# File 'proto_docs/google/cloud/capacityplanner/v1beta/usage_service.rb', line 557

class MachineShape
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#machine_shape::String

Returns Optional. The customer visible string representing the type of VM.

Returns:

  • (::String)

    Optional. The customer visible string representing the type of VM.



557
558
559
560
# File 'proto_docs/google/cloud/capacityplanner/v1beta/usage_service.rb', line 557

class MachineShape
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#machine_type::String

Returns Optional. The characteristics of the sampled VM expressed as a string.

Returns:

  • (::String)

    Optional. The characteristics of the sampled VM expressed as a string.



557
558
559
560
# File 'proto_docs/google/cloud/capacityplanner/v1beta/usage_service.rb', line 557

class MachineShape
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#memory_gb::Float

Returns Optional. Total amount of memory with the VM.

Returns:

  • (::Float)

    Optional. Total amount of memory with the VM.



557
558
559
560
# File 'proto_docs/google/cloud/capacityplanner/v1beta/usage_service.rb', line 557

class MachineShape
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#min_cpu_platform::String

Returns Optional. The Min-cpu platform used such as icelake.

Returns:

  • (::String)

    Optional. The Min-cpu platform used such as icelake



557
558
559
560
# File 'proto_docs/google/cloud/capacityplanner/v1beta/usage_service.rb', line 557

class MachineShape
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end