Class: Google::Cloud::CapacityPlanner::V1beta::OutputConfig

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/capacityplanner/v1beta/usage_service.rb

Overview

Output configuration for export destination.

Instance Attribute Summary collapse

Instance Attribute Details

#bigquery_destination::Google::Cloud::CapacityPlanner::V1beta::BigQueryDestination

Returns Destination on BigQuery.

Note: The following fields are mutually exclusive: bigquery_destination, gcs_destination. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:



761
762
763
764
# File 'proto_docs/google/cloud/capacityplanner/v1beta/usage_service.rb', line 761

class OutputConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#gcs_destination::Google::Cloud::CapacityPlanner::V1beta::GcsDestination

Returns Destination on Cloud Storage.

Note: The following fields are mutually exclusive: gcs_destination, bigquery_destination. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::CapacityPlanner::V1beta::GcsDestination)

    Destination on Cloud Storage.

    Note: The following fields are mutually exclusive: gcs_destination, bigquery_destination. If a field in that set is populated, all other fields in the set will automatically be cleared.



761
762
763
764
# File 'proto_docs/google/cloud/capacityplanner/v1beta/usage_service.rb', line 761

class OutputConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end