Class: Google::Cloud::CapacityPlanner::V1beta::QueryForecastsRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/capacityplanner/v1beta/usage_service.rb

Overview

The QueryForecasts request. Next : 14

Instance Attribute Summary collapse

Instance Attribute Details

#aggregation_method::Google::Cloud::CapacityPlanner::V1beta::UsageHistory::AggregationMethod

Returns Aggregation Method of the historical usage for which the forecast is generated.

Returns:



156
157
158
159
# File 'proto_docs/google/cloud/capacityplanner/v1beta/usage_service.rb', line 156

class QueryForecastsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#cloud_resource_type::String

Returns Required. The resource for the Forecast values to return. Possible values include "gce-vcpus", "gce-ram", "gce-local-ssd", "gce-persistent-disk", "gce-gpu" and "gce-tpu". Empty cloud_resource_type will return results matching all resources.

Returns:

  • (::String)

    Required. The resource for the Forecast values to return. Possible values include "gce-vcpus", "gce-ram", "gce-local-ssd", "gce-persistent-disk", "gce-gpu" and "gce-tpu". Empty cloud_resource_type will return results matching all resources.



156
157
158
159
# File 'proto_docs/google/cloud/capacityplanner/v1beta/usage_service.rb', line 156

class QueryForecastsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#confidential_mode::Boolean

Returns Optional. Whether the persistent disk is in confidential mode.

Returns:

  • (::Boolean)

    Optional. Whether the persistent disk is in confidential mode.



156
157
158
159
# File 'proto_docs/google/cloud/capacityplanner/v1beta/usage_service.rb', line 156

class QueryForecastsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#disk_type::String

Returns Optional. The disk_type for the Forecast values to return with request persistent-disk cloud_resource_type. Empty disk_type will return results matching all disk types.

Returns:

  • (::String)

    Optional. The disk_type for the Forecast values to return with request persistent-disk cloud_resource_type. Empty disk_type will return results matching all disk types.



156
157
158
159
# File 'proto_docs/google/cloud/capacityplanner/v1beta/usage_service.rb', line 156

class QueryForecastsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#forecast_type::Google::Cloud::CapacityPlanner::V1beta::Forecast::ForecastType

Returns The type of forecast to use to select the Forecast values to return. FORECAST_TYPE_UNSPECIFIED will return results matching all the forecast types.

Returns:



156
157
158
159
# File 'proto_docs/google/cloud/capacityplanner/v1beta/usage_service.rb', line 156

class QueryForecastsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#gpu_type::String

Returns Optional. The GPU type for the Forecast values to return. Sample values are "nvidia-tesla-t4", and "nvidia-tesla-a100". See https://cloud.google.com/compute/docs/gpus for a list. Empty gpu_type will return results matching all GPUs.

Returns:

  • (::String)

    Optional. The GPU type for the Forecast values to return. Sample values are "nvidia-tesla-t4", and "nvidia-tesla-a100". See https://cloud.google.com/compute/docs/gpus for a list. Empty gpu_type will return results matching all GPUs.



156
157
158
159
# File 'proto_docs/google/cloud/capacityplanner/v1beta/usage_service.rb', line 156

class QueryForecastsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#machine_family::String

Returns The machine family to use to select the Forecast values to return. Possible values include "n1", and "n2d". Empty machine_family will return results matching all machine families.

Returns:

  • (::String)

    The machine family to use to select the Forecast values to return. Possible values include "n1", and "n2d". Empty machine_family will return results matching all machine families.



156
157
158
159
# File 'proto_docs/google/cloud/capacityplanner/v1beta/usage_service.rb', line 156

class QueryForecastsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#machine_shape::Google::Cloud::CapacityPlanner::V1beta::MachineShape

Returns Optional. The machine shape for the time series values to return.

Returns:



156
157
158
159
# File 'proto_docs/google/cloud/capacityplanner/v1beta/usage_service.rb', line 156

class QueryForecastsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#parent::String

Returns Required. The compute engine resource and location for the time series values to return. The format is:

projects/{project}/locations/{location} or organizations/{organization}/locations/{location} or folders/{folder}/locations/{location}.

Returns:

  • (::String)

    Required. The compute engine resource and location for the time series values to return. The format is:

    projects/{project}/locations/{location} or organizations/{organization}/locations/{location} or folders/{folder}/locations/{location}



156
157
158
159
# File 'proto_docs/google/cloud/capacityplanner/v1beta/usage_service.rb', line 156

class QueryForecastsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#prediction_interval::Google::Cloud::CapacityPlanner::V1beta::Forecast::PredictionInterval

Returns The prediction interval to use to select the Forecast values to return. PREDICTION_INTERVAL_UNSPECIFIED will return results matching all prediction intervals.

Returns:



156
157
158
159
# File 'proto_docs/google/cloud/capacityplanner/v1beta/usage_service.rb', line 156

class QueryForecastsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#tpu_type::String

Returns Optional. The TPU type for the Forecast values to return. Empty tpu_type will return results matching all TPUs.

Returns:

  • (::String)

    Optional. The TPU type for the Forecast values to return. Empty tpu_type will return results matching all TPUs.



156
157
158
159
# File 'proto_docs/google/cloud/capacityplanner/v1beta/usage_service.rb', line 156

class QueryForecastsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end