Module: Google::Cloud::CapacityPlanner::V1beta::QueryReservationsRequest::ReservationDataLevel

Defined in:
proto_docs/google/cloud/capacityplanner/v1beta/usage_service.rb

Overview

The form in which data of reservations should be returned. In case of AGGREGATED, timeseries for selected reservations is returned. If unspecified, all levels are included.

Constant Summary collapse

RESERVATION_DATA_LEVEL_UNSPECIFIED =

No reservation data level specified.

0
RESERVATION_DATA_LEVEL_AGGREGATED =

aggregated reservations data in a timeseries or aggregation over timeseries.

1
RESERVATION_DATA_LEVEL_PER_RESERVATION =

per reservation detail which is equivalent of Arcus Future Reservation or Allocation with only limited fields which are useful for Capacity Planning.

2