Class: Google::Cloud::CapacityPlanner::V1beta::QueryUsageHistoriesRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/capacityplanner/v1beta/usage_service.rb

Overview

The QueryUsageHistories request. Next : 16

Instance Attribute Summary collapse

Instance Attribute Details

#cloud_resource_type::String

Returns Required. The resource for the UsageHistory values to return. Possible values include "gce-vcpus", "gce-ram", "gce-local-ssd", "gce-persistent-disk", "gce-gpu" and "gce-tpu". Empty cloud_resource_type will return results matching all resources.

Returns:

  • (::String)

    Required. The resource for the UsageHistory values to return. Possible values include "gce-vcpus", "gce-ram", "gce-local-ssd", "gce-persistent-disk", "gce-gpu" and "gce-tpu". Empty cloud_resource_type will return results matching all resources.



86
87
88
89
# File 'proto_docs/google/cloud/capacityplanner/v1beta/usage_service.rb', line 86

class QueryUsageHistoriesRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#confidential_mode::Boolean

Returns Optional. Whether the persistent disk is in confidential mode.

Returns:

  • (::Boolean)

    Optional. Whether the persistent disk is in confidential mode.



86
87
88
89
# File 'proto_docs/google/cloud/capacityplanner/v1beta/usage_service.rb', line 86

class QueryUsageHistoriesRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#disk_type::String

Returns Optional. The disk_type for the UsageHistory values to return request with persistent-disk cloud_resource_type. Empty disk_type will return results matching all disk types.

Returns:

  • (::String)

    Optional. The disk_type for the UsageHistory values to return request with persistent-disk cloud_resource_type. Empty disk_type will return results matching all disk types.



86
87
88
89
# File 'proto_docs/google/cloud/capacityplanner/v1beta/usage_service.rb', line 86

class QueryUsageHistoriesRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#end_date::Google::Type::Date

Returns Optional. The end date of reservations usage.

Returns:



86
87
88
89
# File 'proto_docs/google/cloud/capacityplanner/v1beta/usage_service.rb', line 86

class QueryUsageHistoriesRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#gpu_type::String

Returns Optional. The GPU type for the UsageHistory values to return. Sample values are "nvidia-tesla-t4", and "nvidia-tesla-a100". See https://cloud.google.com/compute/docs/gpus for a list. Empty gpu_type will return results matching all GPUs.

Returns:

  • (::String)

    Optional. The GPU type for the UsageHistory values to return. Sample values are "nvidia-tesla-t4", and "nvidia-tesla-a100". See https://cloud.google.com/compute/docs/gpus for a list. Empty gpu_type will return results matching all GPUs.



86
87
88
89
# File 'proto_docs/google/cloud/capacityplanner/v1beta/usage_service.rb', line 86

class QueryUsageHistoriesRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#is_spot::Boolean

Returns Optional. The is_spot flag is used to fetch the usage data for preemptible Resources.

Returns:

  • (::Boolean)

    Optional. The is_spot flag is used to fetch the usage data for preemptible Resources.



86
87
88
89
# File 'proto_docs/google/cloud/capacityplanner/v1beta/usage_service.rb', line 86

class QueryUsageHistoriesRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#location_level::Google::Cloud::CapacityPlanner::V1beta::TimeSeries::LocationType

Returns Optional. The location level of the reservations usage timeseries.

Returns:



86
87
88
89
# File 'proto_docs/google/cloud/capacityplanner/v1beta/usage_service.rb', line 86

class QueryUsageHistoriesRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#machine_family::String

Returns The machine family for the UsageHistory values to return. Possible values include "n1", and "n2d". See https://cloud.google.com/compute/docs/machine-types for more examples. Empty machine_family will return results matching all machine families.

Returns:

  • (::String)

    The machine family for the UsageHistory values to return. Possible values include "n1", and "n2d". See https://cloud.google.com/compute/docs/machine-types for more examples. Empty machine_family will return results matching all machine families.



86
87
88
89
# File 'proto_docs/google/cloud/capacityplanner/v1beta/usage_service.rb', line 86

class QueryUsageHistoriesRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#machine_shape::Google::Cloud::CapacityPlanner::V1beta::MachineShape

Returns Optional. The machine shape for the UsageHistory values to return.

Returns:



86
87
88
89
# File 'proto_docs/google/cloud/capacityplanner/v1beta/usage_service.rb', line 86

class QueryUsageHistoriesRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#parent::String

Returns Required. The compute engine resource and location for the time series values to return. The format is:

projects/{project}/locations/{location} or
organizations/{organization}/locations/{location} or
folders/{folder}/locations/{location}.

Returns:

  • (::String)

    Required. The compute engine resource and location for the time series values to return. The format is:

    projects/{project}/locations/{location} or
    organizations/{organization}/locations/{location} or
    folders/{folder}/locations/{location}
    


86
87
88
89
# File 'proto_docs/google/cloud/capacityplanner/v1beta/usage_service.rb', line 86

class QueryUsageHistoriesRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#start_date::Google::Type::Date

Returns Optional. The start date of reservations usage.

Returns:



86
87
88
89
# File 'proto_docs/google/cloud/capacityplanner/v1beta/usage_service.rb', line 86

class QueryUsageHistoriesRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#tpu_type::String

Returns Optional. The TPU type for the UsageHistory values to return. Empty tpu_type will return results matching all TPUs.

Returns:

  • (::String)

    Optional. The TPU type for the UsageHistory values to return. Empty tpu_type will return results matching all TPUs.



86
87
88
89
# File 'proto_docs/google/cloud/capacityplanner/v1beta/usage_service.rb', line 86

class QueryUsageHistoriesRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#usage_aggregation_method::Google::Cloud::CapacityPlanner::V1beta::UsageHistory::AggregationMethod

Returns The method that should be used to convert sampled usage data to daily usage values. AGGREGATION_METHOD_UNSPECIFIED will return results matching all the aggregation methods.

Returns:



86
87
88
89
# File 'proto_docs/google/cloud/capacityplanner/v1beta/usage_service.rb', line 86

class QueryUsageHistoriesRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end