Class: Google::Cloud::CapacityPlanner::V1beta::ReservationData

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/capacityplanner/v1beta/usage_service.rb

Overview

Response entity for reservations data.

Instance Attribute Summary collapse

Instance Attribute Details

#allocations::Array<::Google::Cloud::CapacityPlanner::V1beta::Allocation>

Returns Allocations filtered by the criteria.

Returns:



514
515
516
517
# File 'proto_docs/google/cloud/capacityplanner/v1beta/usage_service.rb', line 514

class ReservationData
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#future_reservations::Array<::Google::Cloud::CapacityPlanner::V1beta::FutureReservation>

Returns Future reservations filtered by the criteria.

Returns:



514
515
516
517
# File 'proto_docs/google/cloud/capacityplanner/v1beta/usage_service.rb', line 514

class ReservationData
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#name::String

Returns Identifier. The resource name of the connection in the form of: projects/{project_id}/locations/{location_id}/reservations/{reservation_id} or organizations/{organization_id}/locations/{location_id}/reservations/{reservation_id} or folders/{folder_id}/locations/{location_id}/reservations/{reservation_id}.

Returns:

  • (::String)

    Identifier. The resource name of the connection in the form of: projects/{project_id}/locations/{location_id}/reservations/{reservation_id} or organizations/{organization_id}/locations/{location_id}/reservations/{reservation_id} or folders/{folder_id}/locations/{location_id}/reservations/{reservation_id}



514
515
516
517
# File 'proto_docs/google/cloud/capacityplanner/v1beta/usage_service.rb', line 514

class ReservationData
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#time_series::Google::Cloud::CapacityPlanner::V1beta::TimeSeries

Returns The collection of data points that represent the aggregated reserved value for reservations filtered by the criteria.

Returns:



514
515
516
517
# File 'proto_docs/google/cloud/capacityplanner/v1beta/usage_service.rb', line 514

class ReservationData
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#used_reservation_values::Google::Cloud::CapacityPlanner::V1beta::TimeSeries

Returns The collection of data points that represent the aggregated used value for reservations filtered by the criteria.

Returns:



514
515
516
517
# File 'proto_docs/google/cloud/capacityplanner/v1beta/usage_service.rb', line 514

class ReservationData
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end