Class: Google::Cloud::CapacityPlanner::V1beta::TimeSeries

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/capacityplanner/v1beta/usage_service.rb

Overview

A collection of data points that describes the time-varying values of a resource. A time series is identified by its ID. Next : 13

Defined Under Namespace

Modules: LocationType

Instance Attribute Summary collapse

Instance Attribute Details

#cloud_resource_type::String

Returns The resource for the time series values to return. Possible values include "gce-vcpus", "gce-ram", "gce-local-ssd", "gce-persistent-disk", "gce-gpu", "gce-tpu" and "gce-vm".

Returns:

  • (::String)

    The resource for the time series values to return. Possible values include "gce-vcpus", "gce-ram", "gce-local-ssd", "gce-persistent-disk", "gce-gpu", "gce-tpu" and "gce-vm".



474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
# File 'proto_docs/google/cloud/capacityplanner/v1beta/usage_service.rb', line 474

class TimeSeries
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of location that the time series is summarizing.
  module LocationType
    # No location type was specified.
    LOCATION_TYPE_UNSPECIFIED = 0

    # Time series values represent usage aggregated at the region level.
    REGIONAL = 1

    # Time series values represent usage aggregated at the zone level.
    ZONAL = 2
  end
end

#confidential_mode::Boolean

Returns Optional. The confidential mode for disk.

Returns:

  • (::Boolean)

    Optional. The confidential mode for disk.



474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
# File 'proto_docs/google/cloud/capacityplanner/v1beta/usage_service.rb', line 474

class TimeSeries
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of location that the time series is summarizing.
  module LocationType
    # No location type was specified.
    LOCATION_TYPE_UNSPECIFIED = 0

    # Time series values represent usage aggregated at the region level.
    REGIONAL = 1

    # Time series values represent usage aggregated at the zone level.
    ZONAL = 2
  end
end

#disk_type::String

Returns The disk type for the time series values to return.

Returns:

  • (::String)

    The disk type for the time series values to return.



474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
# File 'proto_docs/google/cloud/capacityplanner/v1beta/usage_service.rb', line 474

class TimeSeries
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of location that the time series is summarizing.
  module LocationType
    # No location type was specified.
    LOCATION_TYPE_UNSPECIFIED = 0

    # Time series values represent usage aggregated at the region level.
    REGIONAL = 1

    # Time series values represent usage aggregated at the zone level.
    ZONAL = 2
  end
end

#gpu_type::String

Returns The GPU type of the time series.

Returns:

  • (::String)

    The GPU type of the time series.



474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
# File 'proto_docs/google/cloud/capacityplanner/v1beta/usage_service.rb', line 474

class TimeSeries
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of location that the time series is summarizing.
  module LocationType
    # No location type was specified.
    LOCATION_TYPE_UNSPECIFIED = 0

    # Time series values represent usage aggregated at the region level.
    REGIONAL = 1

    # Time series values represent usage aggregated at the zone level.
    ZONAL = 2
  end
end

#is_spot::Boolean

Returns Optional. The location of the usage data in time series.

Returns:

  • (::Boolean)

    Optional. The location of the usage data in time series.



474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
# File 'proto_docs/google/cloud/capacityplanner/v1beta/usage_service.rb', line 474

class TimeSeries
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of location that the time series is summarizing.
  module LocationType
    # No location type was specified.
    LOCATION_TYPE_UNSPECIFIED = 0

    # Time series values represent usage aggregated at the region level.
    REGIONAL = 1

    # Time series values represent usage aggregated at the zone level.
    ZONAL = 2
  end
end

#location::String

Returns Optional. The location of the usage data in time series.

Returns:

  • (::String)

    Optional. The location of the usage data in time series.



474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
# File 'proto_docs/google/cloud/capacityplanner/v1beta/usage_service.rb', line 474

class TimeSeries
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of location that the time series is summarizing.
  module LocationType
    # No location type was specified.
    LOCATION_TYPE_UNSPECIFIED = 0

    # Time series values represent usage aggregated at the region level.
    REGIONAL = 1

    # Time series values represent usage aggregated at the zone level.
    ZONAL = 2
  end
end

#location_type::Google::Cloud::CapacityPlanner::V1beta::TimeSeries::LocationType

Returns Required. The type of location that the time series is summarizing.

Returns:



474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
# File 'proto_docs/google/cloud/capacityplanner/v1beta/usage_service.rb', line 474

class TimeSeries
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of location that the time series is summarizing.
  module LocationType
    # No location type was specified.
    LOCATION_TYPE_UNSPECIFIED = 0

    # Time series values represent usage aggregated at the region level.
    REGIONAL = 1

    # Time series values represent usage aggregated at the zone level.
    ZONAL = 2
  end
end

#machine_family::String

Returns The machine family for the time series values to return. Possible values include "n1" and "n2d".

Returns:

  • (::String)

    The machine family for the time series values to return. Possible values include "n1" and "n2d".



474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
# File 'proto_docs/google/cloud/capacityplanner/v1beta/usage_service.rb', line 474

class TimeSeries
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of location that the time series is summarizing.
  module LocationType
    # No location type was specified.
    LOCATION_TYPE_UNSPECIFIED = 0

    # Time series values represent usage aggregated at the region level.
    REGIONAL = 1

    # Time series values represent usage aggregated at the zone level.
    ZONAL = 2
  end
end

#machine_shape::Google::Cloud::CapacityPlanner::V1beta::MachineShape

Returns The machine shape of the time series.

Returns:



474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
# File 'proto_docs/google/cloud/capacityplanner/v1beta/usage_service.rb', line 474

class TimeSeries
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of location that the time series is summarizing.
  module LocationType
    # No location type was specified.
    LOCATION_TYPE_UNSPECIFIED = 0

    # Time series values represent usage aggregated at the region level.
    REGIONAL = 1

    # Time series values represent usage aggregated at the zone level.
    ZONAL = 2
  end
end

#points::Array<::Google::Cloud::CapacityPlanner::V1beta::Point>

The data points of this time series. When listing time series, points are returned in chronological order.

Returns:



474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
# File 'proto_docs/google/cloud/capacityplanner/v1beta/usage_service.rb', line 474

class TimeSeries
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of location that the time series is summarizing.
  module LocationType
    # No location type was specified.
    LOCATION_TYPE_UNSPECIFIED = 0

    # Time series values represent usage aggregated at the region level.
    REGIONAL = 1

    # Time series values represent usage aggregated at the zone level.
    ZONAL = 2
  end
end

#tpu_type::String

Returns The TPU type of the time series.

Returns:

  • (::String)

    The TPU type of the time series.



474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
# File 'proto_docs/google/cloud/capacityplanner/v1beta/usage_service.rb', line 474

class TimeSeries
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of location that the time series is summarizing.
  module LocationType
    # No location type was specified.
    LOCATION_TYPE_UNSPECIFIED = 0

    # Time series values represent usage aggregated at the region level.
    REGIONAL = 1

    # Time series values represent usage aggregated at the zone level.
    ZONAL = 2
  end
end

#unit::String

Returns The units in which the values are reported.

Returns:

  • (::String)

    The units in which the values are reported.



474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
# File 'proto_docs/google/cloud/capacityplanner/v1beta/usage_service.rb', line 474

class TimeSeries
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of location that the time series is summarizing.
  module LocationType
    # No location type was specified.
    LOCATION_TYPE_UNSPECIFIED = 0

    # Time series values represent usage aggregated at the region level.
    REGIONAL = 1

    # Time series values represent usage aggregated at the zone level.
    ZONAL = 2
  end
end