Class: Google::Cloud::CapacityPlanner::V1beta::UsageService::Client

Inherits:
Object
  • Object
show all
Includes:
Paths
Defined in:
lib/google/cloud/capacity_planner/v1beta/usage_service/client.rb

Overview

Client for the UsageService service.

Provides access to historical and forecasted usage data.

Defined Under Namespace

Classes: Configuration

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Paths

#location_path

Constructor Details

#initialize {|config| ... } ⇒ Client

Create a new UsageService client object.

Examples:


# Create a client using the default configuration
client = ::Google::Cloud::CapacityPlanner::V1beta::UsageService::Client.new

# Create a client using a custom configuration
client = ::Google::Cloud::CapacityPlanner::V1beta::UsageService::Client.new do |config|
  config.timeout = 10.0
end

Yields:

  • (config)

    Configure the UsageService client.

Yield Parameters:



129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
# File 'lib/google/cloud/capacity_planner/v1beta/usage_service/client.rb', line 129

def initialize
  # These require statements are intentionally placed here to initialize
  # the gRPC module only when it's required.
  # See https://github.com/googleapis/toolkit/issues/446
  require "gapic/grpc"
  require "google/cloud/capacityplanner/v1beta/usage_service_services_pb"

  # Create the configuration object
  @config = Configuration.new Client.configure

  # Yield the configuration if needed
  yield @config if block_given?

  # Create credentials
  credentials = @config.credentials
  # Use self-signed JWT if the endpoint is unchanged from default,
  # but only if the default endpoint does not have a region prefix.
  enable_self_signed_jwt = @config.endpoint.nil? ||
                           (@config.endpoint == Configuration::DEFAULT_ENDPOINT &&
                           !@config.endpoint.split(".").first.include?("-"))
  credentials ||= Credentials.default scope: @config.scope,
                                      enable_self_signed_jwt: enable_self_signed_jwt
  if credentials.is_a?(::String) || credentials.is_a?(::Hash)
    credentials = Credentials.new credentials, scope: @config.scope
  end
  @quota_project_id = @config.quota_project
  @quota_project_id ||= credentials.quota_project_id if credentials.respond_to? :quota_project_id

  @operations_client = Operations.new do |config|
    config.credentials = credentials
    config.quota_project = @quota_project_id
    config.endpoint = @config.endpoint
    config.universe_domain = @config.universe_domain
  end

  @usage_service_stub = ::Gapic::ServiceStub.new(
    ::Google::Cloud::CapacityPlanner::V1beta::UsageService::Stub,
    credentials: credentials,
    endpoint: @config.endpoint,
    endpoint_template: DEFAULT_ENDPOINT_TEMPLATE,
    universe_domain: @config.universe_domain,
    channel_args: @config.channel_args,
    interceptors: @config.interceptors,
    channel_pool_config: @config.channel_pool,
    logger: @config.logger
  )

  @usage_service_stub.stub_logger&.info do |entry|
    entry.set_system_name
    entry.set_service
    entry.message = "Created client for #{entry.service}"
    entry.set_credentials_fields credentials
    entry.set "customEndpoint", @config.endpoint if @config.endpoint
    entry.set "defaultTimeout", @config.timeout if @config.timeout
    entry.set "quotaProject", @quota_project_id if @quota_project_id
  end
end

Instance Attribute Details

#operations_client::Google::Cloud::CapacityPlanner::V1beta::UsageService::Operations (readonly)

Get the associated client for long-running operations.



192
193
194
# File 'lib/google/cloud/capacity_planner/v1beta/usage_service/client.rb', line 192

def operations_client
  @operations_client
end

Class Method Details

.configure {|config| ... } ⇒ Client::Configuration

Configure the UsageService Client class.

See Configuration for a description of the configuration fields.

Examples:


# Modify the configuration for all UsageService clients
::Google::Cloud::CapacityPlanner::V1beta::UsageService::Client.configure do |config|
  config.timeout = 10.0
end

Yields:

  • (config)

    Configure the Client client.

Yield Parameters:

Returns:



62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
# File 'lib/google/cloud/capacity_planner/v1beta/usage_service/client.rb', line 62

def self.configure
  @configure ||= begin
    namespace = ["Google", "Cloud", "CapacityPlanner", "V1beta"]
    parent_config = while namespace.any?
                      parent_name = namespace.join "::"
                      parent_const = const_get parent_name
                      break parent_const.configure if parent_const.respond_to? :configure
                      namespace.pop
                    end
    default_config = Client::Configuration.new parent_config

    default_config.timeout = 60.0
    default_config.retry_policy = {
      initial_delay: 1.0, max_delay: 60.0, multiplier: 1.3, retry_codes: [14, 4, 13]
    }

    default_config
  end
  yield @configure if block_given?
  @configure
end

Instance Method Details

#configure {|config| ... } ⇒ Client::Configuration

Configure the UsageService Client instance.

The configuration is set to the derived mode, meaning that values can be changed, but structural changes (adding new fields, etc.) are not allowed. Structural changes should be made on configure.

See Configuration for a description of the configuration fields.

Yields:

  • (config)

    Configure the Client client.

Yield Parameters:

Returns:



99
100
101
102
# File 'lib/google/cloud/capacity_planner/v1beta/usage_service/client.rb', line 99

def configure
  yield @config if block_given?
  @config
end

#export_forecasts(request, options = nil) ⇒ ::Gapic::Operation #export_forecasts(parent: nil, machine_family: nil, machine_shape: nil, disk_type: nil, gpu_type: nil, tpu_type: nil, resource_type: nil, prediction_interval: nil, aggregation_method: nil, start_date: nil, end_date: nil, output_config: nil) ⇒ ::Gapic::Operation

Exports forecasted usage data requested by user into either an existing Cloud Storage bucket or a BigQuery table.

Examples:

Basic example

require "google/cloud/capacity_planner/v1beta"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::CapacityPlanner::V1beta::UsageService::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::CapacityPlanner::V1beta::ExportForecastsRequest.new

# Call the export_forecasts method.
result = client.export_forecasts request

# The returned object is of type Gapic::Operation. You can use it to
# check the status of an operation, cancel it, or wait for results.
# Here is how to wait for a response.
result.wait_until_done! timeout: 60
if result.response?
  p result.response
else
  puts "No response received."
end

Overloads:

  • #export_forecasts(request, options = nil) ⇒ ::Gapic::Operation

    Pass arguments to export_forecasts via a request object, either of type ExportForecastsRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::CapacityPlanner::V1beta::ExportForecastsRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries, etc. Optional.

  • #export_forecasts(parent: nil, machine_family: nil, machine_shape: nil, disk_type: nil, gpu_type: nil, tpu_type: nil, resource_type: nil, prediction_interval: nil, aggregation_method: nil, start_date: nil, end_date: nil, output_config: nil) ⇒ ::Gapic::Operation

    Pass arguments to export_forecasts via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • parent (::String) (defaults to: nil)

      Required. The compute engine resource and location for the time series values to return. The format is: projects/{project}/locations/{location} or organizations/{organization}/locations/{location} or folders/{folder}/locations/{location}

    • machine_family (::String) (defaults to: nil)

      Optional. The machine family to use to select the Forecast values to return. Possible values include "n1", and "n2d".

    • machine_shape (::Google::Cloud::CapacityPlanner::V1beta::MachineShape, ::Hash) (defaults to: nil)

      Optional. The machine shape for the time series values to export.

    • disk_type (::String) (defaults to: nil)

      Optional. The disk_type for the Forecast values to return with request persistent-disk resource_type.

    • gpu_type (::String) (defaults to: nil)

      Optional. The GPU type for the Forecast values to return. Sample values are "nvidia-tesla-t4", and "nvidia-tesla-a100". See https://cloud.google.com/compute/docs/gpus for a list. Empty gpu_type will return results matching all GPUs.

    • tpu_type (::String) (defaults to: nil)

      Optional. The TPU type for the Forecast values to return. Empty tpu_type will return results matching all TPUs.

    • resource_type (::String) (defaults to: nil)

      Required. The resource for the Forecast values to return. Possible values include "gce-vcpus", "gce-ram", "gce-local-ssd", "gce-persistent-disk", "gce-gpu" and "gce-tpu".

    • prediction_interval (::Google::Cloud::CapacityPlanner::V1beta::Forecast::PredictionInterval) (defaults to: nil)

      Optional. The prediction interval to use to select the Forecast values to return. PREDICTION_INTERVAL_UNSPECIFIED will return results matching all prediction intervals.

    • aggregation_method (::Google::Cloud::CapacityPlanner::V1beta::UsageHistory::AggregationMethod) (defaults to: nil)

      Optional. Aggregation Method of the historical usage for which the forecast is generated.

    • start_date (::Google::Type::Date, ::Hash) (defaults to: nil)

      Optional. The start date of forecasts.

    • end_date (::Google::Type::Date, ::Hash) (defaults to: nil)

      Optional. The end date of forecasts.

    • output_config (::Google::Cloud::CapacityPlanner::V1beta::OutputConfig, ::Hash) (defaults to: nil)

      Required. Output configuration indicating where the results will be output to.

Yields:

  • (response, operation)

    Access the result along with the RPC operation

Yield Parameters:

  • response (::Gapic::Operation)
  • operation (::GRPC::ActiveCall::Operation)

Returns:

  • (::Gapic::Operation)

Raises:

  • (::Google::Cloud::Error)

    if the RPC is aborted.



817
818
819
820
821
822
823
824
825
826
827
828
829
830
831
832
833
834
835
836
837
838
839
840
841
842
843
844
845
846
847
848
849
850
851
852
853
854
855
856
857
858
# File 'lib/google/cloud/capacity_planner/v1beta/usage_service/client.rb', line 817

def export_forecasts request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::CapacityPlanner::V1beta::ExportForecastsRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.export_forecasts..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::CapacityPlanner::V1beta::VERSION
  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  header_params = {}
  if request.parent
    header_params["parent"] = request.parent
  end

  request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&")
  [:"x-goog-request-params"] ||= request_params_header

  options.apply_defaults timeout:      @config.rpcs.export_forecasts.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.export_forecasts.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @usage_service_stub.call_rpc :export_forecasts, request, options: options do |response, operation|
    response = ::Gapic::Operation.new response, @operations_client, options: options
    yield response, operation if block_given?
    throw :response, response
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end

#export_reservations_usage(request, options = nil) ⇒ ::Gapic::Operation #export_reservations_usage(machine_family: nil, machine_shape: nil, gpu_type: nil, parent: nil, location_level: nil, cloud_resource_type: nil, usage_aggregation_method: nil, share_type: nil, start_date: nil, end_date: nil, output_config: nil) ⇒ ::Gapic::Operation

Exports reservations usage data requested by user into either an existing Cloud Storage bucket or a new/existing BigQuery table.

Examples:

Basic example

require "google/cloud/capacity_planner/v1beta"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::CapacityPlanner::V1beta::UsageService::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::CapacityPlanner::V1beta::ExportReservationsUsageRequest.new

# Call the export_reservations_usage method.
result = client.export_reservations_usage request

# The returned object is of type Gapic::Operation. You can use it to
# check the status of an operation, cancel it, or wait for results.
# Here is how to wait for a response.
result.wait_until_done! timeout: 60
if result.response?
  p result.response
else
  puts "No response received."
end

Overloads:

  • #export_reservations_usage(request, options = nil) ⇒ ::Gapic::Operation

    Pass arguments to export_reservations_usage via a request object, either of type ExportReservationsUsageRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::CapacityPlanner::V1beta::ExportReservationsUsageRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries, etc. Optional.

  • #export_reservations_usage(machine_family: nil, machine_shape: nil, gpu_type: nil, parent: nil, location_level: nil, cloud_resource_type: nil, usage_aggregation_method: nil, share_type: nil, start_date: nil, end_date: nil, output_config: nil) ⇒ ::Gapic::Operation

    Pass arguments to export_reservations_usage via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • machine_family (::String) (defaults to: nil)

      Optional. The machine family to query reservations and usage by. For example: n1, n2d.

      Note: The following parameters are mutually exclusive: machine_family, machine_shape, gpu_type. At most one of these parameters can be set. If more than one is set, only one will be used, and it is not defined which one.

    • machine_shape (::Google::Cloud::CapacityPlanner::V1beta::MachineShape, ::Hash) (defaults to: nil)

      Optional. The machine_shape as a filter to select matching reservations and its usage.

      Note: The following parameters are mutually exclusive: machine_shape, machine_family, gpu_type. At most one of these parameters can be set. If more than one is set, only one will be used, and it is not defined which one.

    • gpu_type (::String) (defaults to: nil)

      Optional. The GPU type to query reservations and usage by. For example: NVIDIA T4.

      Note: The following parameters are mutually exclusive: gpu_type, machine_family, machine_shape. At most one of these parameters can be set. If more than one is set, only one will be used, and it is not defined which one.

    • parent (::String) (defaults to: nil)

      Required. The compute engine resource and location of the reservationsusage. The format is: projects/{project}/locations/{location} or organizations/{organization}/locations/{location} or folders/{folder}/locations/{location}

    • location_level (::Google::Cloud::CapacityPlanner::V1beta::TimeSeries::LocationType) (defaults to: nil)

      Optional. The location level of the reservations usage timeseries.

    • cloud_resource_type (::String) (defaults to: nil)

      Required. The resource for the ReservationsUsage values to return. Possible values include "gce-vcpus", "gce-ram", "gce-local-ssd", and "gce-gpu".

    • usage_aggregation_method (::Google::Cloud::CapacityPlanner::V1beta::UsageHistory::AggregationMethod) (defaults to: nil)

      Required. The method that should be used to convert sampled reservations data to daily usage values.

    • share_type (::Google::Cloud::CapacityPlanner::V1beta::ExportReservationsUsageRequest::ShareType) (defaults to: nil)

      Optional. Type of share settings to filter reservations in response. If unspecified, all types are included.

    • start_date (::Google::Type::Date, ::Hash) (defaults to: nil)

      Optional. The start date of reservations usage.

    • end_date (::Google::Type::Date, ::Hash) (defaults to: nil)

      Optional. The end date of reservations usage.

    • output_config (::Google::Cloud::CapacityPlanner::V1beta::OutputConfig, ::Hash) (defaults to: nil)

      Required. Output configuration indicating where the results will be output to.

Yields:

  • (response, operation)

    Access the result along with the RPC operation

Yield Parameters:

  • response (::Gapic::Operation)
  • operation (::GRPC::ActiveCall::Operation)

Returns:

  • (::Gapic::Operation)

Raises:

  • (::Google::Cloud::Error)

    if the RPC is aborted.



950
951
952
953
954
955
956
957
958
959
960
961
962
963
964
965
966
967
968
969
970
971
972
973
974
975
976
977
978
979
980
981
982
983
984
985
986
987
988
989
990
991
# File 'lib/google/cloud/capacity_planner/v1beta/usage_service/client.rb', line 950

def export_reservations_usage request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::CapacityPlanner::V1beta::ExportReservationsUsageRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.export_reservations_usage..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::CapacityPlanner::V1beta::VERSION
  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  header_params = {}
  if request.parent
    header_params["parent"] = request.parent
  end

  request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&")
  [:"x-goog-request-params"] ||= request_params_header

  options.apply_defaults timeout:      @config.rpcs.export_reservations_usage.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.export_reservations_usage.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @usage_service_stub.call_rpc :export_reservations_usage, request, options: options do |response, operation|
    response = ::Gapic::Operation.new response, @operations_client, options: options
    yield response, operation if block_given?
    throw :response, response
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end

#export_usage_histories(request, options = nil) ⇒ ::Gapic::Operation #export_usage_histories(parent: nil, is_spot: nil, machine_family: nil, machine_shape: nil, disk_type: nil, gpu_type: nil, tpu_type: nil, resource_type: nil, usage_aggregation_method: nil, start_date: nil, end_date: nil, output_config: nil) ⇒ ::Gapic::Operation

Exports historical usage data requested by user into either an existing Cloud Storage bucket or a BigQuery table.

Examples:

Basic example

require "google/cloud/capacity_planner/v1beta"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::CapacityPlanner::V1beta::UsageService::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::CapacityPlanner::V1beta::ExportUsageHistoriesRequest.new

# Call the export_usage_histories method.
result = client.export_usage_histories request

# The returned object is of type Gapic::Operation. You can use it to
# check the status of an operation, cancel it, or wait for results.
# Here is how to wait for a response.
result.wait_until_done! timeout: 60
if result.response?
  p result.response
else
  puts "No response received."
end

Overloads:

  • #export_usage_histories(request, options = nil) ⇒ ::Gapic::Operation

    Pass arguments to export_usage_histories via a request object, either of type ExportUsageHistoriesRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::CapacityPlanner::V1beta::ExportUsageHistoriesRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries, etc. Optional.

  • #export_usage_histories(parent: nil, is_spot: nil, machine_family: nil, machine_shape: nil, disk_type: nil, gpu_type: nil, tpu_type: nil, resource_type: nil, usage_aggregation_method: nil, start_date: nil, end_date: nil, output_config: nil) ⇒ ::Gapic::Operation

    Pass arguments to export_usage_histories via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • parent (::String) (defaults to: nil)

      Required. The compute engine resource and location for the time series values to return. The format is: projects/{project}/locations/{location} or organizations/{organization}/locations/{location} or folders/{folder}/locations/{location}

    • is_spot (::Boolean) (defaults to: nil)

      Optional. Set true to export usage for spot resources.

    • machine_family (::String) (defaults to: nil)

      Optional. The machine family for the UsageHistory values to return. Possible values include "n1", and "n2d". See https://cloud.google.com/compute/docs/machine-types for more examples.

    • machine_shape (::Google::Cloud::CapacityPlanner::V1beta::MachineShape, ::Hash) (defaults to: nil)

      Optional. The machine shape for the time series values to export.

    • disk_type (::String) (defaults to: nil)

      Optional. The disk_type for the UsageHistory values to return request with persistent-disk resource_type. Possible values include "pd-ssd", "pd-standard", "pd-balanced", and "pd-extreme".

    • gpu_type (::String) (defaults to: nil)

      Optional. The GPU type for the UsageHistory values to return. Sample values are "nvidia-tesla-t4", and "nvidia-tesla-a100". See https://cloud.google.com/compute/docs/gpus for a list. Empty gpu_type will return results matching all GPUs.

    • tpu_type (::String) (defaults to: nil)

      Optional. The TPU type for the UsageHistory values to return. Empty tpu_type will return results matching all TPUs.

    • resource_type (::String) (defaults to: nil)

      Required. The resource for the UsageHistory values to return. Possible values include "gce-vcpus", "gce-ram", "gce-local-ssd", "gce-persistent-disk", "gce-gpu" and "gce-tpu".

    • usage_aggregation_method (::Google::Cloud::CapacityPlanner::V1beta::UsageHistory::AggregationMethod) (defaults to: nil)

      Optional. The method that should be used to convert sampled usage data to daily usage values. AGGREGATION_METHOD_UNSPECIFIED will return results matching all the aggregation methods.

    • start_date (::Google::Type::Date, ::Hash) (defaults to: nil)

      Optional. The start date of usage.

    • end_date (::Google::Type::Date, ::Hash) (defaults to: nil)

      Optional. The end date of usage.

    • output_config (::Google::Cloud::CapacityPlanner::V1beta::OutputConfig, ::Hash) (defaults to: nil)

      Required. Output configuration indicating where the results will be output to.

Yields:

  • (response, operation)

    Access the result along with the RPC operation

Yield Parameters:

  • response (::Gapic::Operation)
  • operation (::GRPC::ActiveCall::Operation)

Returns:

  • (::Gapic::Operation)

Raises:

  • (::Google::Cloud::Error)

    if the RPC is aborted.



684
685
686
687
688
689
690
691
692
693
694
695
696
697
698
699
700
701
702
703
704
705
706
707
708
709
710
711
712
713
714
715
716
717
718
719
720
721
722
723
724
725
# File 'lib/google/cloud/capacity_planner/v1beta/usage_service/client.rb', line 684

def export_usage_histories request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::CapacityPlanner::V1beta::ExportUsageHistoriesRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.export_usage_histories..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::CapacityPlanner::V1beta::VERSION
  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  header_params = {}
  if request.parent
    header_params["parent"] = request.parent
  end

  request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&")
  [:"x-goog-request-params"] ||= request_params_header

  options.apply_defaults timeout:      @config.rpcs.export_usage_histories.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.export_usage_histories.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @usage_service_stub.call_rpc :export_usage_histories, request, options: options do |response, operation|
    response = ::Gapic::Operation.new response, @operations_client, options: options
    yield response, operation if block_given?
    throw :response, response
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end

#loggerLogger

The logger used for request/response debug logging.

Returns:

  • (Logger)


199
200
201
# File 'lib/google/cloud/capacity_planner/v1beta/usage_service/client.rb', line 199

def logger
  @usage_service_stub.logger
end

#query_forecasts(request, options = nil) ⇒ ::Google::Cloud::CapacityPlanner::V1beta::QueryForecastsResponse #query_forecasts(parent: nil, machine_family: nil, machine_shape: nil, disk_type: nil, confidential_mode: nil, gpu_type: nil, tpu_type: nil, cloud_resource_type: nil, forecast_type: nil, prediction_interval: nil, aggregation_method: nil) ⇒ ::Google::Cloud::CapacityPlanner::V1beta::QueryForecastsResponse

Returns a list of the forecasts that are in the parent parameter and match your specified filters.

Examples:

Basic example

require "google/cloud/capacity_planner/v1beta"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::CapacityPlanner::V1beta::UsageService::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::CapacityPlanner::V1beta::QueryForecastsRequest.new

# Call the query_forecasts method.
result = client.query_forecasts request

# The returned object is of type Google::Cloud::CapacityPlanner::V1beta::QueryForecastsResponse.
p result

Overloads:

  • #query_forecasts(request, options = nil) ⇒ ::Google::Cloud::CapacityPlanner::V1beta::QueryForecastsResponse

    Pass arguments to query_forecasts via a request object, either of type QueryForecastsRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::CapacityPlanner::V1beta::QueryForecastsRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries, etc. Optional.

  • #query_forecasts(parent: nil, machine_family: nil, machine_shape: nil, disk_type: nil, confidential_mode: nil, gpu_type: nil, tpu_type: nil, cloud_resource_type: nil, forecast_type: nil, prediction_interval: nil, aggregation_method: nil) ⇒ ::Google::Cloud::CapacityPlanner::V1beta::QueryForecastsResponse

    Pass arguments to query_forecasts via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • parent (::String) (defaults to: nil)

      Required. The compute engine resource and location for the time series values to return. The format is:

      projects/{project}/locations/{location} or organizations/{organization}/locations/{location} or folders/{folder}/locations/{location}

    • machine_family (::String) (defaults to: nil)

      The machine family to use to select the Forecast values to return. Possible values include "n1", and "n2d". Empty machine_family will return results matching all machine families.

    • machine_shape (::Google::Cloud::CapacityPlanner::V1beta::MachineShape, ::Hash) (defaults to: nil)

      Optional. The machine shape for the time series values to return.

    • disk_type (::String) (defaults to: nil)

      Optional. The disk_type for the Forecast values to return with request persistent-disk cloud_resource_type. Empty disk_type will return results matching all disk types.

    • confidential_mode (::Boolean) (defaults to: nil)

      Optional. Whether the persistent disk is in confidential mode.

    • gpu_type (::String) (defaults to: nil)

      Optional. The GPU type for the Forecast values to return. Sample values are "nvidia-tesla-t4", and "nvidia-tesla-a100". See https://cloud.google.com/compute/docs/gpus for a list. Empty gpu_type will return results matching all GPUs.

    • tpu_type (::String) (defaults to: nil)

      Optional. The TPU type for the Forecast values to return. Empty tpu_type will return results matching all TPUs.

    • cloud_resource_type (::String) (defaults to: nil)

      Required. The resource for the Forecast values to return. Possible values include "gce-vcpus", "gce-ram", "gce-local-ssd", "gce-persistent-disk", "gce-gpu" and "gce-tpu". Empty cloud_resource_type will return results matching all resources.

    • forecast_type (::Google::Cloud::CapacityPlanner::V1beta::Forecast::ForecastType) (defaults to: nil)

      The type of forecast to use to select the Forecast values to return. FORECAST_TYPE_UNSPECIFIED will return results matching all the forecast types.

    • prediction_interval (::Google::Cloud::CapacityPlanner::V1beta::Forecast::PredictionInterval) (defaults to: nil)

      The prediction interval to use to select the Forecast values to return. PREDICTION_INTERVAL_UNSPECIFIED will return results matching all prediction intervals.

    • aggregation_method (::Google::Cloud::CapacityPlanner::V1beta::UsageHistory::AggregationMethod) (defaults to: nil)

      Aggregation Method of the historical usage for which the forecast is generated

Yields:

  • (response, operation)

    Access the result along with the RPC operation

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the RPC is aborted.



422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
# File 'lib/google/cloud/capacity_planner/v1beta/usage_service/client.rb', line 422

def query_forecasts request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::CapacityPlanner::V1beta::QueryForecastsRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.query_forecasts..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::CapacityPlanner::V1beta::VERSION
  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  header_params = {}
  if request.parent
    header_params["parent"] = request.parent
  end

  request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&")
  [:"x-goog-request-params"] ||= request_params_header

  options.apply_defaults timeout:      @config.rpcs.query_forecasts.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.query_forecasts.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @usage_service_stub.call_rpc :query_forecasts, request, options: options do |response, operation|
    yield response, operation if block_given?
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end

#query_reservations(request, options = nil) ⇒ ::Google::Cloud::CapacityPlanner::V1beta::QueryReservationsResponse #query_reservations(parent: nil, location_level: nil, machine_family: nil, machine_shape: nil, gpu_type: nil, cloud_resource_type: nil, reservation_type: nil, share_type: nil, ownership_type: nil, reservation_data_level: nil, include_unapproved_reservations: nil, aggregation_method: nil, start_date: nil, end_date: nil) ⇒ ::Google::Cloud::CapacityPlanner::V1beta::QueryReservationsResponse

Returns a list of the reservations that are in the parent parameter and match your specified filters.

Examples:

Basic example

require "google/cloud/capacity_planner/v1beta"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::CapacityPlanner::V1beta::UsageService::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::CapacityPlanner::V1beta::QueryReservationsRequest.new

# Call the query_reservations method.
result = client.query_reservations request

# The returned object is of type Google::Cloud::CapacityPlanner::V1beta::QueryReservationsResponse.
p result

Overloads:

  • #query_reservations(request, options = nil) ⇒ ::Google::Cloud::CapacityPlanner::V1beta::QueryReservationsResponse

    Pass arguments to query_reservations via a request object, either of type QueryReservationsRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::CapacityPlanner::V1beta::QueryReservationsRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries, etc. Optional.

  • #query_reservations(parent: nil, location_level: nil, machine_family: nil, machine_shape: nil, gpu_type: nil, cloud_resource_type: nil, reservation_type: nil, share_type: nil, ownership_type: nil, reservation_data_level: nil, include_unapproved_reservations: nil, aggregation_method: nil, start_date: nil, end_date: nil) ⇒ ::Google::Cloud::CapacityPlanner::V1beta::QueryReservationsResponse

    Pass arguments to query_reservations via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

Yields:

  • (response, operation)

    Access the result along with the RPC operation

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the RPC is aborted.



552
553
554
555
556
557
558
559
560
561
562
563
564
565
566
567
568
569
570
571
572
573
574
575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
# File 'lib/google/cloud/capacity_planner/v1beta/usage_service/client.rb', line 552

def query_reservations request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::CapacityPlanner::V1beta::QueryReservationsRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.query_reservations..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::CapacityPlanner::V1beta::VERSION
  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  header_params = {}
  if request.parent
    header_params["parent"] = request.parent
  end

  request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&")
  [:"x-goog-request-params"] ||= request_params_header

  options.apply_defaults timeout:      @config.rpcs.query_reservations.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.query_reservations.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @usage_service_stub.call_rpc :query_reservations, request, options: options do |response, operation|
    yield response, operation if block_given?
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end

#query_usage_histories(request, options = nil) ⇒ ::Google::Cloud::CapacityPlanner::V1beta::QueryUsageHistoriesResponse #query_usage_histories(parent: nil, location_level: nil, is_spot: nil, machine_family: nil, machine_shape: nil, disk_type: nil, confidential_mode: nil, gpu_type: nil, tpu_type: nil, cloud_resource_type: nil, usage_aggregation_method: nil, start_date: nil, end_date: nil) ⇒ ::Google::Cloud::CapacityPlanner::V1beta::QueryUsageHistoriesResponse

Returns a list of the usage histories that are in the parent parameter and match your specified filters.

Examples:

Basic example

require "google/cloud/capacity_planner/v1beta"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::CapacityPlanner::V1beta::UsageService::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::CapacityPlanner::V1beta::QueryUsageHistoriesRequest.new

# Call the query_usage_histories method.
result = client.query_usage_histories request

# The returned object is of type Google::Cloud::CapacityPlanner::V1beta::QueryUsageHistoriesResponse.
p result

Overloads:

  • #query_usage_histories(request, options = nil) ⇒ ::Google::Cloud::CapacityPlanner::V1beta::QueryUsageHistoriesResponse

    Pass arguments to query_usage_histories via a request object, either of type QueryUsageHistoriesRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::CapacityPlanner::V1beta::QueryUsageHistoriesRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries, etc. Optional.

  • #query_usage_histories(parent: nil, location_level: nil, is_spot: nil, machine_family: nil, machine_shape: nil, disk_type: nil, confidential_mode: nil, gpu_type: nil, tpu_type: nil, cloud_resource_type: nil, usage_aggregation_method: nil, start_date: nil, end_date: nil) ⇒ ::Google::Cloud::CapacityPlanner::V1beta::QueryUsageHistoriesResponse

    Pass arguments to query_usage_histories via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • parent (::String) (defaults to: nil)

      Required. The compute engine resource and location for the time series values to return. The format is:

      projects/{project}/locations/{location} or
      organizations/{organization}/locations/{location} or
      folders/{folder}/locations/{location}
      
    • location_level (::Google::Cloud::CapacityPlanner::V1beta::TimeSeries::LocationType) (defaults to: nil)

      Optional. The location level of the reservations usage timeseries.

    • is_spot (::Boolean) (defaults to: nil)

      Optional. The is_spot flag is used to fetch the usage data for preemptible Resources.

    • machine_family (::String) (defaults to: nil)

      The machine family for the UsageHistory values to return. Possible values include "n1", and "n2d". See https://cloud.google.com/compute/docs/machine-types for more examples. Empty machine_family will return results matching all machine families.

    • machine_shape (::Google::Cloud::CapacityPlanner::V1beta::MachineShape, ::Hash) (defaults to: nil)

      Optional. The machine shape for the UsageHistory values to return.

    • disk_type (::String) (defaults to: nil)

      Optional. The disk_type for the UsageHistory values to return request with persistent-disk cloud_resource_type. Empty disk_type will return results matching all disk types.

    • confidential_mode (::Boolean) (defaults to: nil)

      Optional. Whether the persistent disk is in confidential mode.

    • gpu_type (::String) (defaults to: nil)

      Optional. The GPU type for the UsageHistory values to return. Sample values are "nvidia-tesla-t4", and "nvidia-tesla-a100". See https://cloud.google.com/compute/docs/gpus for a list. Empty gpu_type will return results matching all GPUs.

    • tpu_type (::String) (defaults to: nil)

      Optional. The TPU type for the UsageHistory values to return. Empty tpu_type will return results matching all TPUs.

    • cloud_resource_type (::String) (defaults to: nil)

      Required. The resource for the UsageHistory values to return. Possible values include "gce-vcpus", "gce-ram", "gce-local-ssd", "gce-persistent-disk", "gce-gpu" and "gce-tpu". Empty cloud_resource_type will return results matching all resources.

    • usage_aggregation_method (::Google::Cloud::CapacityPlanner::V1beta::UsageHistory::AggregationMethod) (defaults to: nil)

      The method that should be used to convert sampled usage data to daily usage values. AGGREGATION_METHOD_UNSPECIFIED will return results matching all the aggregation methods.

    • start_date (::Google::Type::Date, ::Hash) (defaults to: nil)

      Optional. The start date of reservations usage.

    • end_date (::Google::Type::Date, ::Hash) (defaults to: nil)

      Optional. The end date of reservations usage.

Yields:

  • (response, operation)

    Access the result along with the RPC operation

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the RPC is aborted.



295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
# File 'lib/google/cloud/capacity_planner/v1beta/usage_service/client.rb', line 295

def query_usage_histories request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::CapacityPlanner::V1beta::QueryUsageHistoriesRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.query_usage_histories..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::CapacityPlanner::V1beta::VERSION
  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  header_params = {}
  if request.parent
    header_params["parent"] = request.parent
  end

  request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&")
  [:"x-goog-request-params"] ||= request_params_header

  options.apply_defaults timeout:      @config.rpcs.query_usage_histories.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.query_usage_histories.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @usage_service_stub.call_rpc :query_usage_histories, request, options: options do |response, operation|
    yield response, operation if block_given?
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end

#universe_domainString

The effective universe domain

Returns:

  • (String)


109
110
111
# File 'lib/google/cloud/capacity_planner/v1beta/usage_service/client.rb', line 109

def universe_domain
  @usage_service_stub.universe_domain
end