Class: Google::Cloud::CapacityPlanner::V1beta::Value

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/capacityplanner/v1beta/resource.rb

Instance Attribute Summary collapse

Instance Attribute Details

#bool_value::Boolean

Returns Note: The following fields are mutually exclusive: bool_value, int64_value, string_value, double_value. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Boolean)

    Note: The following fields are mutually exclusive: bool_value, int64_value, string_value, double_value. If a field in that set is populated, all other fields in the set will automatically be cleared.



102
103
104
105
# File 'proto_docs/google/cloud/capacityplanner/v1beta/resource.rb', line 102

class Value
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#double_value::Float

Returns Note: The following fields are mutually exclusive: double_value, int64_value, string_value, bool_value. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Float)

    Note: The following fields are mutually exclusive: double_value, int64_value, string_value, bool_value. If a field in that set is populated, all other fields in the set will automatically be cleared.



102
103
104
105
# File 'proto_docs/google/cloud/capacityplanner/v1beta/resource.rb', line 102

class Value
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#int64_value::Integer

Returns Note: The following fields are mutually exclusive: int64_value, string_value, double_value, bool_value. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Integer)

    Note: The following fields are mutually exclusive: int64_value, string_value, double_value, bool_value. If a field in that set is populated, all other fields in the set will automatically be cleared.



102
103
104
105
# File 'proto_docs/google/cloud/capacityplanner/v1beta/resource.rb', line 102

class Value
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#string_value::String

Returns Note: The following fields are mutually exclusive: string_value, int64_value, double_value, bool_value. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::String)

    Note: The following fields are mutually exclusive: string_value, int64_value, double_value, bool_value. If a field in that set is populated, all other fields in the set will automatically be cleared.



102
103
104
105
# File 'proto_docs/google/cloud/capacityplanner/v1beta/resource.rb', line 102

class Value
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end