Class: Google::Cloud::CapacityPlanner::V1beta::Allocation::ShareSettings
- Inherits:
-
Object
- Object
- Google::Cloud::CapacityPlanner::V1beta::Allocation::ShareSettings
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/capacityplanner/v1beta/allocation.rb
Overview
The share setting for reservation.
Defined Under Namespace
Modules: ShareType
Instance Attribute Summary collapse
-
#projects ⇒ ::Array<::String>
A List of Project names to specify consumer projects for this shared-reservation.
-
#share_type ⇒ ::Google::Cloud::CapacityPlanner::V1beta::Allocation::ShareSettings::ShareType
Type of sharing for this shared-reservation.
Instance Attribute Details
#projects ⇒ ::Array<::String>
Returns A List of Project names to specify consumer projects for this shared-reservation. This is only valid when share_type's value is SPECIFIC_PROJECTS.
157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 |
# File 'proto_docs/google/cloud/capacityplanner/v1beta/allocation.rb', line 157 class ShareSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Possible scope in which the reservation can be shared. More granularity # can be added in future. module ShareType # Default value. This value is unused. SHARE_TYPE_UNSPECIFIED = 0 # Shared-reservation is open to entire Organization ORGANIZATION = 1 # Shared-reservation is open to specific projects SPECIFIC_PROJECTS = 2 # Default value. LOCAL = 3 # Shared-reservation is open to direct child projects of specific # folders. DIRECT_PROJECTS_UNDER_SPECIFIC_FOLDERS = 4 end end |
#share_type ⇒ ::Google::Cloud::CapacityPlanner::V1beta::Allocation::ShareSettings::ShareType
Returns Type of sharing for this shared-reservation.
157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 |
# File 'proto_docs/google/cloud/capacityplanner/v1beta/allocation.rb', line 157 class ShareSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Possible scope in which the reservation can be shared. More granularity # can be added in future. module ShareType # Default value. This value is unused. SHARE_TYPE_UNSPECIFIED = 0 # Shared-reservation is open to entire Organization ORGANIZATION = 1 # Shared-reservation is open to specific projects SPECIFIC_PROJECTS = 2 # Default value. LOCAL = 3 # Shared-reservation is open to direct child projects of specific # folders. DIRECT_PROJECTS_UNDER_SPECIFIC_FOLDERS = 4 end end |