Class: Google::Cloud::CapacityPlanner::V1beta::Allocation::SpecificSKUAllocation::AllocatedInstanceProperties::AllocatedDisk
- Inherits:
-
Object
- Object
- Google::Cloud::CapacityPlanner::V1beta::Allocation::SpecificSKUAllocation::AllocatedInstanceProperties::AllocatedDisk
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/capacityplanner/v1beta/allocation.rb
Overview
A specification of the interface and size of disk attached to the instance.
Defined Under Namespace
Modules: DiskInterface
Instance Attribute Summary collapse
-
#disk_interface ⇒ ::Google::Cloud::CapacityPlanner::V1beta::Allocation::SpecificSKUAllocation::AllocatedInstanceProperties::AllocatedDisk::DiskInterface
Specifies the disk interface to use for attaching this disk, which is either SCSI or NVME.
-
#disk_size_gb ⇒ ::Integer
Specifies the size of the disk in base-2 GB.
Instance Attribute Details
#disk_interface ⇒ ::Google::Cloud::CapacityPlanner::V1beta::Allocation::SpecificSKUAllocation::AllocatedInstanceProperties::AllocatedDisk::DiskInterface
Returns Specifies the disk interface to use for attaching this disk, which is either SCSI or NVME. The default is SCSI.
123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 |
# File 'proto_docs/google/cloud/capacityplanner/v1beta/allocation.rb', line 123 class AllocatedDisk include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # guest device interface options to use for the disk. module DiskInterface # Default value. This value is unused. DISK_INTERFACE_UNSPECIFIED = 0 # SCSI disk interface. SCSI = 1 # NVME disk interface. NVME = 2 # NVDIMM disk interface. NVDIMM = 3 # ISCSI disk interface. ISCSI = 4 end end |
#disk_size_gb ⇒ ::Integer
Returns Specifies the size of the disk in base-2 GB.
123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 |
# File 'proto_docs/google/cloud/capacityplanner/v1beta/allocation.rb', line 123 class AllocatedDisk include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # guest device interface options to use for the disk. module DiskInterface # Default value. This value is unused. DISK_INTERFACE_UNSPECIFIED = 0 # SCSI disk interface. SCSI = 1 # NVME disk interface. NVME = 2 # NVDIMM disk interface. NVDIMM = 3 # ISCSI disk interface. ISCSI = 4 end end |