Class: Google::Cloud::CapacityPlanner::V1beta::BigQueryDestination
- Inherits:
-
Object
- Object
- Google::Cloud::CapacityPlanner::V1beta::BigQueryDestination
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/capacityplanner/v1beta/usage_service.rb
Overview
A BigQuery destination for exporting assets to.
Defined Under Namespace
Modules: CreateDisposition, PartitionKey, WriteDisposition
Instance Attribute Summary collapse
-
#create_disposition ⇒ ::Google::Cloud::CapacityPlanner::V1beta::BigQueryDestination::CreateDisposition
Optional.
-
#dataset ⇒ ::String
Required.
-
#gcs_location ⇒ ::String
Optional.
-
#partition_key ⇒ ::Google::Cloud::CapacityPlanner::V1beta::BigQueryDestination::PartitionKey
Optional.
-
#table ⇒ ::String
Required.
-
#write_disposition ⇒ ::Google::Cloud::CapacityPlanner::V1beta::BigQueryDestination::WriteDisposition
Optional.
Instance Attribute Details
#create_disposition ⇒ ::Google::Cloud::CapacityPlanner::V1beta::BigQueryDestination::CreateDisposition
Returns Optional. Specifies the action that occurs if the destination table does not exist.
816 817 818 819 820 821 822 823 824 825 826 827 828 829 830 831 832 833 834 835 836 837 838 839 840 841 842 843 844 845 846 847 848 849 850 851 852 853 854 855 856 857 858 859 860 861 862 863 864 865 866 |
# File 'proto_docs/google/cloud/capacityplanner/v1beta/usage_service.rb', line 816 class BigQueryDestination include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # This enum determines the partition key column for the BigQuery tables. # Partitioning can improve query performance and reduce query cost by # filtering partitions. Refer to # https://cloud.google.com/bigquery/docs/partitioned-tables for details. module PartitionKey # Unspecified partition key. Tables won't be partitioned using this # option. PARTITION_KEY_UNSPECIFIED = 0 # The time when the request is received. If specified as partition key, # the result table(s) is partitioned by the RequestTime column, an # additional timestamp column representing when the request was received. REQUEST_TIME = 1 end # Specifies the action that occurs if the destination table or partition # already exists. By default, the data will be appended to the existing # table. module WriteDisposition # Unspecified write disposition. WRITE_DISPOSITION_UNSPECIFIED = 0 # If the table or partition already exists, BigQuery appends the data to # the table or the latest partition. WRITE_APPEND = 1 # If the table or partition already exists, BigQuery overwrites the entire # table or all the partitions data. WRITE_TRUNCATE = 2 # If the table already exists and contains data, an error is returned. WRITE_EMPTY = 3 end # Specifies the action that occurs if the destination table does not exist. # By default, a new table will be created. module CreateDisposition # Unspecified create disposition. CREATE_DISPOSITION_UNSPECIFIED = 0 # If the table does not exist, BigQuery creates the table. CREATE_IF_NEEDED = 1 # If the table does not exist, an error will be returned. CREATE_NEVER = 2 end end |
#dataset ⇒ ::String
Returns Required. The BigQuery dataset in format "projects/{projectId}/datasets/{datasetId}", to which the snapshot result should be exported. If this dataset does not exist, the export call returns an INVALID_ARGUMENT error.
816 817 818 819 820 821 822 823 824 825 826 827 828 829 830 831 832 833 834 835 836 837 838 839 840 841 842 843 844 845 846 847 848 849 850 851 852 853 854 855 856 857 858 859 860 861 862 863 864 865 866 |
# File 'proto_docs/google/cloud/capacityplanner/v1beta/usage_service.rb', line 816 class BigQueryDestination include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # This enum determines the partition key column for the BigQuery tables. # Partitioning can improve query performance and reduce query cost by # filtering partitions. Refer to # https://cloud.google.com/bigquery/docs/partitioned-tables for details. module PartitionKey # Unspecified partition key. Tables won't be partitioned using this # option. PARTITION_KEY_UNSPECIFIED = 0 # The time when the request is received. If specified as partition key, # the result table(s) is partitioned by the RequestTime column, an # additional timestamp column representing when the request was received. REQUEST_TIME = 1 end # Specifies the action that occurs if the destination table or partition # already exists. By default, the data will be appended to the existing # table. module WriteDisposition # Unspecified write disposition. WRITE_DISPOSITION_UNSPECIFIED = 0 # If the table or partition already exists, BigQuery appends the data to # the table or the latest partition. WRITE_APPEND = 1 # If the table or partition already exists, BigQuery overwrites the entire # table or all the partitions data. WRITE_TRUNCATE = 2 # If the table already exists and contains data, an error is returned. WRITE_EMPTY = 3 end # Specifies the action that occurs if the destination table does not exist. # By default, a new table will be created. module CreateDisposition # Unspecified create disposition. CREATE_DISPOSITION_UNSPECIFIED = 0 # If the table does not exist, BigQuery creates the table. CREATE_IF_NEEDED = 1 # If the table does not exist, an error will be returned. CREATE_NEVER = 2 end end |
#gcs_location ⇒ ::String
Returns Optional. Specifies the Cloud Storage location. Users can choose to provide a location for Cloud Storage bucket to store the exported data. (as it is possible that some locations are restricted via org policy for that project) Temporary Cloud Storage bucket creation is an interim step for BigQuery upload. If no value is provided, the default location used will be 'US'.
816 817 818 819 820 821 822 823 824 825 826 827 828 829 830 831 832 833 834 835 836 837 838 839 840 841 842 843 844 845 846 847 848 849 850 851 852 853 854 855 856 857 858 859 860 861 862 863 864 865 866 |
# File 'proto_docs/google/cloud/capacityplanner/v1beta/usage_service.rb', line 816 class BigQueryDestination include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # This enum determines the partition key column for the BigQuery tables. # Partitioning can improve query performance and reduce query cost by # filtering partitions. Refer to # https://cloud.google.com/bigquery/docs/partitioned-tables for details. module PartitionKey # Unspecified partition key. Tables won't be partitioned using this # option. PARTITION_KEY_UNSPECIFIED = 0 # The time when the request is received. If specified as partition key, # the result table(s) is partitioned by the RequestTime column, an # additional timestamp column representing when the request was received. REQUEST_TIME = 1 end # Specifies the action that occurs if the destination table or partition # already exists. By default, the data will be appended to the existing # table. module WriteDisposition # Unspecified write disposition. WRITE_DISPOSITION_UNSPECIFIED = 0 # If the table or partition already exists, BigQuery appends the data to # the table or the latest partition. WRITE_APPEND = 1 # If the table or partition already exists, BigQuery overwrites the entire # table or all the partitions data. WRITE_TRUNCATE = 2 # If the table already exists and contains data, an error is returned. WRITE_EMPTY = 3 end # Specifies the action that occurs if the destination table does not exist. # By default, a new table will be created. module CreateDisposition # Unspecified create disposition. CREATE_DISPOSITION_UNSPECIFIED = 0 # If the table does not exist, BigQuery creates the table. CREATE_IF_NEEDED = 1 # If the table does not exist, an error will be returned. CREATE_NEVER = 2 end end |
#partition_key ⇒ ::Google::Cloud::CapacityPlanner::V1beta::BigQueryDestination::PartitionKey
Returns Optional. The partition key for BigQuery partitioned table.
816 817 818 819 820 821 822 823 824 825 826 827 828 829 830 831 832 833 834 835 836 837 838 839 840 841 842 843 844 845 846 847 848 849 850 851 852 853 854 855 856 857 858 859 860 861 862 863 864 865 866 |
# File 'proto_docs/google/cloud/capacityplanner/v1beta/usage_service.rb', line 816 class BigQueryDestination include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # This enum determines the partition key column for the BigQuery tables. # Partitioning can improve query performance and reduce query cost by # filtering partitions. Refer to # https://cloud.google.com/bigquery/docs/partitioned-tables for details. module PartitionKey # Unspecified partition key. Tables won't be partitioned using this # option. PARTITION_KEY_UNSPECIFIED = 0 # The time when the request is received. If specified as partition key, # the result table(s) is partitioned by the RequestTime column, an # additional timestamp column representing when the request was received. REQUEST_TIME = 1 end # Specifies the action that occurs if the destination table or partition # already exists. By default, the data will be appended to the existing # table. module WriteDisposition # Unspecified write disposition. WRITE_DISPOSITION_UNSPECIFIED = 0 # If the table or partition already exists, BigQuery appends the data to # the table or the latest partition. WRITE_APPEND = 1 # If the table or partition already exists, BigQuery overwrites the entire # table or all the partitions data. WRITE_TRUNCATE = 2 # If the table already exists and contains data, an error is returned. WRITE_EMPTY = 3 end # Specifies the action that occurs if the destination table does not exist. # By default, a new table will be created. module CreateDisposition # Unspecified create disposition. CREATE_DISPOSITION_UNSPECIFIED = 0 # If the table does not exist, BigQuery creates the table. CREATE_IF_NEEDED = 1 # If the table does not exist, an error will be returned. CREATE_NEVER = 2 end end |
#table ⇒ ::String
Returns Required. The BigQuery table to which the snapshot result should be written.
816 817 818 819 820 821 822 823 824 825 826 827 828 829 830 831 832 833 834 835 836 837 838 839 840 841 842 843 844 845 846 847 848 849 850 851 852 853 854 855 856 857 858 859 860 861 862 863 864 865 866 |
# File 'proto_docs/google/cloud/capacityplanner/v1beta/usage_service.rb', line 816 class BigQueryDestination include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # This enum determines the partition key column for the BigQuery tables. # Partitioning can improve query performance and reduce query cost by # filtering partitions. Refer to # https://cloud.google.com/bigquery/docs/partitioned-tables for details. module PartitionKey # Unspecified partition key. Tables won't be partitioned using this # option. PARTITION_KEY_UNSPECIFIED = 0 # The time when the request is received. If specified as partition key, # the result table(s) is partitioned by the RequestTime column, an # additional timestamp column representing when the request was received. REQUEST_TIME = 1 end # Specifies the action that occurs if the destination table or partition # already exists. By default, the data will be appended to the existing # table. module WriteDisposition # Unspecified write disposition. WRITE_DISPOSITION_UNSPECIFIED = 0 # If the table or partition already exists, BigQuery appends the data to # the table or the latest partition. WRITE_APPEND = 1 # If the table or partition already exists, BigQuery overwrites the entire # table or all the partitions data. WRITE_TRUNCATE = 2 # If the table already exists and contains data, an error is returned. WRITE_EMPTY = 3 end # Specifies the action that occurs if the destination table does not exist. # By default, a new table will be created. module CreateDisposition # Unspecified create disposition. CREATE_DISPOSITION_UNSPECIFIED = 0 # If the table does not exist, BigQuery creates the table. CREATE_IF_NEEDED = 1 # If the table does not exist, an error will be returned. CREATE_NEVER = 2 end end |
#write_disposition ⇒ ::Google::Cloud::CapacityPlanner::V1beta::BigQueryDestination::WriteDisposition
Returns Optional. Specifies the action that occurs if the destination table or partition already exists.
816 817 818 819 820 821 822 823 824 825 826 827 828 829 830 831 832 833 834 835 836 837 838 839 840 841 842 843 844 845 846 847 848 849 850 851 852 853 854 855 856 857 858 859 860 861 862 863 864 865 866 |
# File 'proto_docs/google/cloud/capacityplanner/v1beta/usage_service.rb', line 816 class BigQueryDestination include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # This enum determines the partition key column for the BigQuery tables. # Partitioning can improve query performance and reduce query cost by # filtering partitions. Refer to # https://cloud.google.com/bigquery/docs/partitioned-tables for details. module PartitionKey # Unspecified partition key. Tables won't be partitioned using this # option. PARTITION_KEY_UNSPECIFIED = 0 # The time when the request is received. If specified as partition key, # the result table(s) is partitioned by the RequestTime column, an # additional timestamp column representing when the request was received. REQUEST_TIME = 1 end # Specifies the action that occurs if the destination table or partition # already exists. By default, the data will be appended to the existing # table. module WriteDisposition # Unspecified write disposition. WRITE_DISPOSITION_UNSPECIFIED = 0 # If the table or partition already exists, BigQuery appends the data to # the table or the latest partition. WRITE_APPEND = 1 # If the table or partition already exists, BigQuery overwrites the entire # table or all the partitions data. WRITE_TRUNCATE = 2 # If the table already exists and contains data, an error is returned. WRITE_EMPTY = 3 end # Specifies the action that occurs if the destination table does not exist. # By default, a new table will be created. module CreateDisposition # Unspecified create disposition. CREATE_DISPOSITION_UNSPECIFIED = 0 # If the table does not exist, BigQuery creates the table. CREATE_IF_NEEDED = 1 # If the table does not exist, an error will be returned. CREATE_NEVER = 2 end end |