Module: Google::Cloud::CapacityPlanner::V1beta::BigQueryDestination::CreateDisposition
- Defined in:
- proto_docs/google/cloud/capacityplanner/v1beta/usage_service.rb
Overview
Specifies the action that occurs if the destination table does not exist. By default, a new table will be created.
Constant Summary collapse
- CREATE_DISPOSITION_UNSPECIFIED =
Unspecified create disposition.
0- CREATE_IF_NEEDED =
If the table does not exist, BigQuery creates the table.
1- CREATE_NEVER =
If the table does not exist, an error will be returned.
2