Class: Google::Cloud::CapacityPlanner::V1beta::ExportForecastsRequest
- Inherits:
-
Object
- Object
- Google::Cloud::CapacityPlanner::V1beta::ExportForecastsRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/capacityplanner/v1beta/usage_service.rb
Overview
The ExportForecasts request
Next : 13
Instance Attribute Summary collapse
-
#aggregation_method ⇒ ::Google::Cloud::CapacityPlanner::V1beta::UsageHistory::AggregationMethod
Optional.
-
#disk_type ⇒ ::String
Optional.
-
#end_date ⇒ ::Google::Type::Date
Optional.
-
#gpu_type ⇒ ::String
Optional.
-
#machine_family ⇒ ::String
Optional.
-
#machine_shape ⇒ ::Google::Cloud::CapacityPlanner::V1beta::MachineShape
Optional.
-
#output_config ⇒ ::Google::Cloud::CapacityPlanner::V1beta::OutputConfig
Required.
-
#parent ⇒ ::String
Required.
-
#prediction_interval ⇒ ::Google::Cloud::CapacityPlanner::V1beta::Forecast::PredictionInterval
Optional.
-
#resource_type ⇒ ::String
Required.
-
#start_date ⇒ ::Google::Type::Date
Optional.
-
#tpu_type ⇒ ::String
Optional.
Instance Attribute Details
#aggregation_method ⇒ ::Google::Cloud::CapacityPlanner::V1beta::UsageHistory::AggregationMethod
Returns Optional. Aggregation Method of the historical usage for which the forecast is generated.
676 677 678 679 |
# File 'proto_docs/google/cloud/capacityplanner/v1beta/usage_service.rb', line 676 class ExportForecastsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#disk_type ⇒ ::String
Returns Optional. The disk_type for the Forecast values to return with request
persistent-disk resource_type.
676 677 678 679 |
# File 'proto_docs/google/cloud/capacityplanner/v1beta/usage_service.rb', line 676 class ExportForecastsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#end_date ⇒ ::Google::Type::Date
Returns Optional. The end date of forecasts.
676 677 678 679 |
# File 'proto_docs/google/cloud/capacityplanner/v1beta/usage_service.rb', line 676 class ExportForecastsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#gpu_type ⇒ ::String
Returns Optional. The GPU type for the Forecast values to return. Sample values
are "nvidia-tesla-t4", and "nvidia-tesla-a100". See
https://cloud.google.com/compute/docs/gpus for a list. Empty gpu_type
will return results matching all GPUs.
676 677 678 679 |
# File 'proto_docs/google/cloud/capacityplanner/v1beta/usage_service.rb', line 676 class ExportForecastsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#machine_family ⇒ ::String
Optional. The machine family to use to select the Forecast values to
return. Possible values include "n1", and "n2d".
676 677 678 679 |
# File 'proto_docs/google/cloud/capacityplanner/v1beta/usage_service.rb', line 676 class ExportForecastsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#machine_shape ⇒ ::Google::Cloud::CapacityPlanner::V1beta::MachineShape
Returns Optional. The machine shape for the time series values to export.
676 677 678 679 |
# File 'proto_docs/google/cloud/capacityplanner/v1beta/usage_service.rb', line 676 class ExportForecastsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#output_config ⇒ ::Google::Cloud::CapacityPlanner::V1beta::OutputConfig
Returns Required. Output configuration indicating where the results will be output to.
676 677 678 679 |
# File 'proto_docs/google/cloud/capacityplanner/v1beta/usage_service.rb', line 676 class ExportForecastsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#parent ⇒ ::String
Returns Required. The compute engine resource and location for the time series values to return. The format is: projects/{project}/locations/{location} or organizations/{organization}/locations/{location} or folders/{folder}/locations/{location}.
676 677 678 679 |
# File 'proto_docs/google/cloud/capacityplanner/v1beta/usage_service.rb', line 676 class ExportForecastsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#prediction_interval ⇒ ::Google::Cloud::CapacityPlanner::V1beta::Forecast::PredictionInterval
Optional. The prediction interval to use to select the Forecast values to
return. PREDICTION_INTERVAL_UNSPECIFIED will return results matching all
prediction intervals.
676 677 678 679 |
# File 'proto_docs/google/cloud/capacityplanner/v1beta/usage_service.rb', line 676 class ExportForecastsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#resource_type ⇒ ::String
Returns Required. The resource for the Forecast values to return. Possible values
include "gce-vcpus", "gce-ram", "gce-local-ssd", "gce-persistent-disk",
"gce-gpu" and "gce-tpu".
676 677 678 679 |
# File 'proto_docs/google/cloud/capacityplanner/v1beta/usage_service.rb', line 676 class ExportForecastsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#start_date ⇒ ::Google::Type::Date
Returns Optional. The start date of forecasts.
676 677 678 679 |
# File 'proto_docs/google/cloud/capacityplanner/v1beta/usage_service.rb', line 676 class ExportForecastsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#tpu_type ⇒ ::String
Returns Optional. The TPU type for the Forecast values to return. Empty tpu_type
will return results matching all TPUs.
676 677 678 679 |
# File 'proto_docs/google/cloud/capacityplanner/v1beta/usage_service.rb', line 676 class ExportForecastsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |