Class: Google::Cloud::CapacityPlanner::V1beta::ExportReservationsUsageResponse
- Inherits:
-
Object
- Object
- Google::Cloud::CapacityPlanner::V1beta::ExportReservationsUsageResponse
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/capacityplanner/v1beta/usage_service.rb
Overview
A response message for [UsageService.ExportReservationsUsage].
Instance Attribute Summary collapse
-
#response ⇒ ::String
The response message for the reservations usage export.
Instance Attribute Details
#response ⇒ ::String
Returns The response message for the reservations usage export. In case of bigquery, it will also contain job id.
905 906 907 908 |
# File 'proto_docs/google/cloud/capacityplanner/v1beta/usage_service.rb', line 905 class ExportReservationsUsageResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |