Class: Google::Cloud::CapacityPlanner::V1beta::ExportUsageHistoriesRequest
- Inherits:
-
Object
- Object
- Google::Cloud::CapacityPlanner::V1beta::ExportUsageHistoriesRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/capacityplanner/v1beta/usage_service.rb
Overview
The ExportUsageHistories request
Next : 12
Instance Attribute Summary collapse
-
#disk_type ⇒ ::String
Optional.
-
#end_date ⇒ ::Google::Type::Date
Optional.
-
#gpu_type ⇒ ::String
Optional.
-
#is_spot ⇒ ::Boolean
Optional.
-
#machine_family ⇒ ::String
Optional.
-
#machine_shape ⇒ ::Google::Cloud::CapacityPlanner::V1beta::MachineShape
Optional.
-
#output_config ⇒ ::Google::Cloud::CapacityPlanner::V1beta::OutputConfig
Required.
-
#parent ⇒ ::String
Required.
-
#resource_type ⇒ ::String
Required.
-
#start_date ⇒ ::Google::Type::Date
Optional.
-
#tpu_type ⇒ ::String
Optional.
-
#usage_aggregation_method ⇒ ::Google::Cloud::CapacityPlanner::V1beta::UsageHistory::AggregationMethod
Optional.
Instance Attribute Details
#disk_type ⇒ ::String
Returns Optional. The disk_type for the UsageHistory values to return request
with persistent-disk resource_type. Possible values include "pd-ssd",
"pd-standard", "pd-balanced", and "pd-extreme".
617 618 619 620 |
# File 'proto_docs/google/cloud/capacityplanner/v1beta/usage_service.rb', line 617 class ExportUsageHistoriesRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#end_date ⇒ ::Google::Type::Date
Returns Optional. The end date of usage.
617 618 619 620 |
# File 'proto_docs/google/cloud/capacityplanner/v1beta/usage_service.rb', line 617 class ExportUsageHistoriesRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#gpu_type ⇒ ::String
Returns Optional. The GPU type for the UsageHistory values to return. Sample
values are "nvidia-tesla-t4", and "nvidia-tesla-a100". See
https://cloud.google.com/compute/docs/gpus for a list. Empty gpu_type
will return results matching all GPUs.
617 618 619 620 |
# File 'proto_docs/google/cloud/capacityplanner/v1beta/usage_service.rb', line 617 class ExportUsageHistoriesRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#is_spot ⇒ ::Boolean
Returns Optional. Set true to export usage for spot resources.
617 618 619 620 |
# File 'proto_docs/google/cloud/capacityplanner/v1beta/usage_service.rb', line 617 class ExportUsageHistoriesRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#machine_family ⇒ ::String
Returns Optional. The machine family for the UsageHistory values to return.
Possible values include "n1", and "n2d". See
https://cloud.google.com/compute/docs/machine-types for more examples.
617 618 619 620 |
# File 'proto_docs/google/cloud/capacityplanner/v1beta/usage_service.rb', line 617 class ExportUsageHistoriesRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#machine_shape ⇒ ::Google::Cloud::CapacityPlanner::V1beta::MachineShape
Returns Optional. The machine shape for the time series values to export.
617 618 619 620 |
# File 'proto_docs/google/cloud/capacityplanner/v1beta/usage_service.rb', line 617 class ExportUsageHistoriesRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#output_config ⇒ ::Google::Cloud::CapacityPlanner::V1beta::OutputConfig
Returns Required. Output configuration indicating where the results will be output to.
617 618 619 620 |
# File 'proto_docs/google/cloud/capacityplanner/v1beta/usage_service.rb', line 617 class ExportUsageHistoriesRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#parent ⇒ ::String
Returns Required. The compute engine resource and location for the time series values to return. The format is: projects/{project}/locations/{location} or organizations/{organization}/locations/{location} or folders/{folder}/locations/{location}.
617 618 619 620 |
# File 'proto_docs/google/cloud/capacityplanner/v1beta/usage_service.rb', line 617 class ExportUsageHistoriesRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#resource_type ⇒ ::String
Returns Required. The resource for the UsageHistory values to return. Possible
values include "gce-vcpus", "gce-ram", "gce-local-ssd",
"gce-persistent-disk", "gce-gpu" and "gce-tpu".
617 618 619 620 |
# File 'proto_docs/google/cloud/capacityplanner/v1beta/usage_service.rb', line 617 class ExportUsageHistoriesRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#start_date ⇒ ::Google::Type::Date
Returns Optional. The start date of usage.
617 618 619 620 |
# File 'proto_docs/google/cloud/capacityplanner/v1beta/usage_service.rb', line 617 class ExportUsageHistoriesRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#tpu_type ⇒ ::String
Returns Optional. The TPU type for the UsageHistory values to return. Empty
tpu_type will return results matching all TPUs.
617 618 619 620 |
# File 'proto_docs/google/cloud/capacityplanner/v1beta/usage_service.rb', line 617 class ExportUsageHistoriesRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#usage_aggregation_method ⇒ ::Google::Cloud::CapacityPlanner::V1beta::UsageHistory::AggregationMethod
Returns Optional. The method that should be used to convert sampled usage data to daily usage values. AGGREGATION_METHOD_UNSPECIFIED will return results matching all the aggregation methods.
617 618 619 620 |
# File 'proto_docs/google/cloud/capacityplanner/v1beta/usage_service.rb', line 617 class ExportUsageHistoriesRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |