Class: Google::Cloud::CapacityPlanner::V1beta::Forecast
- Inherits:
-
Object
- Object
- Google::Cloud::CapacityPlanner::V1beta::Forecast
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/capacityplanner/v1beta/usage_service.rb
Overview
A collection of data points that describes the predicted time-varying values of a resource.
Defined Under Namespace
Modules: Bounds, ForecastType, PredictionInterval
Instance Attribute Summary collapse
-
#aggregation_method ⇒ ::Google::Cloud::CapacityPlanner::V1beta::UsageHistory::AggregationMethod
Aggregation Method of the historical usage for which the forecast is generated.
-
#bounds ⇒ ::Google::Cloud::CapacityPlanner::V1beta::Forecast::Bounds
The bounds represented by this forecast time series.
-
#forecast_type ⇒ ::Google::Cloud::CapacityPlanner::V1beta::Forecast::ForecastType
The type of forecast.
-
#name ⇒ ::String
The resource name of the connection in the form of:
projects/{project_id}/locations/{location_id}/forecasts/{forecast_id}ororganizations/{organization_id}/locations/{location_id}/forecasts/{forecast_id}orfolders/{folder_id}/locations/{location_id}/forecasts/{forecast_id}. -
#prediction_interval ⇒ ::Google::Cloud::CapacityPlanner::V1beta::Forecast::PredictionInterval
The prediction interval represented by the time series.
-
#time_series ⇒ ::Google::Cloud::CapacityPlanner::V1beta::TimeSeries
The collection of data points that represent the predicted values.
Instance Attribute Details
#aggregation_method ⇒ ::Google::Cloud::CapacityPlanner::V1beta::UsageHistory::AggregationMethod
Returns Aggregation Method of the historical usage for which the forecast is generated.
342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 |
# File 'proto_docs/google/cloud/capacityplanner/v1beta/usage_service.rb', line 342 class Forecast include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of the forecast. This describes the method that was used to # produce future time series values from historical time series values. module ForecastType # No forecast type is specified. FORECAST_TYPE_UNSPECIFIED = 0 # Statistical forecast. STATISTICAL = 1 # Statistical forecast that attempts to predict the seasonal affects of # Black Friday and Cyber Monday. STATISTICAL_WITH_BFCM = 2 # Yearly Seasonality model provides generic seasonality beyond BFCM. YEARLY_SEASONALITY = 3 end # The bounds of the forecast time series. module Bounds # No bounds is specified. BOUNDS_UNSPECIFIED = 0 # The time series represents the upper bound of the forecast. LOWER_BOUND = 1 # The time series represents the median expected forecast value. MEDIAN = 2 # The time series represents the lower bound of the forecast. UPPER_BOUND = 3 end # The prediction interval represented by a forecast. module PredictionInterval # No prediction interval is specified. PREDICTION_INTERVAL_UNSPECIFIED = 0 # This represents a prediction interval that has 90% confidence. For # example, for a symmetric prediction interval, a `PredictionInterval` # of `PREDICTION_INTERVAL_90` means that the `UPPER_BOUND` will represent # the 95th precentile. PREDICTION_INTERVAL_90 = 1 # This represents a prediction interval that has 50% confidence. For # example, for a symmetric prediction interval, a `PredictionInterval` # of `PREDICTION_INTERVAL_50` means that the `UPPER_BOUND` will represent # the 75th precentile. PREDICTION_INTERVAL_50 = 2 end end |
#bounds ⇒ ::Google::Cloud::CapacityPlanner::V1beta::Forecast::Bounds
Returns The bounds represented by this forecast time series.
342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 |
# File 'proto_docs/google/cloud/capacityplanner/v1beta/usage_service.rb', line 342 class Forecast include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of the forecast. This describes the method that was used to # produce future time series values from historical time series values. module ForecastType # No forecast type is specified. FORECAST_TYPE_UNSPECIFIED = 0 # Statistical forecast. STATISTICAL = 1 # Statistical forecast that attempts to predict the seasonal affects of # Black Friday and Cyber Monday. STATISTICAL_WITH_BFCM = 2 # Yearly Seasonality model provides generic seasonality beyond BFCM. YEARLY_SEASONALITY = 3 end # The bounds of the forecast time series. module Bounds # No bounds is specified. BOUNDS_UNSPECIFIED = 0 # The time series represents the upper bound of the forecast. LOWER_BOUND = 1 # The time series represents the median expected forecast value. MEDIAN = 2 # The time series represents the lower bound of the forecast. UPPER_BOUND = 3 end # The prediction interval represented by a forecast. module PredictionInterval # No prediction interval is specified. PREDICTION_INTERVAL_UNSPECIFIED = 0 # This represents a prediction interval that has 90% confidence. For # example, for a symmetric prediction interval, a `PredictionInterval` # of `PREDICTION_INTERVAL_90` means that the `UPPER_BOUND` will represent # the 95th precentile. PREDICTION_INTERVAL_90 = 1 # This represents a prediction interval that has 50% confidence. For # example, for a symmetric prediction interval, a `PredictionInterval` # of `PREDICTION_INTERVAL_50` means that the `UPPER_BOUND` will represent # the 75th precentile. PREDICTION_INTERVAL_50 = 2 end end |
#forecast_type ⇒ ::Google::Cloud::CapacityPlanner::V1beta::Forecast::ForecastType
Returns The type of forecast.
342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 |
# File 'proto_docs/google/cloud/capacityplanner/v1beta/usage_service.rb', line 342 class Forecast include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of the forecast. This describes the method that was used to # produce future time series values from historical time series values. module ForecastType # No forecast type is specified. FORECAST_TYPE_UNSPECIFIED = 0 # Statistical forecast. STATISTICAL = 1 # Statistical forecast that attempts to predict the seasonal affects of # Black Friday and Cyber Monday. STATISTICAL_WITH_BFCM = 2 # Yearly Seasonality model provides generic seasonality beyond BFCM. YEARLY_SEASONALITY = 3 end # The bounds of the forecast time series. module Bounds # No bounds is specified. BOUNDS_UNSPECIFIED = 0 # The time series represents the upper bound of the forecast. LOWER_BOUND = 1 # The time series represents the median expected forecast value. MEDIAN = 2 # The time series represents the lower bound of the forecast. UPPER_BOUND = 3 end # The prediction interval represented by a forecast. module PredictionInterval # No prediction interval is specified. PREDICTION_INTERVAL_UNSPECIFIED = 0 # This represents a prediction interval that has 90% confidence. For # example, for a symmetric prediction interval, a `PredictionInterval` # of `PREDICTION_INTERVAL_90` means that the `UPPER_BOUND` will represent # the 95th precentile. PREDICTION_INTERVAL_90 = 1 # This represents a prediction interval that has 50% confidence. For # example, for a symmetric prediction interval, a `PredictionInterval` # of `PREDICTION_INTERVAL_50` means that the `UPPER_BOUND` will represent # the 75th precentile. PREDICTION_INTERVAL_50 = 2 end end |
#name ⇒ ::String
Returns The resource name of the connection in the form of:
projects/{project_id}/locations/{location_id}/forecasts/{forecast_id} or
organizations/{organization_id}/locations/{location_id}/forecasts/{forecast_id}
or folders/{folder_id}/locations/{location_id}/forecasts/{forecast_id}.
342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 |
# File 'proto_docs/google/cloud/capacityplanner/v1beta/usage_service.rb', line 342 class Forecast include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of the forecast. This describes the method that was used to # produce future time series values from historical time series values. module ForecastType # No forecast type is specified. FORECAST_TYPE_UNSPECIFIED = 0 # Statistical forecast. STATISTICAL = 1 # Statistical forecast that attempts to predict the seasonal affects of # Black Friday and Cyber Monday. STATISTICAL_WITH_BFCM = 2 # Yearly Seasonality model provides generic seasonality beyond BFCM. YEARLY_SEASONALITY = 3 end # The bounds of the forecast time series. module Bounds # No bounds is specified. BOUNDS_UNSPECIFIED = 0 # The time series represents the upper bound of the forecast. LOWER_BOUND = 1 # The time series represents the median expected forecast value. MEDIAN = 2 # The time series represents the lower bound of the forecast. UPPER_BOUND = 3 end # The prediction interval represented by a forecast. module PredictionInterval # No prediction interval is specified. PREDICTION_INTERVAL_UNSPECIFIED = 0 # This represents a prediction interval that has 90% confidence. For # example, for a symmetric prediction interval, a `PredictionInterval` # of `PREDICTION_INTERVAL_90` means that the `UPPER_BOUND` will represent # the 95th precentile. PREDICTION_INTERVAL_90 = 1 # This represents a prediction interval that has 50% confidence. For # example, for a symmetric prediction interval, a `PredictionInterval` # of `PREDICTION_INTERVAL_50` means that the `UPPER_BOUND` will represent # the 75th precentile. PREDICTION_INTERVAL_50 = 2 end end |
#prediction_interval ⇒ ::Google::Cloud::CapacityPlanner::V1beta::Forecast::PredictionInterval
Returns The prediction interval represented by the time series.
342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 |
# File 'proto_docs/google/cloud/capacityplanner/v1beta/usage_service.rb', line 342 class Forecast include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of the forecast. This describes the method that was used to # produce future time series values from historical time series values. module ForecastType # No forecast type is specified. FORECAST_TYPE_UNSPECIFIED = 0 # Statistical forecast. STATISTICAL = 1 # Statistical forecast that attempts to predict the seasonal affects of # Black Friday and Cyber Monday. STATISTICAL_WITH_BFCM = 2 # Yearly Seasonality model provides generic seasonality beyond BFCM. YEARLY_SEASONALITY = 3 end # The bounds of the forecast time series. module Bounds # No bounds is specified. BOUNDS_UNSPECIFIED = 0 # The time series represents the upper bound of the forecast. LOWER_BOUND = 1 # The time series represents the median expected forecast value. MEDIAN = 2 # The time series represents the lower bound of the forecast. UPPER_BOUND = 3 end # The prediction interval represented by a forecast. module PredictionInterval # No prediction interval is specified. PREDICTION_INTERVAL_UNSPECIFIED = 0 # This represents a prediction interval that has 90% confidence. For # example, for a symmetric prediction interval, a `PredictionInterval` # of `PREDICTION_INTERVAL_90` means that the `UPPER_BOUND` will represent # the 95th precentile. PREDICTION_INTERVAL_90 = 1 # This represents a prediction interval that has 50% confidence. For # example, for a symmetric prediction interval, a `PredictionInterval` # of `PREDICTION_INTERVAL_50` means that the `UPPER_BOUND` will represent # the 75th precentile. PREDICTION_INTERVAL_50 = 2 end end |
#time_series ⇒ ::Google::Cloud::CapacityPlanner::V1beta::TimeSeries
Returns The collection of data points that represent the predicted values. Note that some of these values may be in the past (if, for example, the forecast was created in the past and predicted values for the present day).
342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 |
# File 'proto_docs/google/cloud/capacityplanner/v1beta/usage_service.rb', line 342 class Forecast include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of the forecast. This describes the method that was used to # produce future time series values from historical time series values. module ForecastType # No forecast type is specified. FORECAST_TYPE_UNSPECIFIED = 0 # Statistical forecast. STATISTICAL = 1 # Statistical forecast that attempts to predict the seasonal affects of # Black Friday and Cyber Monday. STATISTICAL_WITH_BFCM = 2 # Yearly Seasonality model provides generic seasonality beyond BFCM. YEARLY_SEASONALITY = 3 end # The bounds of the forecast time series. module Bounds # No bounds is specified. BOUNDS_UNSPECIFIED = 0 # The time series represents the upper bound of the forecast. LOWER_BOUND = 1 # The time series represents the median expected forecast value. MEDIAN = 2 # The time series represents the lower bound of the forecast. UPPER_BOUND = 3 end # The prediction interval represented by a forecast. module PredictionInterval # No prediction interval is specified. PREDICTION_INTERVAL_UNSPECIFIED = 0 # This represents a prediction interval that has 90% confidence. For # example, for a symmetric prediction interval, a `PredictionInterval` # of `PREDICTION_INTERVAL_90` means that the `UPPER_BOUND` will represent # the 95th precentile. PREDICTION_INTERVAL_90 = 1 # This represents a prediction interval that has 50% confidence. For # example, for a symmetric prediction interval, a `PredictionInterval` # of `PREDICTION_INTERVAL_50` means that the `UPPER_BOUND` will represent # the 75th precentile. PREDICTION_INTERVAL_50 = 2 end end |