Module: Google::Cloud::CapacityPlanner::V1beta::Forecast::Bounds
- Defined in:
- proto_docs/google/cloud/capacityplanner/v1beta/usage_service.rb
Overview
The bounds of the forecast time series.
Constant Summary collapse
- BOUNDS_UNSPECIFIED =
No bounds is specified.
0- LOWER_BOUND =
The time series represents the upper bound of the forecast.
1- MEDIAN =
The time series represents the median expected forecast value.
2- UPPER_BOUND =
The time series represents the lower bound of the forecast.
3