Class: Google::Cloud::CapacityPlanner::V1beta::FutureReservation::Status
- Inherits:
-
Object
- Object
- Google::Cloud::CapacityPlanner::V1beta::FutureReservation::Status
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/capacityplanner/v1beta/future_reservation.rb
Overview
Represents status related to the future reservation.
Defined Under Namespace
Modules: ProcurementStatus
Instance Attribute Summary collapse
-
#auto_created_reservations ⇒ ::Array<::String>
Fully qualified urls of the automatically created reservations at start_time.
-
#fulfilled_count ⇒ ::Integer
This count indicates the fulfilled capacity so far.
-
#lock_time ⇒ ::Google::Protobuf::Timestamp
Time when Future Reservation would become LOCKED, after which no modifications to Future Reservation will be allowed.
-
#procurement_status ⇒ ::Google::Cloud::CapacityPlanner::V1beta::FutureReservation::Status::ProcurementStatus
Current state of this Future Reservation.
Instance Attribute Details
#auto_created_reservations ⇒ ::Array<::String>
Returns Fully qualified urls of the automatically created reservations at start_time.
126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 |
# File 'proto_docs/google/cloud/capacityplanner/v1beta/future_reservation.rb', line 126 class Status include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents procurement status of the Future Reservation. module ProcurementStatus # This is unused status value. PROCUREMENT_STATUS_UNSPECIFIED = 0 # Future reservation is pending approval by Google Cloud Platform. PENDING_APPROVAL = 1 # Future reservation is approved by Google Cloud Platform. APPROVED = 2 # Future reservation is committed by the customer. COMMITTED = 3 # Future reservation is rejected by Google Cloud Platform. DECLINED = 4 # Future reservation is cancelled by the customer. CANCELLED = 5 # Future reservation is being procured by Google Cloud Platform. Beyond # this point, Future reservation is locked and no further modifications # are allowed. PROCURING = 6 # Future reservation capacity is being provisioned. This state will be # entered after start_time, while reservations are being created to # provide total_count reserved instance slots. This state will not # persist past start_time + 24h. PROVISIONING = 7 # Future reservation is fulfilled completely. FULFILLED = 8 # Future reservation failed. No additional reservations were provided. FAILED = 9 # Future reservation is partially fulfilled. Additional reservations were # provided but did not reach total_count reserved instance slots. FAILED_PARTIALLY_FULFILLED = 10 # Related status for PlanningStatus.Draft. Transitions to # PENDING_APPROVAL upon user submitting FR. DRAFTING = 11 # An Amendment to the Future Reservation has been requested. If the # Amendment is declined, the Future Reservation will be restored to the # last known good state. PENDING_AMENDMENT_APPROVAL = 12 end end |
#fulfilled_count ⇒ ::Integer
Returns This count indicates the fulfilled capacity so far. This is set during "PROVISIONING" state. This count also includes capacity delivered as part of existing matching reservations.
126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 |
# File 'proto_docs/google/cloud/capacityplanner/v1beta/future_reservation.rb', line 126 class Status include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents procurement status of the Future Reservation. module ProcurementStatus # This is unused status value. PROCUREMENT_STATUS_UNSPECIFIED = 0 # Future reservation is pending approval by Google Cloud Platform. PENDING_APPROVAL = 1 # Future reservation is approved by Google Cloud Platform. APPROVED = 2 # Future reservation is committed by the customer. COMMITTED = 3 # Future reservation is rejected by Google Cloud Platform. DECLINED = 4 # Future reservation is cancelled by the customer. CANCELLED = 5 # Future reservation is being procured by Google Cloud Platform. Beyond # this point, Future reservation is locked and no further modifications # are allowed. PROCURING = 6 # Future reservation capacity is being provisioned. This state will be # entered after start_time, while reservations are being created to # provide total_count reserved instance slots. This state will not # persist past start_time + 24h. PROVISIONING = 7 # Future reservation is fulfilled completely. FULFILLED = 8 # Future reservation failed. No additional reservations were provided. FAILED = 9 # Future reservation is partially fulfilled. Additional reservations were # provided but did not reach total_count reserved instance slots. FAILED_PARTIALLY_FULFILLED = 10 # Related status for PlanningStatus.Draft. Transitions to # PENDING_APPROVAL upon user submitting FR. DRAFTING = 11 # An Amendment to the Future Reservation has been requested. If the # Amendment is declined, the Future Reservation will be restored to the # last known good state. PENDING_AMENDMENT_APPROVAL = 12 end end |
#lock_time ⇒ ::Google::Protobuf::Timestamp
Returns Time when Future Reservation would become LOCKED, after which no modifications to Future Reservation will be allowed. Applicable only after the Future Reservation is in the APPROVED state. The lock_time is an RFC3339 string. The procurement_status will transition to PROCURING state at this time.
126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 |
# File 'proto_docs/google/cloud/capacityplanner/v1beta/future_reservation.rb', line 126 class Status include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents procurement status of the Future Reservation. module ProcurementStatus # This is unused status value. PROCUREMENT_STATUS_UNSPECIFIED = 0 # Future reservation is pending approval by Google Cloud Platform. PENDING_APPROVAL = 1 # Future reservation is approved by Google Cloud Platform. APPROVED = 2 # Future reservation is committed by the customer. COMMITTED = 3 # Future reservation is rejected by Google Cloud Platform. DECLINED = 4 # Future reservation is cancelled by the customer. CANCELLED = 5 # Future reservation is being procured by Google Cloud Platform. Beyond # this point, Future reservation is locked and no further modifications # are allowed. PROCURING = 6 # Future reservation capacity is being provisioned. This state will be # entered after start_time, while reservations are being created to # provide total_count reserved instance slots. This state will not # persist past start_time + 24h. PROVISIONING = 7 # Future reservation is fulfilled completely. FULFILLED = 8 # Future reservation failed. No additional reservations were provided. FAILED = 9 # Future reservation is partially fulfilled. Additional reservations were # provided but did not reach total_count reserved instance slots. FAILED_PARTIALLY_FULFILLED = 10 # Related status for PlanningStatus.Draft. Transitions to # PENDING_APPROVAL upon user submitting FR. DRAFTING = 11 # An Amendment to the Future Reservation has been requested. If the # Amendment is declined, the Future Reservation will be restored to the # last known good state. PENDING_AMENDMENT_APPROVAL = 12 end end |
#procurement_status ⇒ ::Google::Cloud::CapacityPlanner::V1beta::FutureReservation::Status::ProcurementStatus
Returns Current state of this Future Reservation.
126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 |
# File 'proto_docs/google/cloud/capacityplanner/v1beta/future_reservation.rb', line 126 class Status include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents procurement status of the Future Reservation. module ProcurementStatus # This is unused status value. PROCUREMENT_STATUS_UNSPECIFIED = 0 # Future reservation is pending approval by Google Cloud Platform. PENDING_APPROVAL = 1 # Future reservation is approved by Google Cloud Platform. APPROVED = 2 # Future reservation is committed by the customer. COMMITTED = 3 # Future reservation is rejected by Google Cloud Platform. DECLINED = 4 # Future reservation is cancelled by the customer. CANCELLED = 5 # Future reservation is being procured by Google Cloud Platform. Beyond # this point, Future reservation is locked and no further modifications # are allowed. PROCURING = 6 # Future reservation capacity is being provisioned. This state will be # entered after start_time, while reservations are being created to # provide total_count reserved instance slots. This state will not # persist past start_time + 24h. PROVISIONING = 7 # Future reservation is fulfilled completely. FULFILLED = 8 # Future reservation failed. No additional reservations were provided. FAILED = 9 # Future reservation is partially fulfilled. Additional reservations were # provided but did not reach total_count reserved instance slots. FAILED_PARTIALLY_FULFILLED = 10 # Related status for PlanningStatus.Draft. Transitions to # PENDING_APPROVAL upon user submitting FR. DRAFTING = 11 # An Amendment to the Future Reservation has been requested. If the # Amendment is declined, the Future Reservation will be restored to the # last known good state. PENDING_AMENDMENT_APPROVAL = 12 end end |