Module: Google::Cloud::CapacityPlanner::V1beta::FutureReservation::Status::ProcurementStatus
- Defined in:
- proto_docs/google/cloud/capacityplanner/v1beta/future_reservation.rb
Overview
Represents procurement status of the Future Reservation.
Constant Summary collapse
- PROCUREMENT_STATUS_UNSPECIFIED =
This is unused status value.
0- PENDING_APPROVAL =
Future reservation is pending approval by Google Cloud Platform.
1- APPROVED =
Future reservation is approved by Google Cloud Platform.
2- COMMITTED =
Future reservation is committed by the customer.
3- DECLINED =
Future reservation is rejected by Google Cloud Platform.
4- CANCELLED =
Future reservation is cancelled by the customer.
5- PROCURING =
Future reservation is being procured by Google Cloud Platform. Beyond this point, Future reservation is locked and no further modifications are allowed.
6- PROVISIONING =
Future reservation capacity is being provisioned. This state will be entered after start_time, while reservations are being created to provide total_count reserved instance slots. This state will not persist past start_time + 24h.
7- FULFILLED =
Future reservation is fulfilled completely.
8- FAILED =
Future reservation failed. No additional reservations were provided.
9- FAILED_PARTIALLY_FULFILLED =
Future reservation is partially fulfilled. Additional reservations were provided but did not reach total_count reserved instance slots.
10- DRAFTING =
Related status for PlanningStatus.Draft. Transitions to PENDING_APPROVAL upon user submitting FR.
11- PENDING_AMENDMENT_APPROVAL =
An Amendment to the Future Reservation has been requested. If the Amendment is declined, the Future Reservation will be restored to the last known good state.
12