Class: Google::Cloud::CapacityPlanner::V1beta::GcsDestination
- Inherits:
-
Object
- Object
- Google::Cloud::CapacityPlanner::V1beta::GcsDestination
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/capacityplanner/v1beta/usage_service.rb
Overview
A Cloud Storage location.
Instance Attribute Summary collapse
-
#bucket ⇒ ::String
Required.
-
#force ⇒ ::Boolean
Optional.
-
#object ⇒ ::String
Required.
-
#uri ⇒ ::String
Optional.
Instance Attribute Details
#bucket ⇒ ::String
Returns Required. The bucket name to which the export will be stored.
781 782 783 784 |
# File 'proto_docs/google/cloud/capacityplanner/v1beta/usage_service.rb', line 781 class GcsDestination include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#force ⇒ ::Boolean
Returns Optional. Flag to indicate overwrite in case file already exists.
781 782 783 784 |
# File 'proto_docs/google/cloud/capacityplanner/v1beta/usage_service.rb', line 781 class GcsDestination include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#object ⇒ ::String
Returns Required. The object name to which the export will be stored.
781 782 783 784 |
# File 'proto_docs/google/cloud/capacityplanner/v1beta/usage_service.rb', line 781 class GcsDestination include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#uri ⇒ ::String
Returns Optional. The path to the file in Cloud Storage where the export will be
stored. The URI is in the form gs://bucketName/fileName. If the file
already exists, the request succeeds, but the operation fails.
781 782 783 784 |
# File 'proto_docs/google/cloud/capacityplanner/v1beta/usage_service.rb', line 781 class GcsDestination include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |