Class: Google::Cloud::CapacityPlanner::V1beta::QueryReservationsRequest
- Inherits:
-
Object
- Object
- Google::Cloud::CapacityPlanner::V1beta::QueryReservationsRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/capacityplanner/v1beta/usage_service.rb
Overview
The QueryReservations request.
Defined Under Namespace
Modules: OwnershipType, ReservationDataLevel, ReservationType, ShareType
Instance Attribute Summary collapse
-
#aggregation_method ⇒ ::Google::Cloud::CapacityPlanner::V1beta::UsageHistory::AggregationMethod
Optional.
-
#cloud_resource_type ⇒ ::String
Required.
-
#end_date ⇒ ::Google::Type::Date
Optional.
-
#gpu_type ⇒ ::String
Optional.
-
#include_unapproved_reservations ⇒ ::Boolean
Optional.
-
#location_level ⇒ ::Google::Cloud::CapacityPlanner::V1beta::TimeSeries::LocationType
Optional.
-
#machine_family ⇒ ::String
Optional.
-
#machine_shape ⇒ ::Google::Cloud::CapacityPlanner::V1beta::MachineShape
Optional.
-
#ownership_type ⇒ ::Google::Cloud::CapacityPlanner::V1beta::QueryReservationsRequest::OwnershipType
Optional.
-
#parent ⇒ ::String
Required.
-
#reservation_data_level ⇒ ::Google::Cloud::CapacityPlanner::V1beta::QueryReservationsRequest::ReservationDataLevel
Required.
-
#reservation_type ⇒ ::Google::Cloud::CapacityPlanner::V1beta::QueryReservationsRequest::ReservationType
Required.
-
#share_type ⇒ ::Google::Cloud::CapacityPlanner::V1beta::QueryReservationsRequest::ShareType
Optional.
-
#start_date ⇒ ::Google::Type::Date
Optional.
Instance Attribute Details
#aggregation_method ⇒ ::Google::Cloud::CapacityPlanner::V1beta::UsageHistory::AggregationMethod
Returns Optional. Aggregation Method of the historical reservation usage.
231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 |
# File 'proto_docs/google/cloud/capacityplanner/v1beta/usage_service.rb', line 231 class QueryReservationsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Type of the reservation module ReservationType # No reservation type specified. RESERVATION_TYPE_UNSPECIFIED = 0 # Allocation refers to realized reservation either auto created or created # by the users on demand. RESERVATION_TYPE_ALLOCATION = 1 # Future Reservation requests created by users. RESERVATION_TYPE_FUTURE_RESERVATION = 2 # All reservations. RESERVATION_TYPE_ALL = 3 end # Possible scope in which the reservation can be shared. module ShareType # No share type specified. SHARE_TYPE_UNSPECIFIED = 0 # Default value, for which reservation is open to only owner project. SHARE_TYPE_LOCAL = 1 # Shared-reservation is open to specific projects. SHARE_TYPE_SPECIFIC_PROJECTS = 2 end # Reservation ownership status to provide distinction for Capacity Planning. module OwnershipType # No ownership status specified. OWNERSHIP_TYPE_UNSPECIFIED = 0 # For the reservations owned within selected Google Cloud Platform Resource # Container (project/folder/organization). OWNERSHIP_TYPE_OWNED = 1 # For the reservations consumable within selected Google Cloud Platform # Resource Container (project/folder/organization), but not owned by them. OWNERSHIP_TYPE_SHARED_BY_OTHERS = 2 end # The form in which data of reservations should be returned. # In case of AGGREGATED, timeseries for selected reservations is returned. If # unspecified, all levels are included. module ReservationDataLevel # No reservation data level specified. RESERVATION_DATA_LEVEL_UNSPECIFIED = 0 # aggregated reservations data in a timeseries or aggregation over # timeseries. RESERVATION_DATA_LEVEL_AGGREGATED = 1 # per reservation detail which is equivalent of Arcus Future Reservation or # Allocation with only limited fields which are useful for Capacity # Planning. RESERVATION_DATA_LEVEL_PER_RESERVATION = 2 end end |
#cloud_resource_type ⇒ ::String
Returns Required. The resource for the reserved values to return. Possible values include "gce-vcpus", "gce-ram", "gce-local-ssd", "gce-gpu" and "gce-vm".
231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 |
# File 'proto_docs/google/cloud/capacityplanner/v1beta/usage_service.rb', line 231 class QueryReservationsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Type of the reservation module ReservationType # No reservation type specified. RESERVATION_TYPE_UNSPECIFIED = 0 # Allocation refers to realized reservation either auto created or created # by the users on demand. RESERVATION_TYPE_ALLOCATION = 1 # Future Reservation requests created by users. RESERVATION_TYPE_FUTURE_RESERVATION = 2 # All reservations. RESERVATION_TYPE_ALL = 3 end # Possible scope in which the reservation can be shared. module ShareType # No share type specified. SHARE_TYPE_UNSPECIFIED = 0 # Default value, for which reservation is open to only owner project. SHARE_TYPE_LOCAL = 1 # Shared-reservation is open to specific projects. SHARE_TYPE_SPECIFIC_PROJECTS = 2 end # Reservation ownership status to provide distinction for Capacity Planning. module OwnershipType # No ownership status specified. OWNERSHIP_TYPE_UNSPECIFIED = 0 # For the reservations owned within selected Google Cloud Platform Resource # Container (project/folder/organization). OWNERSHIP_TYPE_OWNED = 1 # For the reservations consumable within selected Google Cloud Platform # Resource Container (project/folder/organization), but not owned by them. OWNERSHIP_TYPE_SHARED_BY_OTHERS = 2 end # The form in which data of reservations should be returned. # In case of AGGREGATED, timeseries for selected reservations is returned. If # unspecified, all levels are included. module ReservationDataLevel # No reservation data level specified. RESERVATION_DATA_LEVEL_UNSPECIFIED = 0 # aggregated reservations data in a timeseries or aggregation over # timeseries. RESERVATION_DATA_LEVEL_AGGREGATED = 1 # per reservation detail which is equivalent of Arcus Future Reservation or # Allocation with only limited fields which are useful for Capacity # Planning. RESERVATION_DATA_LEVEL_PER_RESERVATION = 2 end end |
#end_date ⇒ ::Google::Type::Date
Returns Optional. The end date of reservations usage.
231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 |
# File 'proto_docs/google/cloud/capacityplanner/v1beta/usage_service.rb', line 231 class QueryReservationsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Type of the reservation module ReservationType # No reservation type specified. RESERVATION_TYPE_UNSPECIFIED = 0 # Allocation refers to realized reservation either auto created or created # by the users on demand. RESERVATION_TYPE_ALLOCATION = 1 # Future Reservation requests created by users. RESERVATION_TYPE_FUTURE_RESERVATION = 2 # All reservations. RESERVATION_TYPE_ALL = 3 end # Possible scope in which the reservation can be shared. module ShareType # No share type specified. SHARE_TYPE_UNSPECIFIED = 0 # Default value, for which reservation is open to only owner project. SHARE_TYPE_LOCAL = 1 # Shared-reservation is open to specific projects. SHARE_TYPE_SPECIFIC_PROJECTS = 2 end # Reservation ownership status to provide distinction for Capacity Planning. module OwnershipType # No ownership status specified. OWNERSHIP_TYPE_UNSPECIFIED = 0 # For the reservations owned within selected Google Cloud Platform Resource # Container (project/folder/organization). OWNERSHIP_TYPE_OWNED = 1 # For the reservations consumable within selected Google Cloud Platform # Resource Container (project/folder/organization), but not owned by them. OWNERSHIP_TYPE_SHARED_BY_OTHERS = 2 end # The form in which data of reservations should be returned. # In case of AGGREGATED, timeseries for selected reservations is returned. If # unspecified, all levels are included. module ReservationDataLevel # No reservation data level specified. RESERVATION_DATA_LEVEL_UNSPECIFIED = 0 # aggregated reservations data in a timeseries or aggregation over # timeseries. RESERVATION_DATA_LEVEL_AGGREGATED = 1 # per reservation detail which is equivalent of Arcus Future Reservation or # Allocation with only limited fields which are useful for Capacity # Planning. RESERVATION_DATA_LEVEL_PER_RESERVATION = 2 end end |
#gpu_type ⇒ ::String
Returns Optional. The GPU type for the reserved values to return. Sample values are "nvidia-tesla-t4", and "nvidia-tesla-a100". See https://cloud.google.com/compute/docs/gpus for a list. Empty gpu_type will return results matching all GPUs.
231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 |
# File 'proto_docs/google/cloud/capacityplanner/v1beta/usage_service.rb', line 231 class QueryReservationsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Type of the reservation module ReservationType # No reservation type specified. RESERVATION_TYPE_UNSPECIFIED = 0 # Allocation refers to realized reservation either auto created or created # by the users on demand. RESERVATION_TYPE_ALLOCATION = 1 # Future Reservation requests created by users. RESERVATION_TYPE_FUTURE_RESERVATION = 2 # All reservations. RESERVATION_TYPE_ALL = 3 end # Possible scope in which the reservation can be shared. module ShareType # No share type specified. SHARE_TYPE_UNSPECIFIED = 0 # Default value, for which reservation is open to only owner project. SHARE_TYPE_LOCAL = 1 # Shared-reservation is open to specific projects. SHARE_TYPE_SPECIFIC_PROJECTS = 2 end # Reservation ownership status to provide distinction for Capacity Planning. module OwnershipType # No ownership status specified. OWNERSHIP_TYPE_UNSPECIFIED = 0 # For the reservations owned within selected Google Cloud Platform Resource # Container (project/folder/organization). OWNERSHIP_TYPE_OWNED = 1 # For the reservations consumable within selected Google Cloud Platform # Resource Container (project/folder/organization), but not owned by them. OWNERSHIP_TYPE_SHARED_BY_OTHERS = 2 end # The form in which data of reservations should be returned. # In case of AGGREGATED, timeseries for selected reservations is returned. If # unspecified, all levels are included. module ReservationDataLevel # No reservation data level specified. RESERVATION_DATA_LEVEL_UNSPECIFIED = 0 # aggregated reservations data in a timeseries or aggregation over # timeseries. RESERVATION_DATA_LEVEL_AGGREGATED = 1 # per reservation detail which is equivalent of Arcus Future Reservation or # Allocation with only limited fields which are useful for Capacity # Planning. RESERVATION_DATA_LEVEL_PER_RESERVATION = 2 end end |
#include_unapproved_reservations ⇒ ::Boolean
Returns Optional. Whether to include pending for approval reservations in the response. This field is only applicable for future reservations.
231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 |
# File 'proto_docs/google/cloud/capacityplanner/v1beta/usage_service.rb', line 231 class QueryReservationsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Type of the reservation module ReservationType # No reservation type specified. RESERVATION_TYPE_UNSPECIFIED = 0 # Allocation refers to realized reservation either auto created or created # by the users on demand. RESERVATION_TYPE_ALLOCATION = 1 # Future Reservation requests created by users. RESERVATION_TYPE_FUTURE_RESERVATION = 2 # All reservations. RESERVATION_TYPE_ALL = 3 end # Possible scope in which the reservation can be shared. module ShareType # No share type specified. SHARE_TYPE_UNSPECIFIED = 0 # Default value, for which reservation is open to only owner project. SHARE_TYPE_LOCAL = 1 # Shared-reservation is open to specific projects. SHARE_TYPE_SPECIFIC_PROJECTS = 2 end # Reservation ownership status to provide distinction for Capacity Planning. module OwnershipType # No ownership status specified. OWNERSHIP_TYPE_UNSPECIFIED = 0 # For the reservations owned within selected Google Cloud Platform Resource # Container (project/folder/organization). OWNERSHIP_TYPE_OWNED = 1 # For the reservations consumable within selected Google Cloud Platform # Resource Container (project/folder/organization), but not owned by them. OWNERSHIP_TYPE_SHARED_BY_OTHERS = 2 end # The form in which data of reservations should be returned. # In case of AGGREGATED, timeseries for selected reservations is returned. If # unspecified, all levels are included. module ReservationDataLevel # No reservation data level specified. RESERVATION_DATA_LEVEL_UNSPECIFIED = 0 # aggregated reservations data in a timeseries or aggregation over # timeseries. RESERVATION_DATA_LEVEL_AGGREGATED = 1 # per reservation detail which is equivalent of Arcus Future Reservation or # Allocation with only limited fields which are useful for Capacity # Planning. RESERVATION_DATA_LEVEL_PER_RESERVATION = 2 end end |
#location_level ⇒ ::Google::Cloud::CapacityPlanner::V1beta::TimeSeries::LocationType
Returns Optional. The location level of the reservations usage timeseries.
231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 |
# File 'proto_docs/google/cloud/capacityplanner/v1beta/usage_service.rb', line 231 class QueryReservationsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Type of the reservation module ReservationType # No reservation type specified. RESERVATION_TYPE_UNSPECIFIED = 0 # Allocation refers to realized reservation either auto created or created # by the users on demand. RESERVATION_TYPE_ALLOCATION = 1 # Future Reservation requests created by users. RESERVATION_TYPE_FUTURE_RESERVATION = 2 # All reservations. RESERVATION_TYPE_ALL = 3 end # Possible scope in which the reservation can be shared. module ShareType # No share type specified. SHARE_TYPE_UNSPECIFIED = 0 # Default value, for which reservation is open to only owner project. SHARE_TYPE_LOCAL = 1 # Shared-reservation is open to specific projects. SHARE_TYPE_SPECIFIC_PROJECTS = 2 end # Reservation ownership status to provide distinction for Capacity Planning. module OwnershipType # No ownership status specified. OWNERSHIP_TYPE_UNSPECIFIED = 0 # For the reservations owned within selected Google Cloud Platform Resource # Container (project/folder/organization). OWNERSHIP_TYPE_OWNED = 1 # For the reservations consumable within selected Google Cloud Platform # Resource Container (project/folder/organization), but not owned by them. OWNERSHIP_TYPE_SHARED_BY_OTHERS = 2 end # The form in which data of reservations should be returned. # In case of AGGREGATED, timeseries for selected reservations is returned. If # unspecified, all levels are included. module ReservationDataLevel # No reservation data level specified. RESERVATION_DATA_LEVEL_UNSPECIFIED = 0 # aggregated reservations data in a timeseries or aggregation over # timeseries. RESERVATION_DATA_LEVEL_AGGREGATED = 1 # per reservation detail which is equivalent of Arcus Future Reservation or # Allocation with only limited fields which are useful for Capacity # Planning. RESERVATION_DATA_LEVEL_PER_RESERVATION = 2 end end |
#machine_family ⇒ ::String
Returns Optional. The machine family to use to select the aggregate reserved values to return. Possible values include "n1", and "n2d" etc. Empty machine_family will return results matching all machine families.
231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 |
# File 'proto_docs/google/cloud/capacityplanner/v1beta/usage_service.rb', line 231 class QueryReservationsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Type of the reservation module ReservationType # No reservation type specified. RESERVATION_TYPE_UNSPECIFIED = 0 # Allocation refers to realized reservation either auto created or created # by the users on demand. RESERVATION_TYPE_ALLOCATION = 1 # Future Reservation requests created by users. RESERVATION_TYPE_FUTURE_RESERVATION = 2 # All reservations. RESERVATION_TYPE_ALL = 3 end # Possible scope in which the reservation can be shared. module ShareType # No share type specified. SHARE_TYPE_UNSPECIFIED = 0 # Default value, for which reservation is open to only owner project. SHARE_TYPE_LOCAL = 1 # Shared-reservation is open to specific projects. SHARE_TYPE_SPECIFIC_PROJECTS = 2 end # Reservation ownership status to provide distinction for Capacity Planning. module OwnershipType # No ownership status specified. OWNERSHIP_TYPE_UNSPECIFIED = 0 # For the reservations owned within selected Google Cloud Platform Resource # Container (project/folder/organization). OWNERSHIP_TYPE_OWNED = 1 # For the reservations consumable within selected Google Cloud Platform # Resource Container (project/folder/organization), but not owned by them. OWNERSHIP_TYPE_SHARED_BY_OTHERS = 2 end # The form in which data of reservations should be returned. # In case of AGGREGATED, timeseries for selected reservations is returned. If # unspecified, all levels are included. module ReservationDataLevel # No reservation data level specified. RESERVATION_DATA_LEVEL_UNSPECIFIED = 0 # aggregated reservations data in a timeseries or aggregation over # timeseries. RESERVATION_DATA_LEVEL_AGGREGATED = 1 # per reservation detail which is equivalent of Arcus Future Reservation or # Allocation with only limited fields which are useful for Capacity # Planning. RESERVATION_DATA_LEVEL_PER_RESERVATION = 2 end end |
#machine_shape ⇒ ::Google::Cloud::CapacityPlanner::V1beta::MachineShape
Returns Optional. The machine_shape as a filter to select matching reservations.
231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 |
# File 'proto_docs/google/cloud/capacityplanner/v1beta/usage_service.rb', line 231 class QueryReservationsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Type of the reservation module ReservationType # No reservation type specified. RESERVATION_TYPE_UNSPECIFIED = 0 # Allocation refers to realized reservation either auto created or created # by the users on demand. RESERVATION_TYPE_ALLOCATION = 1 # Future Reservation requests created by users. RESERVATION_TYPE_FUTURE_RESERVATION = 2 # All reservations. RESERVATION_TYPE_ALL = 3 end # Possible scope in which the reservation can be shared. module ShareType # No share type specified. SHARE_TYPE_UNSPECIFIED = 0 # Default value, for which reservation is open to only owner project. SHARE_TYPE_LOCAL = 1 # Shared-reservation is open to specific projects. SHARE_TYPE_SPECIFIC_PROJECTS = 2 end # Reservation ownership status to provide distinction for Capacity Planning. module OwnershipType # No ownership status specified. OWNERSHIP_TYPE_UNSPECIFIED = 0 # For the reservations owned within selected Google Cloud Platform Resource # Container (project/folder/organization). OWNERSHIP_TYPE_OWNED = 1 # For the reservations consumable within selected Google Cloud Platform # Resource Container (project/folder/organization), but not owned by them. OWNERSHIP_TYPE_SHARED_BY_OTHERS = 2 end # The form in which data of reservations should be returned. # In case of AGGREGATED, timeseries for selected reservations is returned. If # unspecified, all levels are included. module ReservationDataLevel # No reservation data level specified. RESERVATION_DATA_LEVEL_UNSPECIFIED = 0 # aggregated reservations data in a timeseries or aggregation over # timeseries. RESERVATION_DATA_LEVEL_AGGREGATED = 1 # per reservation detail which is equivalent of Arcus Future Reservation or # Allocation with only limited fields which are useful for Capacity # Planning. RESERVATION_DATA_LEVEL_PER_RESERVATION = 2 end end |
#ownership_type ⇒ ::Google::Cloud::CapacityPlanner::V1beta::QueryReservationsRequest::OwnershipType
Returns Optional. Types of ownerships to filter reservations based on. In case of OWNED, it filters reservations which are owned by selected parent project/folder/organization. If unspecified, all types are included.
231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 |
# File 'proto_docs/google/cloud/capacityplanner/v1beta/usage_service.rb', line 231 class QueryReservationsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Type of the reservation module ReservationType # No reservation type specified. RESERVATION_TYPE_UNSPECIFIED = 0 # Allocation refers to realized reservation either auto created or created # by the users on demand. RESERVATION_TYPE_ALLOCATION = 1 # Future Reservation requests created by users. RESERVATION_TYPE_FUTURE_RESERVATION = 2 # All reservations. RESERVATION_TYPE_ALL = 3 end # Possible scope in which the reservation can be shared. module ShareType # No share type specified. SHARE_TYPE_UNSPECIFIED = 0 # Default value, for which reservation is open to only owner project. SHARE_TYPE_LOCAL = 1 # Shared-reservation is open to specific projects. SHARE_TYPE_SPECIFIC_PROJECTS = 2 end # Reservation ownership status to provide distinction for Capacity Planning. module OwnershipType # No ownership status specified. OWNERSHIP_TYPE_UNSPECIFIED = 0 # For the reservations owned within selected Google Cloud Platform Resource # Container (project/folder/organization). OWNERSHIP_TYPE_OWNED = 1 # For the reservations consumable within selected Google Cloud Platform # Resource Container (project/folder/organization), but not owned by them. OWNERSHIP_TYPE_SHARED_BY_OTHERS = 2 end # The form in which data of reservations should be returned. # In case of AGGREGATED, timeseries for selected reservations is returned. If # unspecified, all levels are included. module ReservationDataLevel # No reservation data level specified. RESERVATION_DATA_LEVEL_UNSPECIFIED = 0 # aggregated reservations data in a timeseries or aggregation over # timeseries. RESERVATION_DATA_LEVEL_AGGREGATED = 1 # per reservation detail which is equivalent of Arcus Future Reservation or # Allocation with only limited fields which are useful for Capacity # Planning. RESERVATION_DATA_LEVEL_PER_RESERVATION = 2 end end |
#parent ⇒ ::String
Returns Required. The compute engine resource and location for the time series values to return. The format is:
projects/{project}/locations/{location} or organizations/{organization}/locations/{location} or folders/{folder}/locations/{location}.
231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 |
# File 'proto_docs/google/cloud/capacityplanner/v1beta/usage_service.rb', line 231 class QueryReservationsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Type of the reservation module ReservationType # No reservation type specified. RESERVATION_TYPE_UNSPECIFIED = 0 # Allocation refers to realized reservation either auto created or created # by the users on demand. RESERVATION_TYPE_ALLOCATION = 1 # Future Reservation requests created by users. RESERVATION_TYPE_FUTURE_RESERVATION = 2 # All reservations. RESERVATION_TYPE_ALL = 3 end # Possible scope in which the reservation can be shared. module ShareType # No share type specified. SHARE_TYPE_UNSPECIFIED = 0 # Default value, for which reservation is open to only owner project. SHARE_TYPE_LOCAL = 1 # Shared-reservation is open to specific projects. SHARE_TYPE_SPECIFIC_PROJECTS = 2 end # Reservation ownership status to provide distinction for Capacity Planning. module OwnershipType # No ownership status specified. OWNERSHIP_TYPE_UNSPECIFIED = 0 # For the reservations owned within selected Google Cloud Platform Resource # Container (project/folder/organization). OWNERSHIP_TYPE_OWNED = 1 # For the reservations consumable within selected Google Cloud Platform # Resource Container (project/folder/organization), but not owned by them. OWNERSHIP_TYPE_SHARED_BY_OTHERS = 2 end # The form in which data of reservations should be returned. # In case of AGGREGATED, timeseries for selected reservations is returned. If # unspecified, all levels are included. module ReservationDataLevel # No reservation data level specified. RESERVATION_DATA_LEVEL_UNSPECIFIED = 0 # aggregated reservations data in a timeseries or aggregation over # timeseries. RESERVATION_DATA_LEVEL_AGGREGATED = 1 # per reservation detail which is equivalent of Arcus Future Reservation or # Allocation with only limited fields which are useful for Capacity # Planning. RESERVATION_DATA_LEVEL_PER_RESERVATION = 2 end end |
#reservation_data_level ⇒ ::Google::Cloud::CapacityPlanner::V1beta::QueryReservationsRequest::ReservationDataLevel
Returns Required. Reservations output data format.
231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 |
# File 'proto_docs/google/cloud/capacityplanner/v1beta/usage_service.rb', line 231 class QueryReservationsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Type of the reservation module ReservationType # No reservation type specified. RESERVATION_TYPE_UNSPECIFIED = 0 # Allocation refers to realized reservation either auto created or created # by the users on demand. RESERVATION_TYPE_ALLOCATION = 1 # Future Reservation requests created by users. RESERVATION_TYPE_FUTURE_RESERVATION = 2 # All reservations. RESERVATION_TYPE_ALL = 3 end # Possible scope in which the reservation can be shared. module ShareType # No share type specified. SHARE_TYPE_UNSPECIFIED = 0 # Default value, for which reservation is open to only owner project. SHARE_TYPE_LOCAL = 1 # Shared-reservation is open to specific projects. SHARE_TYPE_SPECIFIC_PROJECTS = 2 end # Reservation ownership status to provide distinction for Capacity Planning. module OwnershipType # No ownership status specified. OWNERSHIP_TYPE_UNSPECIFIED = 0 # For the reservations owned within selected Google Cloud Platform Resource # Container (project/folder/organization). OWNERSHIP_TYPE_OWNED = 1 # For the reservations consumable within selected Google Cloud Platform # Resource Container (project/folder/organization), but not owned by them. OWNERSHIP_TYPE_SHARED_BY_OTHERS = 2 end # The form in which data of reservations should be returned. # In case of AGGREGATED, timeseries for selected reservations is returned. If # unspecified, all levels are included. module ReservationDataLevel # No reservation data level specified. RESERVATION_DATA_LEVEL_UNSPECIFIED = 0 # aggregated reservations data in a timeseries or aggregation over # timeseries. RESERVATION_DATA_LEVEL_AGGREGATED = 1 # per reservation detail which is equivalent of Arcus Future Reservation or # Allocation with only limited fields which are useful for Capacity # Planning. RESERVATION_DATA_LEVEL_PER_RESERVATION = 2 end end |
#reservation_type ⇒ ::Google::Cloud::CapacityPlanner::V1beta::QueryReservationsRequest::ReservationType
Returns Required. The Reservation type for example, future reservation request and allocation. If unspecified, all types are included.
231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 |
# File 'proto_docs/google/cloud/capacityplanner/v1beta/usage_service.rb', line 231 class QueryReservationsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Type of the reservation module ReservationType # No reservation type specified. RESERVATION_TYPE_UNSPECIFIED = 0 # Allocation refers to realized reservation either auto created or created # by the users on demand. RESERVATION_TYPE_ALLOCATION = 1 # Future Reservation requests created by users. RESERVATION_TYPE_FUTURE_RESERVATION = 2 # All reservations. RESERVATION_TYPE_ALL = 3 end # Possible scope in which the reservation can be shared. module ShareType # No share type specified. SHARE_TYPE_UNSPECIFIED = 0 # Default value, for which reservation is open to only owner project. SHARE_TYPE_LOCAL = 1 # Shared-reservation is open to specific projects. SHARE_TYPE_SPECIFIC_PROJECTS = 2 end # Reservation ownership status to provide distinction for Capacity Planning. module OwnershipType # No ownership status specified. OWNERSHIP_TYPE_UNSPECIFIED = 0 # For the reservations owned within selected Google Cloud Platform Resource # Container (project/folder/organization). OWNERSHIP_TYPE_OWNED = 1 # For the reservations consumable within selected Google Cloud Platform # Resource Container (project/folder/organization), but not owned by them. OWNERSHIP_TYPE_SHARED_BY_OTHERS = 2 end # The form in which data of reservations should be returned. # In case of AGGREGATED, timeseries for selected reservations is returned. If # unspecified, all levels are included. module ReservationDataLevel # No reservation data level specified. RESERVATION_DATA_LEVEL_UNSPECIFIED = 0 # aggregated reservations data in a timeseries or aggregation over # timeseries. RESERVATION_DATA_LEVEL_AGGREGATED = 1 # per reservation detail which is equivalent of Arcus Future Reservation or # Allocation with only limited fields which are useful for Capacity # Planning. RESERVATION_DATA_LEVEL_PER_RESERVATION = 2 end end |
#share_type ⇒ ::Google::Cloud::CapacityPlanner::V1beta::QueryReservationsRequest::ShareType
Returns Optional. Types of share settings to filter reservations in response. If unspecified, all types are included.
231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 |
# File 'proto_docs/google/cloud/capacityplanner/v1beta/usage_service.rb', line 231 class QueryReservationsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Type of the reservation module ReservationType # No reservation type specified. RESERVATION_TYPE_UNSPECIFIED = 0 # Allocation refers to realized reservation either auto created or created # by the users on demand. RESERVATION_TYPE_ALLOCATION = 1 # Future Reservation requests created by users. RESERVATION_TYPE_FUTURE_RESERVATION = 2 # All reservations. RESERVATION_TYPE_ALL = 3 end # Possible scope in which the reservation can be shared. module ShareType # No share type specified. SHARE_TYPE_UNSPECIFIED = 0 # Default value, for which reservation is open to only owner project. SHARE_TYPE_LOCAL = 1 # Shared-reservation is open to specific projects. SHARE_TYPE_SPECIFIC_PROJECTS = 2 end # Reservation ownership status to provide distinction for Capacity Planning. module OwnershipType # No ownership status specified. OWNERSHIP_TYPE_UNSPECIFIED = 0 # For the reservations owned within selected Google Cloud Platform Resource # Container (project/folder/organization). OWNERSHIP_TYPE_OWNED = 1 # For the reservations consumable within selected Google Cloud Platform # Resource Container (project/folder/organization), but not owned by them. OWNERSHIP_TYPE_SHARED_BY_OTHERS = 2 end # The form in which data of reservations should be returned. # In case of AGGREGATED, timeseries for selected reservations is returned. If # unspecified, all levels are included. module ReservationDataLevel # No reservation data level specified. RESERVATION_DATA_LEVEL_UNSPECIFIED = 0 # aggregated reservations data in a timeseries or aggregation over # timeseries. RESERVATION_DATA_LEVEL_AGGREGATED = 1 # per reservation detail which is equivalent of Arcus Future Reservation or # Allocation with only limited fields which are useful for Capacity # Planning. RESERVATION_DATA_LEVEL_PER_RESERVATION = 2 end end |
#start_date ⇒ ::Google::Type::Date
Returns Optional. The start date of reservations usage.
231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 |
# File 'proto_docs/google/cloud/capacityplanner/v1beta/usage_service.rb', line 231 class QueryReservationsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Type of the reservation module ReservationType # No reservation type specified. RESERVATION_TYPE_UNSPECIFIED = 0 # Allocation refers to realized reservation either auto created or created # by the users on demand. RESERVATION_TYPE_ALLOCATION = 1 # Future Reservation requests created by users. RESERVATION_TYPE_FUTURE_RESERVATION = 2 # All reservations. RESERVATION_TYPE_ALL = 3 end # Possible scope in which the reservation can be shared. module ShareType # No share type specified. SHARE_TYPE_UNSPECIFIED = 0 # Default value, for which reservation is open to only owner project. SHARE_TYPE_LOCAL = 1 # Shared-reservation is open to specific projects. SHARE_TYPE_SPECIFIC_PROJECTS = 2 end # Reservation ownership status to provide distinction for Capacity Planning. module OwnershipType # No ownership status specified. OWNERSHIP_TYPE_UNSPECIFIED = 0 # For the reservations owned within selected Google Cloud Platform Resource # Container (project/folder/organization). OWNERSHIP_TYPE_OWNED = 1 # For the reservations consumable within selected Google Cloud Platform # Resource Container (project/folder/organization), but not owned by them. OWNERSHIP_TYPE_SHARED_BY_OTHERS = 2 end # The form in which data of reservations should be returned. # In case of AGGREGATED, timeseries for selected reservations is returned. If # unspecified, all levels are included. module ReservationDataLevel # No reservation data level specified. RESERVATION_DATA_LEVEL_UNSPECIFIED = 0 # aggregated reservations data in a timeseries or aggregation over # timeseries. RESERVATION_DATA_LEVEL_AGGREGATED = 1 # per reservation detail which is equivalent of Arcus Future Reservation or # Allocation with only limited fields which are useful for Capacity # Planning. RESERVATION_DATA_LEVEL_PER_RESERVATION = 2 end end |