Class: Google::Cloud::CapacityPlanner::V1beta::UsageHistory
- Inherits:
-
Object
- Object
- Google::Cloud::CapacityPlanner::V1beta::UsageHistory
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/capacityplanner/v1beta/usage_service.rb
Overview
A collection of data points that describes the historical time-varying values of a resource.
Defined Under Namespace
Modules: AggregationMethod
Instance Attribute Summary collapse
-
#aggregation_method ⇒ ::Google::Cloud::CapacityPlanner::V1beta::UsageHistory::AggregationMethod
Method used to convert sampled usage data to time series values.
-
#time_series ⇒ ::Google::Cloud::CapacityPlanner::V1beta::TimeSeries
The collection of data points that represent the historical values.
Instance Attribute Details
#aggregation_method ⇒ ::Google::Cloud::CapacityPlanner::V1beta::UsageHistory::AggregationMethod
Returns Method used to convert sampled usage data to time series values.
405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 |
# File 'proto_docs/google/cloud/capacityplanner/v1beta/usage_service.rb', line 405 class UsageHistory include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Methods for converting sampled data to time series values. module AggregationMethod # No aggregation method is specified. AGGREGATION_METHOD_UNSPECIFIED = 0 MEDIAN = 1 # Time series values represent the 99th percentile of the sampled values. PEAK = 2 # Time series values represent the 50th(median) percentile of the sampled # values. P50 = 3 # Time series values represent the 75th percentile of the sampled values. P75 = 4 # Time series values represent the 99th percentile of the sampled values. P99 = 5 end end |
#time_series ⇒ ::Google::Cloud::CapacityPlanner::V1beta::TimeSeries
Returns The collection of data points that represent the historical values.
405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 |
# File 'proto_docs/google/cloud/capacityplanner/v1beta/usage_service.rb', line 405 class UsageHistory include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Methods for converting sampled data to time series values. module AggregationMethod # No aggregation method is specified. AGGREGATION_METHOD_UNSPECIFIED = 0 MEDIAN = 1 # Time series values represent the 99th percentile of the sampled values. PEAK = 2 # Time series values represent the 50th(median) percentile of the sampled # values. P50 = 3 # Time series values represent the 75th percentile of the sampled values. P75 = 4 # Time series values represent the 99th percentile of the sampled values. P99 = 5 end end |