Class: Google::Cloud::CapacityPlanner::V1beta::UsageService::Rest::Client
- Inherits:
-
Object
- Object
- Google::Cloud::CapacityPlanner::V1beta::UsageService::Rest::Client
- Includes:
- Paths
- Defined in:
- lib/google/cloud/capacity_planner/v1beta/usage_service/rest/client.rb
Overview
REST client for the UsageService service.
Provides access to historical and forecasted usage data.
Defined Under Namespace
Classes: Configuration
Instance Attribute Summary collapse
-
#operations_client ⇒ ::Google::Cloud::CapacityPlanner::V1beta::UsageService::Rest::Operations
readonly
Get the associated client for long-running operations.
Class Method Summary collapse
-
.configure {|config| ... } ⇒ Client::Configuration
Configure the UsageService Client class.
Instance Method Summary collapse
-
#configure {|config| ... } ⇒ Client::Configuration
Configure the UsageService Client instance.
-
#export_forecasts(request, options = nil) {|result, operation| ... } ⇒ ::Gapic::Operation
Exports forecasted usage data requested by user into either an existing Cloud Storage bucket or a BigQuery table.
-
#export_reservations_usage(request, options = nil) {|result, operation| ... } ⇒ ::Gapic::Operation
Exports reservations usage data requested by user into either an existing Cloud Storage bucket or a new/existing BigQuery table.
-
#export_usage_histories(request, options = nil) {|result, operation| ... } ⇒ ::Gapic::Operation
Exports historical usage data requested by user into either an existing Cloud Storage bucket or a BigQuery table.
-
#initialize {|config| ... } ⇒ Client
constructor
Create a new UsageService REST client object.
-
#logger ⇒ Logger
The logger used for request/response debug logging.
-
#query_forecasts(request, options = nil) {|result, operation| ... } ⇒ ::Google::Cloud::CapacityPlanner::V1beta::QueryForecastsResponse
Returns a list of the forecasts that are in the parent parameter and match your specified filters.
-
#query_reservations(request, options = nil) {|result, operation| ... } ⇒ ::Google::Cloud::CapacityPlanner::V1beta::QueryReservationsResponse
Returns a list of the reservations that are in the parent parameter and match your specified filters.
-
#query_usage_histories(request, options = nil) {|result, operation| ... } ⇒ ::Google::Cloud::CapacityPlanner::V1beta::QueryUsageHistoriesResponse
Returns a list of the usage histories that are in the parent parameter and match your specified filters.
-
#universe_domain ⇒ String
The effective universe domain.
Methods included from Paths
Constructor Details
#initialize {|config| ... } ⇒ Client
Create a new UsageService REST client object.
131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 |
# File 'lib/google/cloud/capacity_planner/v1beta/usage_service/rest/client.rb', line 131 def initialize # Create the configuration object @config = Configuration.new Client.configure # Yield the configuration if needed yield @config if block_given? # Create credentials credentials = @config.credentials # Use self-signed JWT if the endpoint is unchanged from default, # but only if the default endpoint does not have a region prefix. enable_self_signed_jwt = @config.endpoint.nil? || (@config.endpoint == Configuration::DEFAULT_ENDPOINT && !@config.endpoint.split(".").first.include?("-")) credentials ||= Credentials.default scope: @config.scope, enable_self_signed_jwt: enable_self_signed_jwt if credentials.is_a?(::String) || credentials.is_a?(::Hash) credentials = Credentials.new credentials, scope: @config.scope end @quota_project_id = @config.quota_project @quota_project_id ||= credentials.quota_project_id if credentials.respond_to? :quota_project_id @operations_client = ::Google::Cloud::CapacityPlanner::V1beta::UsageService::Rest::Operations.new do |config| config.credentials = credentials config.quota_project = @quota_project_id config.endpoint = @config.endpoint config.universe_domain = @config.universe_domain end @usage_service_stub = ::Google::Cloud::CapacityPlanner::V1beta::UsageService::Rest::ServiceStub.new( endpoint: @config.endpoint, endpoint_template: DEFAULT_ENDPOINT_TEMPLATE, universe_domain: @config.universe_domain, credentials: credentials, logger: @config.logger ) @usage_service_stub.logger(stub: true)&.info do |entry| entry.set_system_name entry.set_service entry. = "Created client for #{entry.service}" entry.set_credentials_fields credentials entry.set "customEndpoint", @config.endpoint if @config.endpoint entry.set "defaultTimeout", @config.timeout if @config.timeout entry.set "quotaProject", @quota_project_id if @quota_project_id end end |
Instance Attribute Details
#operations_client ⇒ ::Google::Cloud::CapacityPlanner::V1beta::UsageService::Rest::Operations (readonly)
Get the associated client for long-running operations.
185 186 187 |
# File 'lib/google/cloud/capacity_planner/v1beta/usage_service/rest/client.rb', line 185 def operations_client @operations_client end |
Class Method Details
.configure {|config| ... } ⇒ Client::Configuration
Configure the UsageService Client class.
See Configuration for a description of the configuration fields.
64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 |
# File 'lib/google/cloud/capacity_planner/v1beta/usage_service/rest/client.rb', line 64 def self.configure @configure ||= begin namespace = ["Google", "Cloud", "CapacityPlanner", "V1beta"] parent_config = while namespace.any? parent_name = namespace.join "::" parent_const = const_get parent_name break parent_const.configure if parent_const.respond_to? :configure namespace.pop end default_config = Client::Configuration.new parent_config default_config.timeout = 60.0 default_config.retry_policy = { initial_delay: 1.0, max_delay: 60.0, multiplier: 1.3, retry_codes: [14, 4, 13] } default_config end yield @configure if block_given? @configure end |
Instance Method Details
#configure {|config| ... } ⇒ Client::Configuration
Configure the UsageService Client instance.
The configuration is set to the derived mode, meaning that values can be changed, but structural changes (adding new fields, etc.) are not allowed. Structural changes should be made on configure.
See Configuration for a description of the configuration fields.
101 102 103 104 |
# File 'lib/google/cloud/capacity_planner/v1beta/usage_service/rest/client.rb', line 101 def configure yield @config if block_given? @config end |
#export_forecasts(request, options = nil) ⇒ ::Gapic::Operation #export_forecasts(parent: nil, machine_family: nil, machine_shape: nil, disk_type: nil, gpu_type: nil, tpu_type: nil, resource_type: nil, prediction_interval: nil, aggregation_method: nil, start_date: nil, end_date: nil, output_config: nil) ⇒ ::Gapic::Operation
Exports forecasted usage data requested by user into either an existing Cloud Storage bucket or a BigQuery table.
781 782 783 784 785 786 787 788 789 790 791 792 793 794 795 796 797 798 799 800 801 802 803 804 805 806 807 808 809 810 811 812 813 814 815 816 |
# File 'lib/google/cloud/capacity_planner/v1beta/usage_service/rest/client.rb', line 781 def export_forecasts request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::CapacityPlanner::V1beta::ExportForecastsRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.export_forecasts..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::CapacityPlanner::V1beta::VERSION, transports_version_send: [:rest] [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.export_forecasts.timeout, metadata: , retry_policy: @config.rpcs.export_forecasts.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @usage_service_stub.export_forecasts request, do |result, operation| result = ::Gapic::Operation.new result, @operations_client, options: yield result, operation if block_given? throw :response, result end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |
#export_reservations_usage(request, options = nil) ⇒ ::Gapic::Operation #export_reservations_usage(machine_family: nil, machine_shape: nil, gpu_type: nil, parent: nil, location_level: nil, cloud_resource_type: nil, usage_aggregation_method: nil, share_type: nil, start_date: nil, end_date: nil, output_config: nil) ⇒ ::Gapic::Operation
Exports reservations usage data requested by user into either an existing Cloud Storage bucket or a new/existing BigQuery table.
907 908 909 910 911 912 913 914 915 916 917 918 919 920 921 922 923 924 925 926 927 928 929 930 931 932 933 934 935 936 937 938 939 940 941 942 |
# File 'lib/google/cloud/capacity_planner/v1beta/usage_service/rest/client.rb', line 907 def export_reservations_usage request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::CapacityPlanner::V1beta::ExportReservationsUsageRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.export_reservations_usage..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::CapacityPlanner::V1beta::VERSION, transports_version_send: [:rest] [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.export_reservations_usage.timeout, metadata: , retry_policy: @config.rpcs.export_reservations_usage.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @usage_service_stub.export_reservations_usage request, do |result, operation| result = ::Gapic::Operation.new result, @operations_client, options: yield result, operation if block_given? throw :response, result end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |
#export_usage_histories(request, options = nil) ⇒ ::Gapic::Operation #export_usage_histories(parent: nil, is_spot: nil, machine_family: nil, machine_shape: nil, disk_type: nil, gpu_type: nil, tpu_type: nil, resource_type: nil, usage_aggregation_method: nil, start_date: nil, end_date: nil, output_config: nil) ⇒ ::Gapic::Operation
Exports historical usage data requested by user into either an existing Cloud Storage bucket or a BigQuery table.
655 656 657 658 659 660 661 662 663 664 665 666 667 668 669 670 671 672 673 674 675 676 677 678 679 680 681 682 683 684 685 686 687 688 689 690 |
# File 'lib/google/cloud/capacity_planner/v1beta/usage_service/rest/client.rb', line 655 def export_usage_histories request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::CapacityPlanner::V1beta::ExportUsageHistoriesRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.export_usage_histories..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::CapacityPlanner::V1beta::VERSION, transports_version_send: [:rest] [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.export_usage_histories.timeout, metadata: , retry_policy: @config.rpcs.export_usage_histories.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @usage_service_stub.export_usage_histories request, do |result, operation| result = ::Gapic::Operation.new result, @operations_client, options: yield result, operation if block_given? throw :response, result end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |
#logger ⇒ Logger
The logger used for request/response debug logging.
192 193 194 |
# File 'lib/google/cloud/capacity_planner/v1beta/usage_service/rest/client.rb', line 192 def logger @usage_service_stub.logger end |
#query_forecasts(request, options = nil) ⇒ ::Google::Cloud::CapacityPlanner::V1beta::QueryForecastsResponse #query_forecasts(parent: nil, machine_family: nil, machine_shape: nil, disk_type: nil, confidential_mode: nil, gpu_type: nil, tpu_type: nil, cloud_resource_type: nil, forecast_type: nil, prediction_interval: nil, aggregation_method: nil) ⇒ ::Google::Cloud::CapacityPlanner::V1beta::QueryForecastsResponse
Returns a list of the forecasts that are in the parent parameter and match your specified filters.
407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 |
# File 'lib/google/cloud/capacity_planner/v1beta/usage_service/rest/client.rb', line 407 def query_forecasts request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::CapacityPlanner::V1beta::QueryForecastsRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.query_forecasts..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::CapacityPlanner::V1beta::VERSION, transports_version_send: [:rest] [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.query_forecasts.timeout, metadata: , retry_policy: @config.rpcs.query_forecasts.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @usage_service_stub.query_forecasts request, do |result, operation| yield result, operation if block_given? end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |
#query_reservations(request, options = nil) ⇒ ::Google::Cloud::CapacityPlanner::V1beta::QueryReservationsResponse #query_reservations(parent: nil, location_level: nil, machine_family: nil, machine_shape: nil, gpu_type: nil, cloud_resource_type: nil, reservation_type: nil, share_type: nil, ownership_type: nil, reservation_data_level: nil, include_unapproved_reservations: nil, aggregation_method: nil, start_date: nil, end_date: nil) ⇒ ::Google::Cloud::CapacityPlanner::V1beta::QueryReservationsResponse
Returns a list of the reservations that are in the parent parameter and match your specified filters.
530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 |
# File 'lib/google/cloud/capacity_planner/v1beta/usage_service/rest/client.rb', line 530 def query_reservations request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::CapacityPlanner::V1beta::QueryReservationsRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.query_reservations..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::CapacityPlanner::V1beta::VERSION, transports_version_send: [:rest] [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.query_reservations.timeout, metadata: , retry_policy: @config.rpcs.query_reservations.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @usage_service_stub.query_reservations request, do |result, operation| yield result, operation if block_given? end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |
#query_usage_histories(request, options = nil) ⇒ ::Google::Cloud::CapacityPlanner::V1beta::QueryUsageHistoriesResponse #query_usage_histories(parent: nil, location_level: nil, is_spot: nil, machine_family: nil, machine_shape: nil, disk_type: nil, confidential_mode: nil, gpu_type: nil, tpu_type: nil, cloud_resource_type: nil, usage_aggregation_method: nil, start_date: nil, end_date: nil) ⇒ ::Google::Cloud::CapacityPlanner::V1beta::QueryUsageHistoriesResponse
Returns a list of the usage histories that are in the parent parameter and match your specified filters.
287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 |
# File 'lib/google/cloud/capacity_planner/v1beta/usage_service/rest/client.rb', line 287 def query_usage_histories request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::CapacityPlanner::V1beta::QueryUsageHistoriesRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.query_usage_histories..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::CapacityPlanner::V1beta::VERSION, transports_version_send: [:rest] [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.query_usage_histories.timeout, metadata: , retry_policy: @config.rpcs.query_usage_histories.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @usage_service_stub.query_usage_histories request, do |result, operation| yield result, operation if block_given? end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |
#universe_domain ⇒ String
The effective universe domain
111 112 113 |
# File 'lib/google/cloud/capacity_planner/v1beta/usage_service/rest/client.rb', line 111 def universe_domain @usage_service_stub.universe_domain end |